@@ -3,16 +3,17 @@ package org.herac.tuxguitar.player.impl.midiport.alsa;
 import org.herac.tuxguitar.player.base.MidiOutputPort;
 import org.herac.tuxguitar.player.base.MidiReceiver;
 
-public class MidiOutputPortImpl extends MidiOutputPort{
+public class MidiOutputPortImpl implements MidiOutputPort{
 	
-	private final int port;
-	private final int client;
-	private final MidiReceiverImpl receiver;
+	private int port;
+	private int client;
+	private String clientName;
+	private MidiReceiverImpl receiver;
 	
-	public MidiOutputPortImpl(MidiSystem midiSystem,String name,int client,int port){
-		super(MidiOutputPortImpl.getUniqueKey(client, port),MidiOutputPortImpl.getUniqueName(name, client, port));
-		this.client = client;
+	public MidiOutputPortImpl(MidiSystem midiSystem,String clientName,int client,int port){
 		this.port = port;
+		this.client = client;
+		this.clientName = clientName;
 		this.receiver = new MidiReceiverImpl(this,midiSystem);
 	}
 	
@@ -43,11 +44,11 @@ public class MidiOutputPortImpl extends MidiOutputPort{
 		return this.client;
 	}
 	
-	public static String getUniqueKey(int client,int port){
-		return ("tuxguitar-alsa_" + client + "-" + port);
+	public String getKey(){
+		return ("tuxguitar-alsa_" + this.client + "-" + this.port);
 	}
 	
-	public static String getUniqueName(String name,int client,int port){
-		return (name +" [" + client + ":" + port + "]");
+	public String getName(){
+		return (this.clientName +" [" + this.client + ":" + this.port + "]");
 	}
 }
\ No newline at end of file
