@@ -1,11 +1,11 @@
 package org.herac.tuxguitar.io.ascii;
 
 import org.herac.tuxguitar.gui.system.plugins.base.TGExporterPlugin;
-import org.herac.tuxguitar.io.base.TGSongExporter;
+import org.herac.tuxguitar.io.base.TGRawExporter;
 
 public class ASCIIPluginExporter extends TGExporterPlugin{
 	
-	protected TGSongExporter getExporter() {
+	protected TGRawExporter getExporter() {
 		return new ASCIISongExporter();
 	}
 	
