@@ -13,7 +13,7 @@ import java.util.Iterator;
 
 import org.herac.tuxguitar.io.base.TGFileFormat;
 import org.herac.tuxguitar.io.base.TGFileFormatException;
-import org.herac.tuxguitar.io.base.TGSongExporter;
+import org.herac.tuxguitar.io.base.TGLocalFileExporter;
 import org.herac.tuxguitar.song.factory.TGFactory;
 import org.herac.tuxguitar.song.models.TGBeat;
 import org.herac.tuxguitar.song.models.TGChord;
@@ -31,7 +31,7 @@ import org.herac.tuxguitar.song.models.TGTempo;
 import org.herac.tuxguitar.song.models.TGText;
 import org.herac.tuxguitar.song.models.TGTimeSignature;
 import org.herac.tuxguitar.song.models.TGTrack;
-import org.herac.tuxguitar.song.models.TGTupleto;
+import org.herac.tuxguitar.song.models.TGDivisionType;
 import org.herac.tuxguitar.song.models.TGVoice;
 import org.herac.tuxguitar.song.models.effects.TGEffectBend;
 import org.herac.tuxguitar.song.models.effects.TGEffectGrace;
@@ -45,7 +45,7 @@ import org.herac.tuxguitar.song.models.effects.TGEffectTrill;
  * TODO To change the template for this generated type comment go to
  * Window - Preferences - Java - Code Style - Code Templates
  */
-public class TGOutputStream extends TGStream implements TGSongExporter{
+public class TGOutputStream extends TGStream implements TGLocalFileExporter{
 	
 	private DataOutputStream dataOutputStream;
 	
@@ -65,9 +65,12 @@ public class TGOutputStream extends TGStream implements TGSongExporter{
 		return true;
 	}
 	
-	public void exportSong(OutputStream stream,TGSong song) throws TGFileFormatException {
+	public void init(TGFactory factory,OutputStream stream){
+		this.dataOutputStream = new DataOutputStream(stream);
+	}
+	
+	public void exportSong(TGSong song) throws TGFileFormatException {
 		try{
-			this.dataOutputStream = new DataOutputStream(stream);
 			this.writeVersion();
 			this.write(song);
 			this.dataOutputStream.flush();
@@ -431,24 +434,24 @@ public class TGOutputStream extends TGStream implements TGSongExporter{
 		int header = 0;
 		header = (duration.isDotted())?header |= DURATION_DOTTED:header;
 		header = (duration.isDoubleDotted())?header |= DURATION_DOUBLE_DOTTED:header;
-		header = (!duration.getTupleto().isEqual(TGTupleto.NORMAL))?header |= DURATION_NO_TUPLETO:header;
+		header = (!duration.getDivision().isEqual(TGDivisionType.NORMAL))?header |= DURATION_NO_TUPLE:header;
 		writeHeader(header);
 		
 		//escribo el valor
 		writeByte(duration.getValue());
 		
-		//escribo el tupleto
-		if(((header & DURATION_NO_TUPLETO) != 0)){
-			writeTupleto(duration.getTupleto());
+		//escribo el tipo de divisiones
+		if(((header & DURATION_NO_TUPLE) != 0)){
+			writeDivisionType(duration.getDivision());
 		}
 	}
 	
-	private void writeTupleto(TGTupleto tupleto){
+	private void writeDivisionType(TGDivisionType divisionType){
 		//escribo los enters
-		writeByte(tupleto.getEnters());
+		writeByte(divisionType.getEnters());
 		
 		//escribo los tiempos
-		writeByte(tupleto.getTimes());
+		writeByte(divisionType.getTimes());
 	}
 	
 	private void writeNoteEffect(TGNoteEffect effect){
