@@ -11,8 +11,10 @@ import java.util.Iterator;
 
 import org.herac.tuxguitar.io.base.TGFileFormatException;
 import org.herac.tuxguitar.io.base.TGFileFormatManager;
-import org.herac.tuxguitar.io.base.TGSongExporter;
-import org.herac.tuxguitar.io.base.TGSongImporter;
+import org.herac.tuxguitar.io.base.TGLocalFileExporter;
+import org.herac.tuxguitar.io.base.TGLocalFileImporter;
+import org.herac.tuxguitar.io.base.TGOutputStreamBase;
+import org.herac.tuxguitar.io.base.TGRawImporter;
 import org.herac.tuxguitar.song.factory.TGFactory;
 import org.herac.tuxguitar.song.managers.TGSongManager;
 import org.herac.tuxguitar.song.models.TGSong;
@@ -31,8 +33,7 @@ public class TGConverter {
 	
 	private String sourceFolder;
 	private String destinationFolder;
-	private String extension = null;
-	
+	private TGConverterFormat format;
 	private TGConverterListener listener;
 	private boolean cancelled;
 	
@@ -46,7 +47,7 @@ public class TGConverter {
 			this.getListener().notifyFileProcess(convertFileName);
 			
 			TGSongManager manager = new TGSongManager();
-			TGSong song=null;
+			TGSong song = null;
 			try {
 				song = TGFileFormatManager.instance().getLoader().load(manager.getFactory(),new FileInputStream(fileName));
 			} catch (TGFileFormatException e) {
@@ -60,31 +61,24 @@ public class TGConverter {
 				
 				new File(new File(convertFileName).getParent()).mkdirs();
 				
-				boolean exporter = false;
-				try {
-					TGFileFormatManager.instance().getWriter().write(manager.getFactory(),manager.getSong(), convertFileName);
-				} catch (TGFileFormatException ex) {
-					exporter = true;
+				if( this.format != null && this.format.getExporter() instanceof TGOutputStreamBase ){
+					TGOutputStreamBase exporter = (TGOutputStreamBase) this.format.getExporter();
+					exporter.init(manager.getFactory(), new BufferedOutputStream(new FileOutputStream(convertFileName)));
+					exporter.writeSong(song);
 				}
-				// then it's exporter
-				if (exporter==true) {
-					TGSongExporter songExporter = findExporter();
-					if (songExporter==null)
-						this.getListener().notifyFileResult(this.extension,EXPORTER_NOT_FOUND);
-					else {
-						songExporter.configure(true);
-						try {
-							songExporter.exportSong(new BufferedOutputStream(new FileOutputStream(convertFileName)), manager.getSong());
-						} catch (FileNotFoundException ex) {
-							this.getListener().notifyFileResult(convertFileName,FILE_COULDNT_WRITE);
-						}
-					}
+				else if( this.format != null && this.format.getExporter() instanceof TGLocalFileExporter ){
+					TGLocalFileExporter exporter = (TGLocalFileExporter) this.format.getExporter();
+					exporter.configure(true);
+					exporter.init(manager.getFactory(), new BufferedOutputStream(new FileOutputStream(convertFileName)));
+					exporter.exportSong(manager.getSong());
 				}
 				this.getListener().notifyFileResult(convertFileName,FILE_OK);
 			}
 			else{
 				this.getListener().notifyFileResult(fileName,FILE_BAD);
 			}
+		} catch (TGFileFormatException e) {
+			this.getListener().notifyFileResult(fileName,FILE_COULDNT_WRITE); 
 		} catch (FileNotFoundException ex) {
 			this.getListener().notifyFileResult(fileName,FILE_NOT_FOUND);
 		} catch (OutOfMemoryError e) {
@@ -143,32 +137,24 @@ public class TGConverter {
 		String convertPath = (this.destinationFolder + File.separator +path.substring(this.sourceFolder.length()));
 		int lastDot = convertPath.lastIndexOf(".");
 		if (lastDot!=-1) {
-			convertPath = convertPath.substring(0, lastDot) + this.extension;
+			convertPath = convertPath.substring(0, lastDot) + this.format.getExtension();
 		}
 		return checkIfExists( new File(convertPath).getAbsolutePath() , 0 );
 	}
 	
-	private TGSongExporter findExporter() {
-		// find the exporter
-		Iterator exporters = TGFileFormatManager.instance().getExporters();
-		String wantedExtension = "*"+this.extension;
-		while (exporters.hasNext()) {
-			TGSongExporter current = (TGSongExporter)exporters.next();
-			if (current.getFileFormat().getSupportedFormats().startsWith(wantedExtension))
-				return current;
-		}
-		return null;
-	}
-	
 	private TGSong importSong(TGFactory factory, String filename) {
 		Iterator importers = TGFileFormatManager.instance().getImporters();
 		while (importers.hasNext() ) {
-			TGSongImporter currentImporter = (TGSongImporter)importers.next();
 			try {
-				currentImporter.configure(true);
-				if (isSupportedExtension(filename,currentImporter)) {
-					InputStream input = new BufferedInputStream(new FileInputStream(filename));
-					return currentImporter.importSong(factory, input);
+				TGRawImporter rawImporter = (TGRawImporter)importers.next();
+				if( rawImporter instanceof TGLocalFileImporter ){
+					TGLocalFileImporter currentImporter = (TGLocalFileImporter)rawImporter;
+					currentImporter.configure(true);
+					if (isSupportedExtension(filename,currentImporter)) {
+						InputStream input = new BufferedInputStream(new FileInputStream(filename));
+						currentImporter.init(factory, input);
+						return currentImporter.importSong();
+					}
 				}
 			} catch (Throwable throwable) {
 				throwable.printStackTrace();
@@ -177,7 +163,7 @@ public class TGConverter {
 		return null;
 	}
 	
-	private boolean isSupportedExtension(String filename, TGSongImporter currentImporter) {
+	private boolean isSupportedExtension(String filename, TGLocalFileImporter currentImporter) {
 		try {
 			String extension = filename.substring(filename.lastIndexOf("."),filename.length());
 			extension="*"+extension.toLowerCase();
@@ -200,12 +186,8 @@ public class TGConverter {
 		}
 	}
 	
-	public String getExtension() {
-		return this.extension;
-	}
-	
-	public void setExtension(String extension) {
-		this.extension = extension;
+	public void setFormat( TGConverterFormat format ) {
+		this.format = format;
 	}
 	
 	public TGConverterListener getListener() {
