@@ -2,19 +2,39 @@ package org.herac.tuxguitar.io.gervill;
 
 import org.herac.tuxguitar.gui.system.plugins.TGPluginException;
 import org.herac.tuxguitar.gui.system.plugins.base.TGExporterPlugin;
-import org.herac.tuxguitar.io.base.TGSongExporter;
+import org.herac.tuxguitar.io.base.TGRawExporter;
 
 public class MidiToAudioPlugin extends TGExporterPlugin{
 	
-	protected TGSongExporter getExporter() throws TGPluginException {
-		return new MidiToAudioExporter();
+	private boolean available;
+	
+	public MidiToAudioPlugin(){
+		this.available = MidiToAudioSynth.instance().isAvailable();
+	}
+	
+	public void init() throws TGPluginException {
+		if( this.available ){
+			super.init();
+		}
+	}
+	
+	public void close() throws TGPluginException {
+		if( this.available ){
+			super.close();
+		}
 	}
 	
 	public void setEnabled( boolean enabled ) throws TGPluginException {
-		if( enabled && !MidiToAudioSynth.instance().isAvailable() ){
-			throw new TGPluginException("Gervill Synthesizer is not available");
+		if( this.available ){
+			super.setEnabled( enabled );
 		}
-		super.setEnabled( enabled );
+	}
+	
+	protected TGRawExporter getExporter() throws TGPluginException {
+		if( this.available ){
+			return new MidiToAudioExporter();
+		}
+		return null;
 	}
 	
 	public String getVersion() {
@@ -33,7 +53,8 @@ public class MidiToAudioPlugin extends TGExporterPlugin{
 		String description = new String();
 		description += ("The purpose of this plugin is to add gervill support to tuxguitar.\n");
 		description += ("The current version of this plugin includes \"Export to Audio\" feature.\n");
-		description += ("See more about Gervill: https://gervill.dev.java.net/");
+		description += ("See more about Gervill: https://gervill.dev.java.net/\n\n");
+		description += ("This plugin will only work if gervill synthesizer is installed in your JVM");
 		return description;
 	}
 }
