@@ -52,7 +52,7 @@ public class GP4InputStream extends GTPInputStream {
 		readVersion();
 		if (!isSupportedVersion(getVersion())) {
 			this.close();
-			throw new GTPFormatException("Unsuported Version");
+			throw new GTPFormatException("Unsupported Version");
 		}
 		TGSong song = getFactory().newSong();
 		
@@ -89,12 +89,12 @@ public class GP4InputStream extends GTPInputStream {
 		song.setArtist(readStringByteSizeOfInteger());
 		song.setAlbum(readStringByteSizeOfInteger());
 		song.setAuthor(readStringByteSizeOfInteger());
+		song.setCopyright(readStringByteSizeOfInteger());
+		song.setWriter(readStringByteSizeOfInteger());
 		readStringByteSizeOfInteger();
-		readStringByteSizeOfInteger();
-		readStringByteSizeOfInteger();
-		int notes = readInt();
-		for (int i = 0; i < notes; i++) {
-			readStringByteSizeOfInteger();
+		int comments = readInt();
+		for (int i = 0; i < comments; i++) {
+			song.setComments( song.getComments() + readStringByteSizeOfInteger() );
 		}
 	}
 	
@@ -208,39 +208,39 @@ public class GP4InputStream extends GTPInputStream {
 		duration.setValue( (int) (Math.pow( 2 , (readByte() + 4) ) / 4 ) );
 		duration.setDotted(((flags & 0x01) != 0));
 		if ((flags & 0x20) != 0) {
-			int tuplet = readInt();
-			switch (tuplet) {
+			int divisionType = readInt();
+			switch (divisionType) {
 			case 3:
-				duration.getTupleto().setEnters(3);
-				duration.getTupleto().setTimes(2);
+				duration.getDivision().setEnters(3);
+				duration.getDivision().setTimes(2);
 				break;
 			case 5:
-				duration.getTupleto().setEnters(5);
-				duration.getTupleto().setTimes(4);
+				duration.getDivision().setEnters(5);
+				duration.getDivision().setTimes(4);
 				break;
 			case 6:
-				duration.getTupleto().setEnters(6);
-				duration.getTupleto().setTimes(4);
+				duration.getDivision().setEnters(6);
+				duration.getDivision().setTimes(4);
 				break;
 			case 7:
-				duration.getTupleto().setEnters(7);
-				duration.getTupleto().setTimes(4);
+				duration.getDivision().setEnters(7);
+				duration.getDivision().setTimes(4);
 				break;
 			case 9:
-				duration.getTupleto().setEnters(9);
-				duration.getTupleto().setTimes(8);
+				duration.getDivision().setEnters(9);
+				duration.getDivision().setTimes(8);
 				break;
 			case 10:
-				duration.getTupleto().setEnters(10);
-				duration.getTupleto().setTimes(8);
+				duration.getDivision().setEnters(10);
+				duration.getDivision().setTimes(8);
 				break;
 			case 11:
-				duration.getTupleto().setEnters(11);
-				duration.getTupleto().setTimes(8);
+				duration.getDivision().setEnters(11);
+				duration.getDivision().setTimes(8);
 				break;
 			case 12:
-				duration.getTupleto().setEnters(12);
-				duration.getTupleto().setTimes(8);
+				duration.getDivision().setEnters(12);
+				duration.getDivision().setTimes(8);
 				break;
 			}
 		}
@@ -319,6 +319,7 @@ public class GP4InputStream extends GTPInputStream {
 		for (int i = 0; i < numberOfBeats; i++) {
 			nextNoteStart += readBeat(nextNoteStart, measure, track, tempo);
 		}
+		measure.setClef( getClef(track) );
 	}
 	
 	private TGNote readNote(TGString string, TGTrack track,TGNoteEffect effect)throws IOException {
@@ -669,4 +670,17 @@ public class GP4InputStream extends GTPInputStream {
 		short value = (short)(( b * 8 ) - 1);
 		return (short)Math.max(value,0);
 	}
+	
+	private int getClef( TGTrack track ){
+		if( !track.isPercussionTrack() ){
+			Iterator it = track.getStrings().iterator();
+			while( it.hasNext() ){
+				TGString string = (TGString) it.next();
+				if( string.getValue() <= 34 ){
+					return TGMeasure.CLEF_BASS;
+				}
+			}
+		}
+		return TGMeasure.CLEF_TREBLE;
+	}
 }
