@@ -7,7 +7,9 @@
 package org.herac.tuxguitar.io.gtp;
 
 import java.io.IOException;
+import java.util.ArrayList;
 import java.util.Iterator;
+import java.util.List;
 
 import org.herac.tuxguitar.io.base.TGFileFormat;
 import org.herac.tuxguitar.io.base.TGFileFormatException;
@@ -28,7 +30,7 @@ import org.herac.tuxguitar.song.models.TGTempo;
 import org.herac.tuxguitar.song.models.TGText;
 import org.herac.tuxguitar.song.models.TGTimeSignature;
 import org.herac.tuxguitar.song.models.TGTrack;
-import org.herac.tuxguitar.song.models.TGTupleto;
+import org.herac.tuxguitar.song.models.TGDivisionType;
 import org.herac.tuxguitar.song.models.TGVelocities;
 import org.herac.tuxguitar.song.models.TGVoice;
 import org.herac.tuxguitar.song.models.effects.TGEffectBend;
@@ -86,15 +88,19 @@ public class GP4OutputStream extends GTPOutputStream{
 	}
 	
 	private void writeInfo(TGSong song) throws IOException{
+		List comments = toCommentLines(song.getComments());
 		writeStringByteSizeOfInteger(song.getName());
 		writeStringByteSizeOfInteger("");
 		writeStringByteSizeOfInteger(song.getArtist());
 		writeStringByteSizeOfInteger(song.getAlbum());
 		writeStringByteSizeOfInteger(song.getAuthor());
+		writeStringByteSizeOfInteger(song.getCopyright());
+		writeStringByteSizeOfInteger(song.getWriter());
 		writeStringByteSizeOfInteger("");
-		writeStringByteSizeOfInteger("");
-		writeStringByteSizeOfInteger("");
-		writeInt(0);
+		writeInt( comments.size() );
+		for (int i = 0; i < comments.size(); i++) {
+			writeStringByteSizeOfInteger( (String)comments.get(i) );
+		}
 	}
 	
 	private void writeChannels(TGSong song) throws IOException{
@@ -270,7 +276,7 @@ public class GP4OutputStream extends GTPOutputStream{
 		else if (effect.isTremoloBar() || effect.isTapping() || effect.isSlapping() || effect.isPopping() || effect.isFadeIn()) {
 			flags |= 0x08;
 		}
-		if (!duration.getTupleto().isEqual(TGTupleto.NORMAL)) {
+		if (!duration.getDivision().isEqual(TGDivisionType.NORMAL)) {
 			flags |= 0x20;
 		}
 		if (changeTempo) {
@@ -286,7 +292,7 @@ public class GP4OutputStream extends GTPOutputStream{
 		}
 		writeByte(parseDuration(duration));
 		if ((flags & 0x20) != 0) {
-			writeInt(duration.getTupleto().getEnters());
+			writeInt(duration.getDivision().getEnters());
 		}
 		if ((flags & 0x02) != 0) {
 			writeChord(beat.getChord());
@@ -650,4 +656,18 @@ public class GP4OutputStream extends GTPOutputStream{
 	private byte toChannelByte(short s){
 		return  (byte) ((s + 1) / 8);
 	}
+	
+	private List toCommentLines( String comments ){
+		List lines = new ArrayList();
+		
+		String line = comments;
+		while( line.length() > Byte.MAX_VALUE ) {
+			String subline = line.substring(0, Byte.MAX_VALUE);
+			lines.add( subline );
+			line = line.substring( Byte.MAX_VALUE );
+		}
+		lines.add( line );
+		
+		return lines;
+	}
 }
