@@ -30,7 +30,7 @@ import org.herac.tuxguitar.song.models.TGTempo;
 import org.herac.tuxguitar.song.models.TGText;
 import org.herac.tuxguitar.song.models.TGTimeSignature;
 import org.herac.tuxguitar.song.models.TGTrack;
-import org.herac.tuxguitar.song.models.TGTupleto;
+import org.herac.tuxguitar.song.models.TGDivisionType;
 import org.herac.tuxguitar.song.models.TGVelocities;
 import org.herac.tuxguitar.song.models.TGVoice;
 import org.herac.tuxguitar.song.models.effects.TGEffectBend;
@@ -106,16 +106,20 @@ public class GP5OutputStream extends GTPOutputStream {
 	}
 	
 	private void writeInfo(TGSong song) throws IOException{
+		List comments = toCommentLines(song.getComments());
 		writeStringByteSizeOfInteger(song.getName());
 		writeStringByteSizeOfInteger("");
 		writeStringByteSizeOfInteger(song.getArtist());
 		writeStringByteSizeOfInteger(song.getAlbum());
 		writeStringByteSizeOfInteger(song.getAuthor());
 		writeStringByteSizeOfInteger("");
+		writeStringByteSizeOfInteger(song.getCopyright());
+		writeStringByteSizeOfInteger(song.getWriter());
 		writeStringByteSizeOfInteger("");
-		writeStringByteSizeOfInteger("");
-		writeStringByteSizeOfInteger("");
-		writeInt(0);
+		writeInt( comments.size() );
+		for (int i = 0; i < comments.size(); i++) {
+			writeStringByteSizeOfInteger( (String)comments.get(i) );
+		}
 	}
 	
 	private void writeLyrics(TGSong song) throws IOException{
@@ -367,7 +371,7 @@ public class GP5OutputStream extends GTPOutputStream {
 		if (changeTempo) {
 			flags |= 0x10;
 		}
-		if (!duration.getTupleto().isEqual(TGTupleto.NORMAL)) {
+		if (!duration.getDivision().isEqual(TGDivisionType.NORMAL)) {
 			flags |= 0x20;
 		}
 		if (voice.isEmpty() || voice.isRestVoice()) {
@@ -381,7 +385,7 @@ public class GP5OutputStream extends GTPOutputStream {
 		}
 		writeByte(parseDuration(duration));
 		if ((flags & 0x20) != 0) {
-			writeInt(duration.getTupleto().getEnters());
+			writeInt(duration.getDivision().getEnters());
 		}
 		
 		if ((flags & 0x02) != 0) {
@@ -778,4 +782,18 @@ public class GP5OutputStream extends GTPOutputStream {
 	private byte toChannelByte(short s){
 		return  (byte) ((s + 1) / 8);
 	}
+	
+	private List toCommentLines( String comments ){
+		List lines = new ArrayList();
+		
+		String line = comments;
+		while( line.length() > Byte.MAX_VALUE ) {
+			String subline = line.substring(0, Byte.MAX_VALUE);
+			lines.add( subline );
+			line = line.substring( Byte.MAX_VALUE );
+		}
+		lines.add( line );
+		
+		return lines;
+	}
 }
\ No newline at end of file
