@@ -5,6 +5,8 @@ import javax.sound.midi.Sequencer;
 import javax.sound.midi.Track;
 import javax.sound.midi.Transmitter;
 
+import org.herac.tuxguitar.gui.TuxGuitar;
+import org.herac.tuxguitar.player.base.MidiPlayerException;
 import org.herac.tuxguitar.player.base.MidiSequenceHandler;
 import org.herac.tuxguitar.player.base.MidiSequencer;
 import org.herac.tuxguitar.player.base.MidiTransmitter;
@@ -13,11 +15,13 @@ public class MidiSequencerImpl implements MidiSequencer,MidiSequenceLoader{
 	
 	private static final int TICK_MOVE = 1;
 	
+	private Object lock;
 	private Sequencer sequencer;
 	private Transmitter sequencerTransmitter;
 	private MidiTransmitter transmitter;
 	
 	public MidiSequencerImpl(Sequencer sequencer){
+		this.lock = new Object();
 		this.sequencer = sequencer;
 	}
 	
@@ -64,11 +68,17 @@ public class MidiSequencerImpl implements MidiSequencer,MidiSequenceLoader{
 		}
 	}
 	
-	protected Sequencer getSequencer() {
-		this.open();
+	protected Sequencer getSequencer(boolean open) {
+		if( open ){
+			this.open();
+		}
 		return this.sequencer;
 	}
 	
+	protected Sequencer getSequencer() {
+		return this.getSequencer(true);
+	}
+	
 	public MidiSequenceHandler createSequence(int tracks) {
 		this.resetTracks();
 		return new MidiSequenceHandlerImpl(this,tracks);
@@ -109,15 +119,6 @@ public class MidiSequencerImpl implements MidiSequencer,MidiSequenceLoader{
 		}
 	}
 	
-	public boolean isRunning() {
-		try {
-			return getSequencer().isRunning();
-		} catch (Throwable throwable) {
-			throwable.printStackTrace();
-		}
-		return false;
-	}
-	
 	public void setMute(int index, boolean mute) {
 		try {
 			getSequencer().setTrackMute(index, mute);
@@ -144,7 +145,7 @@ public class MidiSequencerImpl implements MidiSequencer,MidiSequenceLoader{
 	
 	public void start() {
 		try {
-			getSequencer().start();
+			this.setRunning( true );
 		} catch (Throwable throwable) {
 			throwable.printStackTrace();
 		}
@@ -152,8 +153,31 @@ public class MidiSequencerImpl implements MidiSequencer,MidiSequenceLoader{
 	
 	public void stop() {
 		try {
-			this.getSequencer().stop();
-			this.reset( true );
+			this.setRunning( false );
+		} catch (Throwable throwable) {
+			throwable.printStackTrace();
+		}
+	}
+	
+	public boolean isRunning() {
+		try {
+			return ( getSequencer( false ) != null && getSequencer( false ).isRunning() );
+		} catch (Throwable throwable) {
+			throwable.printStackTrace();
+		}
+		return false;
+	}
+	
+	public void setRunning( boolean running ) {
+		try {
+			synchronized ( this.lock ) {
+				if( running && !this.isRunning() ){
+					this.getSequencer().start();
+				}else if( !running && this.isRunning() ){
+					this.getSequencer().stop();
+					this.reset( true );
+				}
+			}
 		} catch (Throwable throwable) {
 			throwable.printStackTrace();
 		}
@@ -198,4 +222,11 @@ public class MidiSequencerImpl implements MidiSequencer,MidiSequenceLoader{
 	public String getName() {
 		return this.sequencer.getDeviceInfo().getName();
 	}
+	
+	public void check() throws MidiPlayerException {
+		this.getSequencer( true );
+		if( this.sequencer == null || !this.sequencer.isOpen() ){
+			throw new MidiPlayerException(TuxGuitar.getProperty("jsa.error.midi.unavailable"));
+		}
+	}
 }
