@@ -6,7 +6,6 @@ import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
 
-import org.herac.tuxguitar.song.factory.TGFactory;
 import org.herac.tuxguitar.song.managers.TGSongManager;
 import org.herac.tuxguitar.song.models.TGBeat;
 import org.herac.tuxguitar.song.models.TGChord;
@@ -14,13 +13,16 @@ import org.herac.tuxguitar.song.models.TGDuration;
 import org.herac.tuxguitar.song.models.TGMeasure;
 import org.herac.tuxguitar.song.models.TGMeasureHeader;
 import org.herac.tuxguitar.song.models.TGNote;
+import org.herac.tuxguitar.song.models.TGNoteEffect;
 import org.herac.tuxguitar.song.models.TGSong;
 import org.herac.tuxguitar.song.models.TGString;
+import org.herac.tuxguitar.song.models.TGStroke;
 import org.herac.tuxguitar.song.models.TGTempo;
 import org.herac.tuxguitar.song.models.TGTimeSignature;
 import org.herac.tuxguitar.song.models.TGTrack;
-import org.herac.tuxguitar.song.models.TGTupleto;
+import org.herac.tuxguitar.song.models.TGDivisionType;
 import org.herac.tuxguitar.song.models.TGVoice;
+import org.herac.tuxguitar.song.models.effects.TGEffectGrace;
 
 public class LilypondOutputStream {
 	
@@ -51,9 +53,11 @@ public class LilypondOutputStream {
 		this.manager = new TGSongManager();
 		this.manager.setSong(song);
 		
+		this.addFunctions();
 		this.addVersion();
 		this.addPaper(song);
 		this.addLayout();
+		this.addCommands();
 		this.addSongDefinitions(song);
 		this.addSong(song);
 		
@@ -65,11 +69,39 @@ public class LilypondOutputStream {
 		this.writer.println("\\version \"" + LILYPOND_VERSION + "\"");
 	}
 	
+	private void addFunctions(){
+		// tab-clear-tied-fret-numbers
+		this.writer.println("#(define (tie::tab-clear-tied-fret-numbers grob)");
+		this.writer.println(indent(1) + "(let* ((tied-fret-nr (ly:spanner-bound grob RIGHT)))");
+		this.writer.println(indent(2) + "(ly:grob-set-property! tied-fret-nr 'transparent #t)))");
+		this.writer.println();
+	}
+	
+	private void addCommands(){
+		// deadNote
+		this.writer.println("deadNote = #(define-music-function (parser location note) (ly:music?)");
+		this.writer.println(indent(1) + "(set! (ly:music-property note 'tweaks)");
+		this.writer.println(indent(2) + "(acons 'stencil ly:note-head::print");
+		this.writer.println(indent(3) + "(acons 'glyph-name \"2cross\"");
+		this.writer.println(indent(4) + "(acons 'style 'special");
+		this.writer.println(indent(5) + "(ly:music-property note 'tweaks)))))");
+		this.writer.println(indent(1) + "note)");
+		this.writer.println();
+		
+		// palmMute
+		this.writer.println("palmMute = #(define-music-function (parser location note) (ly:music?)");
+		this.writer.println(indent(1) + "(set! (ly:music-property note 'tweaks)");
+		this.writer.println(indent(2) + "(acons 'style 'do (ly:music-property note 'tweaks)))");
+		this.writer.println(indent(1) + "note)");
+		this.writer.println();
+	}
+	
 	private void addPaper(TGSong song){
 		this.writer.println("\\paper {");
 		
 		this.writer.println(indent(1) + "indent = #" + (this.addTrackTitleOnGroup(song) ? 30 : 0));
 		this.writer.println(indent(1) + "printallheaders = #" + getLilypondBoolean(true));
+		this.writer.println(indent(1) + "print-all-headers = #" + getLilypondBoolean(true));
 		this.writer.println(indent(1) + "ragged-right = #" + getLilypondBoolean(false));
 		this.writer.println(indent(1) + "ragged-bottom = #" + getLilypondBoolean(true));
 		this.writer.println("}");
@@ -98,7 +130,13 @@ public class LilypondOutputStream {
 		this.writer.println(indent(2) + "\\override TimeSignature #'style = #'numbered");
 		this.writer.println(indent(2) + "\\override Stem #'transparent = #" + getLilypondBoolean(this.settings.isScoreEnabled()));
 		this.writer.println(indent(2) + "\\override Beam #'transparent = #" + getLilypondBoolean(this.settings.isScoreEnabled()));
+		this.writer.println(indent(2) + "\\override Tie  #'after-line-breaking = #tie::tab-clear-tied-fret-numbers");
 		this.writer.println(indent(1) + "}");
+		if( this.settings.isScoreEnabled() ){
+			this.writer.println(indent(1) + "\\context { \\TabVoice");
+			this.writer.println(indent(2) + "\\override Tie #'stencil = ##f");
+			this.writer.println(indent(1) + "}");
+		}
 		this.writer.println(indent(1) + "\\context { \\StaffGroup");
 		this.writer.println(indent(2) + "\\consists \"Instrument_name_engraver\"");
 		this.writer.println(indent(1) + "}");
@@ -151,25 +189,27 @@ public class LilypondOutputStream {
 	}
 	
 	private void addMusic(TGTrack track,String id){
-		this.writer.println(id + "Music = #(define-music-function (parser location inTab) (boolean?)");
-		this.writer.println("#{");
-		TGMeasure previous = null;
-		int count = track.countMeasures();
-		for(int i = 0; i < count; i ++){
-			// TODO: Add multivoice support.
-			TGMeasure srcMeasure = track.getMeasure(i);
-			TGMeasure measure = new TGVoiceJoiner(this.manager.getFactory(),srcMeasure).process();
-			
-			int measureFrom = this.settings.getMeasureFrom();
-			int measureTo = this.settings.getMeasureTo();
-			if((measureFrom <= measure.getNumber() || measureFrom == LilypondSettings.FIRST_MEASURE) && (measureTo >= measure.getNumber() || measureTo == LilypondSettings.LAST_MEASURE )){
-				this.addMeasure(measure,previous,1,(i == (count - 1)));
-				previous = measure;
+		for( int voice = 0 ; voice < TGBeat.MAX_VOICES ; voice ++ ){
+			this.writer.println(trackVoiceID(voice,id,"Music") + " = #(define-music-function (parser location inTab) (boolean?)");
+			this.writer.println("#{");
+			if( this.isVoiceAvailable( track , voice ) ){
+				TGMeasure previous = null;
+				int count = track.countMeasures();
+				for(int i = 0; i < count; i ++){
+					TGMeasure measure = track.getMeasure(i);
+					
+					int measureFrom = this.settings.getMeasureFrom();
+					int measureTo = this.settings.getMeasureTo();
+					if((measureFrom <= measure.getNumber() || measureFrom == LilypondSettings.FIRST_MEASURE) && (measureTo >= measure.getNumber() || measureTo == LilypondSettings.LAST_MEASURE )){
+						this.addMeasure(measure,previous,voice,1,(i == (count - 1)));
+						previous = measure;
+					}
+				}
+				this.writer.println(indent(1) + "\\bar \"|.\"");
+				this.writer.println(indent(1) + "\\pageBreak");
 			}
+			this.writer.println("#})");
 		}
-		this.writer.println(indent(1) + "\\bar \"|.\"");
-		this.writer.println(indent(1) + "\\pageBreak");
-		this.writer.println("#})");
 	}
 	
 	private void addScoreStaff(TGTrack track,String id){
@@ -177,19 +217,26 @@ public class LilypondOutputStream {
 		boolean addChordDiagrams = this.settings.isChordDiagramEnabled();
 		boolean addTexts = this.settings.isTextEnabled();
 		
-		this.writer.println(id + "Staff = \\new " + (addLyrics ? "Voice = \"" + id + "Staff\" <<" : "Staff {"));
+		this.writer.println(id + "Staff = \\new Staff <<" );
 		
-		if(!addChordDiagrams){
-			this.writer.println(indent(1) + "\\removeWithTag #'chords");
+		for( int v = 0 ; v < TGBeat.MAX_VOICES ; v ++ ){
+			String vId =  trackVoiceID(v, id, "Music") ;
+			this.writer.println(indent(1) + "\\context Voice = \"" + vId + "\" {");
+			if(!addChordDiagrams){
+				this.writer.println(indent(2) + "\\removeWithTag #'chords");
+			}
+			if(!addTexts){
+				this.writer.println(indent(2) + "\\removeWithTag #'texts");
+			}
+			this.writer.println(indent(2) + "\\" + vId + " #" + getLilypondBoolean( false ) );
+			this.writer.println(indent(1) + "}");
 		}
-		if(!addTexts){
-			this.writer.println(indent(1) + "\\removeWithTag #'texts");
-		}
-		this.writer.println(indent(1) + "\\" + id + "Music #" + getLilypondBoolean( false ));
+		
 		if(addLyrics){
-			this.writer.println(indent(1) + "\\new Lyrics \\lyricsto \"" + id + "Staff\" \\" + id + "Lyrics");
+			this.writer.println(indent(1) + "\\new Lyrics \\lyricsto \"" + trackVoiceID(0, id, "Music") + "\" \\" + id + "Lyrics");
 		}
-		this.writer.println( (addLyrics ? ">>" : "}" ) );
+		
+		this.writer.println(">>");
 	}
 	
 	private void addTabStaff(TGTrack track,String id){
@@ -197,21 +244,25 @@ public class LilypondOutputStream {
 		boolean addChordDiagrams = (this.settings.isChordDiagramEnabled() && !this.settings.isScoreEnabled());
 		boolean addTexts = (this.settings.isTextEnabled() && !this.settings.isScoreEnabled());
 		
-		this.writer.println(id + "TabStaff = \\new " + (addLyrics ? "TabVoice = \"" + id + "TabStaff\" <<" : "TabStaff {" ));
+		this.writer.println(id + "TabStaff = \\new TabStaff " + getLilypondTuning(track) + " <<" );
 		
-		this.addTuning(track,1);
-		
-		if(!addChordDiagrams){
-			this.writer.println(indent(1) + "\\removeWithTag #'chords");
+		for( int v = 0 ; v < TGBeat.MAX_VOICES ; v ++ ){
+			String vId =  trackVoiceID(v, id, "Music") ;
+			this.writer.println(indent(1) + "\\context TabVoice = \"" + vId + "\" {");
+			if(!addChordDiagrams){
+				this.writer.println(indent(2) + "\\removeWithTag #'chords");
+			}
+			if(!addTexts){
+				this.writer.println(indent(2) + "\\removeWithTag #'texts");
+			}
+			this.writer.println(indent(2) + "\\" + vId + " #" + getLilypondBoolean( true ) );
+			this.writer.println(indent(1) + "}");
+			
 		}
-		if(!addTexts){
-			this.writer.println(indent(1) + "\\removeWithTag #'texts");
-		}
-		this.writer.println(indent(1) + "\\" + id + "Music #" + getLilypondBoolean( true ));
 		if(addLyrics){
-			this.writer.println(indent(1) + "\\new Lyrics \\lyricsto \"" + id + "TabStaff\" \\" + id + "Lyrics");
+			this.writer.println(indent(1) + "\\new Lyrics \\lyricsto \"" + trackVoiceID(0, id, "Music") + "\" \\" + id + "Lyrics");
 		}
-		this.writer.println( (addLyrics ? ">>" : "}" ) );
+		this.writer.println(">>");
 	}
 	
 	private void addLyrics(TGTrack track,String id){
@@ -230,17 +281,6 @@ public class LilypondOutputStream {
 		this.writer.println("}");
 	}
 	
-	private void addTuning(TGTrack track, int indent){
-		this.writer.print(indent(indent) + "\\set TabStaff.stringTunings = #'(");
-		Iterator strings = track.getStrings().iterator();
-		while(strings.hasNext()){
-			TGString string = (TGString)strings.next();
-			//Lilypond relates string tuning to MIDI middle C (note 60)
-			this.writer.print( (string.getValue() - 60) + " ");
-		}
-		this.writer.println(")");
-	}
-	
 	private void addStaffGroup(TGTrack track,String id){
 		this.writer.println(id + "StaffGroup = \\new StaffGroup <<");
 		if(this.addTrackTitleOnGroup(track.getSong())){
@@ -255,7 +295,7 @@ public class LilypondOutputStream {
 		this.writer.println(">>");
 	}
 	
-	private void addMeasure(TGMeasure measure,TGMeasure previous,int indent,boolean isLast){
+	private void addMeasure(TGMeasure measure,TGMeasure previous,int voice,int indent,boolean isLast){
 		if(previous == null || measure.getTempo().getValue() != previous.getTempo().getValue()){
 			this.addTempo(measure.getTempo(),indent);
 		}
@@ -271,6 +311,9 @@ public class LilypondOutputStream {
 			this.addTimeSignature(measure.getTimeSignature(),indent);
 		}
 		
+		// Set the specific voice
+		this.addMeasureVoice(measure,voice, (previous == null), indent);
+		
 		// Open repeat
 		if(measure.isRepeatOpen()){
 			this.addRepeatOpen(measure.getHeader(),indent);
@@ -288,7 +331,7 @@ public class LilypondOutputStream {
 			this.addRepeatAlternativeOpen(indent);
 		}
 		
-		this.addMeasureComponents(measure,(this.temp.isRepeatOpen() || this.temp.isRepeatAlternativeOpen() ? (indent + 1): indent));
+		this.addMeasureComponents(measure,voice,(this.temp.isRepeatOpen() || this.temp.isRepeatAlternativeOpen() ? (indent + 1): indent));
 		
 		// If is last alternative, we can close it now
 		if(this.temp.isRepeatAlternativeOpen() && this.temp.getRepeatAlternativeNumber() >= this.temp.getRepeatCount()){
@@ -388,76 +431,111 @@ public class LilypondOutputStream {
 		}
 	}
 	
-	private void addMeasureComponents(TGMeasure measure,int indent){
+	private void addMeasureVoice(TGMeasure measure, int voice , boolean force ,int indent){
+		boolean multipleVoices = hasMultipleVoices(measure);
+		if ( force || multipleVoices != this.temp.isMultipleVoices() ){
+			this.writer.println( indent(indent) + getLilypondVoice( multipleVoices ? voice : -1 ) );
+		}
+		this.temp.setMultipleVoices( multipleVoices );
+	}
+	
+	private void addMeasureComponents(TGMeasure measure,int voice,int indent){
 		this.writer.print(indent(indent));
-		this.addComponents(measure);
+		this.addComponents(measure,voice);
 		this.writer.println();
 	}
 	
-	private void addComponents(TGMeasure measure){
+	private void addComponents(TGMeasure measure,int vIndex){
 		int key = measure.getKeySignature();
 		TGBeat previous = null;
 		
 		for(int i = 0 ; i < measure.countBeats() ; i ++){
 			TGBeat beat = measure.getBeat( i );
-			TGVoice voice = beat.getVoice(0);
-			TGTupleto tupleto = voice.getDuration().getTupleto();
-			
-			if(previous != null && this.temp.isTupletOpen() && !tupleto.isEqual( previous.getVoice(0).getDuration().getTupleto() )){
-				this.writer.print("} ");
-				this.temp.setTupletOpen(false);
+			TGVoice voice = beat.getVoice( vIndex );
+			if( !voice.isEmpty() ){
+				TGDivisionType divisionType = voice.getDuration().getDivision();
+				
+				if(previous != null && this.temp.isDivisionTypeOpen() && !divisionType.isEqual( previous.getVoice(0).getDuration().getDivision() )){
+					this.writer.print("} ");
+					this.temp.setDivisionTypeOpen(false);
+				}
+				
+				if(!this.temp.isDivisionTypeOpen() && !divisionType.isEqual(TGDivisionType.NORMAL)){
+					this.writer.print("\\times " + divisionType.getTimes() + "/" + divisionType.getEnters() + " {");
+					this.temp.setDivisionTypeOpen(true);
+				}
+				
+				this.addBeat(key, beat, voice);
+				
+				previous = beat;
 			}
-			
-			if(!this.temp.isTupletOpen() && !tupleto.isEqual(TGTupleto.NORMAL)){
-				this.writer.print("\\times " + tupleto.getTimes() + "/" + tupleto.getEnters() + " {");
-				this.temp.setTupletOpen(true);
-			}
-			
-			this.addBeat(key, beat);
-			
-			previous = beat;
+		}
+		// It Means that all voice beats are empty 
+		if( previous == null ){
+			this.writer.print("\\skip ");
+			this.addDuration( measure.getTimeSignature().getDenominator() );
+			this.writer.print("*" + measure.getTimeSignature().getNumerator() + " ");
 		}
 		
-		if(this.temp.isTupletOpen()){
+		if(this.temp.isDivisionTypeOpen()){
 			this.writer.print("} ");
-			this.temp.setTupletOpen(false);
+			this.temp.setDivisionTypeOpen(false);
 		}
 	}
 	
-	private void addBeat(int key,TGBeat beat){
-		TGVoice voice = beat.getVoice(0);
+	private void addBeat(int key,TGBeat beat, TGVoice voice){		
 		if(voice.isRestVoice()){
-			this.writer.print("r");
+			boolean skip = false;
+			for( int v = 0 ; v < beat.countVoices() ; v ++ ){
+				if( !skip && v != voice.getIndex() ){
+					TGVoice current = beat.getVoice( v );
+					if(!current.isEmpty() && current.getDuration().isEqual( voice.getDuration() )){
+						skip = (!current.isRestVoice() || current.getIndex() < voice.getIndex());
+					}
+				}
+			}
+			this.writer.print( ( skip ? "\\skip " : "r" ) );
 			this.addDuration( voice.getDuration() );
 		}
 		else{
+			this.addEffectsBeforeBeat(voice);
+			
+			this.writer.print("<");
+			
 			int size = voice.countNotes();
-			if(size > 1){
-				this.writer.print("<");
-			}
 			for(int i = 0 ; i < size ; i ++){
 				TGNote note = voice.getNote(i);
 				
-				int note_value = (beat.getMeasure().getTrack().getString(note.getString()).getValue() + note.getValue());
-				this.addKey(key, note_value);
-				if(!(size > 1)){
-					this.addDuration( voice.getDuration() );
-				}
-				this.addString(note.getString());
+				this.addEffectsBeforeNote(note);
+				
+				this.addKey(key, (beat.getMeasure().getTrack().getString(note.getString()).getValue() + note.getValue()) );
 				if(this.isAnyTiedTo(note)){
 					this.writer.print("~");
 				}
 				
+				this.addString(note.getString());
+				this.addEffectsOnNote(note.getEffect());
+				
 				if(size > 1){
 					this.writer.print(" ");
 				}
 			}
-			if(size > 1){
-				this.writer.print(">");
-				this.addDuration( voice.getDuration() );
-			}
 			
-			if(beat.isChordBeat()){
+			this.writer.print(">");
+			
+			this.addDuration( voice.getDuration() );
+			this.addEffectsOnDuration( voice );
+			this.addEffectsOnBeat( voice );
+		}
+		
+		// Add Chord, if was not previously added in another voice
+		if( beat.isChordBeat() && !voice.isRestVoice() ){
+			boolean skip = false;
+			for( int v = 0 ; v < voice.getIndex() ; v ++ ){
+				TGVoice current = beat.getVoice( v );
+				skip = (skip || ( !current.isEmpty() && !current.isRestVoice() ) );
+			}
+			if( !skip ){
 				this.writer.print("-\\tag #'chords ^\\markup \\fret-diagram #\"");
 				TGChord chord = beat.getChord();
 				for( int i = 0; i < chord.countStrings(); i ++){
@@ -465,28 +543,32 @@ public class LilypondOutputStream {
 				}
 				this.writer.print("\"");
 			}
-			
-			if(beat.isTextBeat()){
+		}
+		
+		// Add Text, if was not previously added in another voice
+		if( beat.isTextBeat() ){
+			boolean skip = false;
+			for( int v = 0 ; v < voice.getIndex() ; v ++ ){
+				skip = (skip || !beat.getVoice( v ).isEmpty() );
+			}
+			if( !skip ){
 				this.writer.print("-\\tag #'texts ^\\markup {\"" + beat.getText().getValue() + "\"}");
 			}
-			
-			if(beat.getMeasure().getTrack().getLyrics().getFrom() > beat.getMeasure().getNumber()){
+		}
+		
+		// Check if it's a lyric beat to skip
+		// For now we only support lyrics for first voice.
+		if( voice.getIndex() == 0 && !voice.isRestVoice() ){
+			if( beat.getMeasure().getTrack().getLyrics().getFrom() > beat.getMeasure().getNumber()){
 				this.temp.addSkippedLyricBeat( getLilypondDuration(voice.getDuration()));
 			}
-			
-			this.writer.print(" ");
 		}
+		
+		this.writer.print(" ");
 	}
 	
-	private void addKey(int key,int value){
-		String[] LILYPOND_NOTES = (key <= 7 ? LILYPOND_SHARP_NOTES : LILYPOND_FLAT_NOTES );
-		this.writer.print(LILYPOND_NOTES[ value % 12 ]);
-		for(int i = 4; i < (value / 12); i ++){
-			this.writer.print("'");
-		}
-		for(int i = (value / 12); i < 4; i ++){
-			this.writer.print(",");
-		}
+	private void addKey(int keySignature,int value){
+		this.writer.print( getLilypondKey(keySignature, value) );
 	}
 	
 	private void addString(int string){
@@ -497,6 +579,115 @@ public class LilypondOutputStream {
 		this.writer.print(getLilypondDuration(duration));
 	}
 	
+	private void addEffectsBeforeNote(TGNote note){
+		TGNoteEffect effect = note.getEffect();
+		if( effect.isDeadNote() ){
+			this.writer.print("\\deadNote ");
+		}
+		if( effect.isPalmMute() ){
+			this.writer.print("\\palmMute ");
+		}
+		if( effect.isGhostNote() ){
+			this.writer.print("\\parenthesize ");
+		}
+		if( effect.isBend() ){
+			this.writer.print("\\bendAfter #+6 ");
+		}
+	}
+	
+	private void addEffectsOnNote(TGNoteEffect effect){
+		if( effect.isHarmonic() ){
+			this.writer.print("\\harmonic");
+		}
+	}
+	
+	private void addEffectsOnDuration(TGVoice voice){
+		int tremoloPicking = -1;
+		for( int i = 0 ; i < voice.countNotes() ; i ++ ){
+			TGNote note = voice.getNote(i);
+			if( tremoloPicking == -1 && note.getEffect().isTremoloPicking() ){
+				tremoloPicking = note.getEffect().getTremoloPicking().getDuration().getValue();
+			}
+		}
+		if( tremoloPicking != -1 ){
+			this.writer.print(":" + tremoloPicking );
+		}
+	}
+	
+	private void addEffectsOnBeat(TGVoice voice){
+		boolean trill = false;
+		boolean vibrato = false;
+		boolean staccato = false;
+		boolean accentuatedNote = false;
+		boolean heavyAccentuatedNote = false;
+		boolean arpeggio = ( voice.getBeat().getStroke().getDirection() != TGStroke.STROKE_NONE );
+		for( int i = 0 ; i < voice.countNotes() ; i ++ ){
+			TGNoteEffect effect = voice.getNote(i).getEffect();
+			
+			trill = (trill || effect.isTrill() );
+			vibrato = (vibrato || effect.isVibrato() );
+			staccato = (staccato || effect.isStaccato() );
+			accentuatedNote = (accentuatedNote || effect.isAccentuatedNote() );
+			heavyAccentuatedNote = (heavyAccentuatedNote || effect.isHeavyAccentuatedNote() );
+		}
+		if( trill ){
+			this.writer.print("\\trill");
+		}
+		if( vibrato ){
+			this.writer.print("\\prall");
+		}
+		if( staccato ){
+			this.writer.print("\\staccato");
+		}
+		if( accentuatedNote ){
+			this.writer.print("->");
+		}
+		if( heavyAccentuatedNote ){
+			this.writer.print("-^");
+		}
+		if( arpeggio ){
+			this.writer.print("\\arpeggio");
+		}
+	}
+	
+	private void addEffectsBeforeBeat(TGVoice voice){
+		List graceNotes = new ArrayList();
+		for( int i = 0 ; i < voice.countNotes() ; i ++ ){
+			TGNote note = voice.getNote(i);
+			if( note.getEffect().isGrace() ){
+				graceNotes.add( note );
+			}
+		}
+		if( !graceNotes.isEmpty() ){
+			this.writer.print("\\grace ");
+			this.writer.print("<");
+			
+			int duration = 0;
+			for( int i = 0 ; i < graceNotes.size() ; i ++ ){
+				TGNote note = (TGNote)graceNotes.get( i );
+				TGMeasure measure = voice.getBeat().getMeasure();
+				TGString string = measure.getTrack().getString(note.getString());
+				TGEffectGrace grace = note.getEffect().getGrace();
+				
+				if( duration < TGDuration.SIXTY_FOURTH && grace.getDuration() == 1 ){
+					duration = TGDuration.SIXTY_FOURTH;
+				}else if( duration < TGDuration.THIRTY_SECOND && grace.getDuration() == 2 ){
+					duration = TGDuration.THIRTY_SECOND;
+				}else if( duration < TGDuration.SIXTEENTH && grace.getDuration() == 3 ){
+					duration = TGDuration.SIXTEENTH;
+				}
+				if( i > 0 ){
+					this.writer.print(" ");
+				}
+				this.addKey(measure.getKeySignature(), (string.getValue() + grace.getFret()) );
+				this.addString(note.getString());
+			}
+			this.writer.print(">");
+			this.writer.print(duration);
+			this.writer.print(" ");
+		}
+	}
+	
 	private void checkRepeatCount(TGMeasureHeader header){
 		boolean alternativePresent = false;
 		TGMeasureHeader next = header;
@@ -515,6 +706,36 @@ public class LilypondOutputStream {
 		}
 	}
 	
+	private boolean hasMultipleVoices( TGMeasure measure ){
+		int voiceCount = 0;
+		for( int voice = 0 ; voice < TGBeat.MAX_VOICES ; voice ++ ){
+			if( isVoiceAvailable(measure, voice) ){
+				voiceCount ++;
+			}
+		}
+		return (voiceCount > 1);
+	}
+	
+	private boolean isVoiceAvailable( TGMeasure measure , int voice ){
+		for( int i = 0 ; i < measure.countBeats() ; i ++ ){
+			TGBeat beat = measure.getBeat( i );
+			if( !beat.getVoice( voice ).isEmpty() ){
+				return true;
+			}
+		}
+		return false;
+	}
+	
+	private boolean isVoiceAvailable( TGTrack track , int voice ){
+		for( int i = 0 ; i < track.countMeasures() ; i ++ ){
+			TGMeasure measure = track.getMeasure( i );
+			if( isVoiceAvailable(measure, voice) ){
+				return true;
+			}
+		}
+		return false;
+	}
+	
 	private boolean addTrackTitleOnGroup(TGSong song){
 		if(this.settings.isTrackNameEnabled() && this.settings.isTrackGroupEnabled()){
 			if(this.settings.getTrack() == LilypondSettings.ALL_TRACKS && song.countTracks() > 1){
@@ -565,6 +786,18 @@ public class LilypondOutputStream {
 		return (value ? "#t" : "#f");
 	}
 	
+	private String getLilypondKey(int keySignature , int value){
+		String[] LILYPOND_NOTES = (keySignature <= 7 ? LILYPOND_SHARP_NOTES : LILYPOND_FLAT_NOTES );
+		String key = (LILYPOND_NOTES[ value % 12 ]);
+		for(int i = 4; i < (value / 12); i ++){
+			key += ("'");
+		}
+		for(int i = (value / 12); i < 4; i ++){
+			key += (",");
+		}
+		return key;
+	}
+	
 	private String getLilypondDuration(TGDuration value){
 		String duration = Integer.toString(value.getValue());
 		if(value.isDotted()){
@@ -586,6 +819,25 @@ public class LilypondOutputStream {
 		return Integer.toString(value);
 	}
 	
+	private String getLilypondTuning(TGTrack track){
+		String tuning = ("\\with { stringTunings = #'( ");
+		Iterator strings = track.getStrings().iterator();
+		while(strings.hasNext()){
+			TGString string = (TGString)strings.next();
+			//Lilypond relates string tuning to MIDI middle C (note 60)
+			tuning += ( (string.getValue() - 60) + " ");
+		}
+		tuning += (") }");
+		return tuning;
+	}
+	
+	private String getLilypondVoice(int voice){
+		if( voice == -1 ){
+			return "\\oneVoice";
+		}
+		return ( voice == 0 ? "\\voiceOne" : "\\voiceTwo" );
+	}
+	
 	private String toBase26(int value){
 		String result = new String();
 		int base = value;
@@ -597,17 +849,21 @@ public class LilypondOutputStream {
 	}
 	
 	private String trackID(int index, String suffix){
-		//Lilypond identifiers must be alphabetic. Base26 of the track index is used for uniqueness.
 		return ("Track" + this.toBase26(index) + suffix);
 	}
 	
+	private String trackVoiceID(int index, String prefix, String suffix){
+		return (prefix + "Voice" + this.toBase26(index) + suffix);
+	}
+	
 	protected class LilypondTempData{
 		
 		private int repeatCount;
 		private int repeatAlternativeNumber;
 		private boolean repeatOpen;
 		private boolean repeatAlternativeOpen;
-		private boolean tupletOpen;
+		private boolean divisionTypeOpen;
+		private boolean multipleVoices;
 		private List skippedLyricBeats;
 		
 		protected LilypondTempData(){
@@ -616,9 +872,10 @@ public class LilypondOutputStream {
 		}
 		
 		public void reset(){
+			this.multipleVoices = false;
 			this.repeatCount = 0;
 			this.repeatOpen = false;
-			this.tupletOpen = false;
+			this.divisionTypeOpen = false;
 			this.skippedLyricBeats.clear();
 		}
 		
@@ -654,12 +911,20 @@ public class LilypondOutputStream {
 			this.repeatAlternativeOpen = repeatAlternativeOpen;
 		}
 		
-		public boolean isTupletOpen() {
-			return this.tupletOpen;
+		public boolean isDivisionTypeOpen() {
+			return this.divisionTypeOpen;
 		}
 		
-		public void setTupletOpen(boolean tupletOpen) {
-			this.tupletOpen = tupletOpen;
+		public void setDivisionTypeOpen(boolean divisionTypeOpen) {
+			this.divisionTypeOpen = divisionTypeOpen;
+		}
+		
+		public void setMultipleVoices( boolean multipleVoices ){
+			this.multipleVoices = multipleVoices;
+		}
+		
+		public boolean isMultipleVoices() {
+			return this.multipleVoices;
 		}
 		
 		public void addSkippedLyricBeat( String duration ){
@@ -670,117 +935,4 @@ public class LilypondOutputStream {
 			return this.skippedLyricBeats;
 		}
 	}
-	
-	public class TGVoiceJoiner {
-		private TGFactory factory;
-		private TGMeasure measure;
-		
-		public TGVoiceJoiner(TGFactory factory,TGMeasure measure){
-			this.factory = factory;
-			this.measure = measure.clone(factory, measure.getHeader());
-			this.measure.setTrack( measure.getTrack() );
-		}
-		
-		public TGMeasure process(){
-			this.orderBeats();
-			this.joinBeats();
-			return this.measure;
-		}
-		
-		public void joinBeats(){
-			TGBeat previous = null;
-			boolean finish = true;
-			
-			long measureStart = this.measure.getStart();
-			long measureEnd = (measureStart + this.measure.getLength());
-			for(int i = 0;i < this.measure.countBeats();i++){
-				TGBeat beat = this.measure.getBeat( i );
-				TGVoice voice = beat.getVoice(0);
-				for(int v = 1; v < beat.countVoices(); v++ ){
-					TGVoice currentVoice = beat.getVoice(v);
-					if(!currentVoice.isEmpty()){
-						for(int n = 0 ; n < currentVoice.countNotes() ; n++ ){
-							TGNote note = currentVoice.getNote( n );
-							voice.addNote( note );
-						}
-					}
-				}
-				if( voice.isEmpty() ){
-					this.measure.removeBeat(beat);
-					finish = false;
-					break;
-				}
-				
-				long beatStart = beat.getStart();
-				if(previous != null){
-					long previousStart = previous.getStart();
-					
-					TGDuration previousBestDuration = null;
-					for(int v = /*1*/0; v < previous.countVoices(); v++ ){
-						TGVoice previousVoice = previous.getVoice(v);
-						if(!previousVoice.isEmpty()){
-							long length = previousVoice.getDuration().getTime();
-							if( (previousStart + length) <= beatStart){
-								if( previousBestDuration == null || length > previousBestDuration.getTime() ){
-									previousBestDuration = previousVoice.getDuration();
-								}
-							}
-						}
-					}
-					
-					if(previousBestDuration != null){
-						previousBestDuration.copy( previous.getVoice(0).getDuration() );
-					}else{
-						if(voice.isRestVoice()){
-							this.measure.removeBeat(beat);
-							finish = false;
-							break;
-						}
-						TGDuration duration = TGDuration.fromTime(this.factory, (beatStart - previousStart) );
-						duration.copy( previous.getVoice(0).getDuration() );
-					}
-				}
-				
-				TGDuration beatBestDuration = null;
-				for(int v = /*1*/0; v < beat.countVoices(); v++ ){
-					TGVoice currentVoice = beat.getVoice(v);
-					if(!currentVoice.isEmpty()){
-						long length = currentVoice.getDuration().getTime();
-						if( (beatStart + length) <= measureEnd ){
-							if( beatBestDuration == null || length > beatBestDuration.getTime() ){
-								beatBestDuration = currentVoice.getDuration();
-							}
-						}
-					}
-				}
-				
-				if(beatBestDuration == null){
-					if(voice.isRestVoice()){
-						this.measure.removeBeat(beat);
-						finish = false;
-						break;
-					}
-					TGDuration duration = TGDuration.fromTime(this.factory, (measureEnd - beatStart) );
-					duration.copy( voice.getDuration() );
-				}
-				previous = beat;
-			}
-			if(!finish){
-				joinBeats();
-			}
-		}
-		
-		public void orderBeats(){
-			for(int i = 0;i < this.measure.countBeats();i++){
-				TGBeat minBeat = null;
-				for(int j = i;j < this.measure.countBeats();j++){
-					TGBeat beat = this.measure.getBeat(j);
-					if(minBeat == null || beat.getStart() < minBeat.getStart()){
-						minBeat = beat;
-					}
-				}
-				this.measure.moveBeat(i, minBeat);
-			}
-		}
-	}
 }
