@@ -7,7 +7,7 @@ import java.util.Iterator;
 
 import org.herac.tuxguitar.io.base.TGFileFormat;
 import org.herac.tuxguitar.io.base.TGFileFormatException;
-import org.herac.tuxguitar.io.base.TGSongImporter;
+import org.herac.tuxguitar.io.base.TGLocalFileImporter;
 import org.herac.tuxguitar.io.tef.base.TEChord;
 import org.herac.tuxguitar.io.tef.base.TEComponent;
 import org.herac.tuxguitar.io.tef.base.TEComponentChord;
@@ -28,9 +28,9 @@ import org.herac.tuxguitar.song.models.TGSong;
 import org.herac.tuxguitar.song.models.TGString;
 import org.herac.tuxguitar.song.models.TGTimeSignature;
 import org.herac.tuxguitar.song.models.TGTrack;
-import org.herac.tuxguitar.song.models.TGTupleto;
+import org.herac.tuxguitar.song.models.TGDivisionType;
 
-public class TESongImporter implements TGSongImporter{
+public class TESongImporter implements TGLocalFileImporter{
 	
 	private static final int[][] PERCUSSION_TUNINGS = new int[][]{
 		new int[]{ 49, 41, 32 },
@@ -41,6 +41,7 @@ public class TESongImporter implements TGSongImporter{
 	};
 	
 	protected TGSongManager manager;
+	protected InputStream stream;
 	
 	public TESongImporter(){
 		super();
@@ -58,10 +59,16 @@ public class TESongImporter implements TGSongImporter{
 		return true;
 	}
 	
-	public TGSong importSong(TGFactory factory,InputStream stream) throws TGFileFormatException {
+	public void init(TGFactory factory,InputStream stream) {
+		this.manager = new TGSongManager(factory);
+		this.stream = stream;
+	}
+	
+	public TGSong importSong() throws TGFileFormatException {
 		try {
-			this.manager = new TGSongManager(factory);
-			return this.parseSong(new TEInputStream(stream).readSong());
+			if( this.manager != null && this.stream != null ){
+				return this.parseSong(new TEInputStream(this.stream).readSong());
+			}
 		} catch (Exception e) {
 			e.printStackTrace();
 		}
@@ -108,7 +115,7 @@ public class TESongImporter implements TGSongImporter{
 			track.getChannel().setBalance((short)(( tracks[i].getPan() * 127) / 15));
 			track.getChannel().setInstrument((short)tracks[i].getInstrument());
 			if(tracks[i].isPercussion()){
-				TGChannel.setPercusionChannel(track.getChannel());
+				TGChannel.setPercussionChannel(track.getChannel());
 			}
 			track.getStrings().clear();
 			int strings[] = tracks[i].getStrings();
@@ -164,7 +171,7 @@ public class TESongImporter implements TGSongImporter{
 	
 	private long getStart(TGDuration duration, TGMeasure measure,int position){
 		float fixedPosition = position;
-		if(duration != null && !duration.getTupleto().isEqual(TGTupleto.NORMAL)){
+		if(duration != null && !duration.getDivision().isEqual(TGDivisionType.NORMAL)){
 			fixedPosition = (( fixedPosition - (fixedPosition % 64)) + ((((fixedPosition % 64) * 2) * 2) / 3) );
 		}
 		long start = ((long) (measure.getStart() + ( (fixedPosition * TGDuration.QUARTER_TIME)  / 64)) );
@@ -184,8 +191,8 @@ public class TESongImporter implements TGSongImporter{
 			tgDuration.setDotted(true);
 		}
 		else if( (duration % 3) == 2){
-			tgDuration.getTupleto().setEnters(3);
-			tgDuration.getTupleto().setTimes(2);
+			tgDuration.getDivision().setEnters(3);
+			tgDuration.getDivision().setTimes(2);
 		}
 		tgDuration.setValue(value);
 		
