@@ -11,6 +11,7 @@ import java.net.URL;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.MouseAdapter;
 import org.eclipse.swt.events.MouseEvent;
+import org.eclipse.swt.events.MouseTrackAdapter;
 import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.layout.FormAttachment;
@@ -56,6 +57,7 @@ import org.herac.tuxguitar.gui.table.TGTableViewer;
 import org.herac.tuxguitar.gui.tools.browser.dialog.TGBrowserDialog;
 import org.herac.tuxguitar.gui.tools.scale.ScaleManager;
 import org.herac.tuxguitar.gui.transport.TGTransport;
+import org.herac.tuxguitar.gui.transport.TGTransportListener;
 import org.herac.tuxguitar.gui.undo.UndoableManager;
 import org.herac.tuxguitar.gui.util.ArgumentParser;
 import org.herac.tuxguitar.gui.util.TGFileUtils;
@@ -159,7 +161,7 @@ public class TuxGuitar {
 	
 	private void initSynchronizer(){
 		TGSynchronizer.instance().setController(new TGSynchronizer.TGSynchronizerController() {
-			public void excecute(final TGSynchronizer.TGSynchronizerTask task) {
+			public void execute(final TGSynchronizer.TGSynchronizerTask task) {
 				final Display display = getDisplay();
 				if(display != null && !display.isDisposed()){
 					display.syncExec(new Runnable() {
@@ -170,7 +172,7 @@ public class TuxGuitar {
 				}
 			}
 			
-			public void excecuteLater(final TGSynchronizer.TGSynchronizerTask task) {
+			public void executeLater(final TGSynchronizer.TGSynchronizerTask task) {
 				final Display display = getDisplay();
 				if(display != null && !display.isDisposed()){
 					display.asyncExec(new Runnable() {
@@ -259,39 +261,50 @@ public class TuxGuitar {
 	}
 	
 	public void createComposites(Composite composite) {
-		this.sashComposite = new Composite(composite,SWT.NONE);
-		this.sashComposite.setLayout(new FormLayout());
 		FormData data = new FormData();
 		data.left = new FormAttachment(0,0);
 		data.right = new FormAttachment(100,0);
 		data.top = new FormAttachment(getItemManager().getCoolbar(),MARGIN_WIDTH);
 		data.bottom = new FormAttachment(100,0);
+		this.sashComposite = new Composite(composite,SWT.NONE);
+		this.sashComposite.setLayout(new FormLayout());
 		this.sashComposite.setLayoutData(data);
 		
-		this.sash = new Sash(this.sashComposite, SWT.HORIZONTAL);
 		data = new FormData();
 		data.left = new FormAttachment(0,0);
 		data.right = new FormAttachment(100,0);
 		data.bottom = new FormAttachment(100,-150);
-		
+		data.height = MARGIN_WIDTH;
+		this.sash = new Sash(this.sashComposite, SWT.HORIZONTAL);
 		this.sash.setLayoutData(data);
 		
-		getTablatureEditor().showTablature(this.sashComposite);
 		data = new FormData();
 		data.left = new FormAttachment(0,0);
 		data.right = new FormAttachment(100,0);
 		data.top = new FormAttachment(0,0);
 		data.bottom = new FormAttachment(this.sash, 0);
+		getTablatureEditor().showTablature(this.sashComposite);
 		getTablatureEditor().getTablature().setLayoutData(data);
 		
-		getTable().init(this.sashComposite);
 		data = new FormData();
 		data.left = new FormAttachment(0,0);
 		data.right = new FormAttachment(100,0);
-		data.top = new FormAttachment(this.sash,10);
+		data.top = new FormAttachment(this.sash,0);
 		data.bottom = new FormAttachment(100,0);
+		getTable().init(this.sashComposite);
 		getTable().getComposite().setLayoutData(data);
 		
+		data = new FormData();
+		data.left = new FormAttachment(0,0);
+		data.right = new FormAttachment(100,0);
+		data.top = new FormAttachment(this.sashComposite,0);
+		data.bottom = new FormAttachment(100,0);
+		
+		Composite footer = new Composite(composite,SWT.NONE);
+		footer.setLayout(new FormLayout());
+		footer.setLayoutData(data);
+		getFretBoardEditor().showFretBoard(footer);
+		
 		this.sash.addMouseListener(new MouseAdapter() {
 			public void mouseUp(MouseEvent e) {
 				TuxGuitar.this.sashComposite.layout(true,true);
@@ -306,6 +319,11 @@ public class TuxGuitar {
 				((FormData) TuxGuitar.this.sash.getLayoutData()).bottom = new FormAttachment(100, -height);
 			}
 		});
+		this.sash.addMouseTrackListener(new MouseTrackAdapter() {
+			public void mouseEnter(MouseEvent e) {
+				TuxGuitar.this.sash.setCursor( getDisplay().getSystemCursor( SWT.CURSOR_SIZENS ) );
+			}
+		});
 		this.sashComposite.addListener(SWT.Resize, new Listener() {
 			public void handleEvent(Event arg0) {
 				FormData data = ((FormData) TuxGuitar.this.sash.getLayoutData());
@@ -316,17 +334,6 @@ public class TuxGuitar {
 				}
 			}
 		});
-		
-		data = new FormData();
-		data.left = new FormAttachment(0,0);
-		data.right = new FormAttachment(100,0);
-		data.top = new FormAttachment(this.sashComposite,0);
-		data.bottom = new FormAttachment(100,0);
-		
-		Composite footer = new Composite(composite,SWT.NONE);
-		footer.setLayout(new FormLayout());
-		footer.setLayoutData(data);
-		getFretBoardEditor().showFretBoard(footer);
 	}
 	
 	public void restoreControlsConfig(){
@@ -395,17 +402,17 @@ public class TuxGuitar {
 		int offset = ((FormData) getTable().getComposite().getLayoutData()).top.offset;
 		int sashHeight = this.sash.getBounds().height;
 		int maximumHeight = (this.sashComposite.getBounds().height - sashHeight);
-		int height = (value + sashHeight + offset);
+		int height = (value + offset);
 		height = Math.max( height,0);
 		height = Math.min( height,maximumHeight);
 		((FormData) TuxGuitar.this.sash.getLayoutData()).bottom = new FormAttachment(100, -height);
 		this.sashComposite.layout(true,true);
 	}
 	
-	public void updateShellFooter(int offset,int minimunWith,int minimunHeight){
+	public void updateShellFooter(int offset,int minimumWith,int minimumHeight){
 		FormData data = ((FormData)this.sashComposite.getLayoutData());
 		data.bottom.offset = -offset;
-		getShell().setMinimumSize(Math.max(640,minimunWith),Math.max(480,minimunHeight));
+		getShell().setMinimumSize(Math.max(640,minimumWith),Math.max(480,minimumHeight));
 		getShell().layout(true,true);
 		getShell().redraw();
 	}
@@ -584,6 +591,7 @@ public class TuxGuitar {
 		if(this.player == null){
 			this.player = new MidiPlayer();
 			this.player.init(getSongManager());
+			this.player.addListener( new TGTransportListener() );
 			try {
 				getPlayer().addSequencerProvider(new MidiSequencerProviderImpl(), false);
 			} catch (MidiPlayerException e) {
@@ -639,7 +647,7 @@ public class TuxGuitar {
 		}
 	}
 	
-	public void redrawPayingMode(){
+	public void redrawPlayingMode(){
 		if(!isDisposed() && !this.isLocked()){
 			this.lock();
 			this.getEditorCache().updatePlayMode();
@@ -732,6 +740,7 @@ public class TuxGuitar {
 		TuxGuitar.instance().getSongManager().setSong(song);
 		getFileHistory().reset(url);
 		getPlayer().reset();
+		getPlayer().getMode().clear();
 		getEditorCache().reset();
 		getUndoableManager().discardAllEdits();
 		getEditorManager().doUpdate( TGUpdateListener.SONG_LOADED );
@@ -748,6 +757,7 @@ public class TuxGuitar {
 		getFileHistory().reset(url);
 		getEditorCache().reset();
 		getUndoableManager().discardAllEdits();
+		getEditorManager().doUpdate( TGUpdateListener.SONG_SAVED );
 		
 		this.unlock();
 		
