@@ -24,7 +24,7 @@ import org.herac.tuxguitar.gui.actions.composition.ChangeTimeSignatureAction;
 import org.herac.tuxguitar.gui.actions.composition.ChangeTripletFeelAction;
 import org.herac.tuxguitar.gui.actions.duration.ChangeDottedDurationAction;
 import org.herac.tuxguitar.gui.actions.duration.ChangeDoubleDottedDurationAction;
-import org.herac.tuxguitar.gui.actions.duration.ChangeTupletoDurationAction;
+import org.herac.tuxguitar.gui.actions.duration.ChangeDivisionTypeAction;
 import org.herac.tuxguitar.gui.actions.duration.DecrementDurationAction;
 import org.herac.tuxguitar.gui.actions.duration.IncrementDurationAction;
 import org.herac.tuxguitar.gui.actions.duration.SetEighthDurationAction;
@@ -107,6 +107,9 @@ import org.herac.tuxguitar.gui.actions.note.CleanBeatAction;
 import org.herac.tuxguitar.gui.actions.note.DecrementNoteSemitoneAction;
 import org.herac.tuxguitar.gui.actions.note.IncrementNoteSemitoneAction;
 import org.herac.tuxguitar.gui.actions.note.InsertNoteAction;
+import org.herac.tuxguitar.gui.actions.note.MoveBeatsCustomAction;
+import org.herac.tuxguitar.gui.actions.note.MoveBeatsLeftAction;
+import org.herac.tuxguitar.gui.actions.note.MoveBeatsRightAction;
 import org.herac.tuxguitar.gui.actions.note.RemoveNoteAction;
 import org.herac.tuxguitar.gui.actions.note.RemoveUnusedVoiceAction;
 import org.herac.tuxguitar.gui.actions.note.SetStrokeDownAction;
@@ -122,6 +125,7 @@ import org.herac.tuxguitar.gui.actions.settings.EditPluginsAction;
 import org.herac.tuxguitar.gui.actions.system.DisposeAction;
 import org.herac.tuxguitar.gui.actions.tools.ScaleAction;
 import org.herac.tuxguitar.gui.actions.tools.TGBrowserAction;
+import org.herac.tuxguitar.gui.actions.tools.TransposeAction;
 import org.herac.tuxguitar.gui.actions.track.AddTrackAction;
 import org.herac.tuxguitar.gui.actions.track.CloneTrackAction;
 import org.herac.tuxguitar.gui.actions.track.EditLyricsAction;
@@ -137,6 +141,8 @@ import org.herac.tuxguitar.gui.actions.track.TrackPropertiesAction;
 import org.herac.tuxguitar.gui.actions.transport.TransportMetronomeAction;
 import org.herac.tuxguitar.gui.actions.transport.TransportModeAction;
 import org.herac.tuxguitar.gui.actions.transport.TransportPlayAction;
+import org.herac.tuxguitar.gui.actions.transport.TransportSetLoopEHeaderAction;
+import org.herac.tuxguitar.gui.actions.transport.TransportSetLoopSHeaderAction;
 import org.herac.tuxguitar.gui.actions.transport.TransportStopAction;
 import org.herac.tuxguitar.gui.actions.view.ShowFretBoardAction;
 import org.herac.tuxguitar.gui.actions.view.ShowMatrixAction;
@@ -245,6 +251,9 @@ public class ActionManager {
 		addAction(new DecrementNoteSemitoneAction());
 		addAction(new SetStrokeUpAction());
 		addAction(new SetStrokeDownAction());
+		addAction(new MoveBeatsRightAction());
+		addAction(new MoveBeatsLeftAction());
+		addAction(new MoveBeatsCustomAction());
 		
 		//duration actions
 		addAction(new SetWholeDurationAction());
@@ -256,7 +265,7 @@ public class ActionManager {
 		addAction(new SetSixtyFourthDurationAction());
 		addAction(new ChangeDottedDurationAction());
 		addAction(new ChangeDoubleDottedDurationAction());
-		addAction(new ChangeTupletoDurationAction());
+		addAction(new ChangeDivisionTypeAction());
 		addAction(new IncrementDurationAction());
 		addAction(new DecrementDurationAction());
 		
@@ -304,6 +313,8 @@ public class ActionManager {
 		addAction(new TransportStopAction());
 		addAction(new TransportMetronomeAction());
 		addAction(new TransportModeAction());
+		addAction(new TransportSetLoopSHeaderAction());
+		addAction(new TransportSetLoopEHeaderAction());
 		
 		//setting actions
 		addAction(new EditPluginsAction());
@@ -321,6 +332,7 @@ public class ActionManager {
 		addAction(new ShowAboutAction());
 		
 		//tools
+		addAction(new TransposeAction() );
 		addAction(new ScaleAction());
 		addAction(new TGBrowserAction());
 		
