@@ -146,17 +146,10 @@ public class FretBoard extends Composite {
 		this.handSelector = new Combo(this.toolComposite, SWT.DROP_DOWN | SWT.READ_ONLY);
 		this.handSelector.add(TuxGuitar.getProperty("fretboard.right-mode"));
 		this.handSelector.add(TuxGuitar.getProperty("fretboard.left-mode"));
-		this.handSelector.select(0);
+		this.handSelector.select( this.getDirection(this.config.getDirection()) );
 		this.handSelector.addSelectionListener(new SelectionAdapter() {
 			public void widgetSelected(SelectionEvent e) {
-				int index = FretBoard.this.handSelector.getSelectionIndex();
-				if (index == 0) {
-					initFrets(10, 1);
-				} else {
-					initFrets(10, 2);
-				}
-				setChanges(true);
-				FretBoard.this.fretBoardComposite.redraw();
+				updateDirection(FretBoard.this.handSelector.getSelectionIndex());
 			}
 		});
 		
@@ -243,15 +236,16 @@ public class FretBoard extends Composite {
 		}
 	}
 	
-	protected void initFrets(int fromX, int hand) {
+	protected void initFrets(int fromX) {
 		this.frets = new int[MAX_FRETS];
 		int nextX = fromX;
-		if (hand == 1) {
+		int direction = this.getDirection(this.config.getDirection());
+		if (direction == FretBoardConfig.DIRECTION_RIGHT) {
 			for (int i = 0; i < this.frets.length; i++) {
 				this.frets[i] = nextX;
 				nextX += (this.fretSpacing - ((i + 1) * 2));
 			}
-		} else if (hand == 2) {
+		} else if (direction == FretBoardConfig.DIRECTION_LEFT) {
 			for (int i = this.frets.length - 1; i >= 0; i--) {
 				this.frets[i] = nextX;
 				nextX += (this.fretSpacing - (i * 2));
@@ -259,6 +253,14 @@ public class FretBoard extends Composite {
 		}
 	}
 	
+	private int getDirection( int value ){
+		int direction = value;
+		if( direction != FretBoardConfig.DIRECTION_RIGHT && direction != FretBoardConfig.DIRECTION_LEFT ){
+			direction = FretBoardConfig.DIRECTION_RIGHT;
+		}
+		return direction;
+	}
+	
 	private void initStrings(int count) {
 		int fromY = TOP_SPACING;
 		this.strings = new int[count];
@@ -289,7 +291,7 @@ public class FretBoard extends Composite {
 			int clientHeight = getClientArea().height;
 			
 			if(this.lastSize.x != clientWidth || hasChanges()){
-				this.layout(getClientArea().width,this.handSelector.getSelectionIndex() + 1);
+				this.layout(getClientArea().width);
 			}
 			
 			if(this.lastSize.y != clientHeight){
@@ -331,8 +333,8 @@ public class FretBoard extends Composite {
 				if(i > 2){
 					painterBuffer.setLineWidth(2);
 				}
-				//painterBuffer.drawLine(this.frets[0], this.strings[i], this.frets[this.frets.length - 1], this.strings[i]);
 				painterBuffer.initPath();
+				painterBuffer.setAntialias(false);
 				painterBuffer.moveTo(this.frets[0], this.strings[i]);
 				painterBuffer.lineTo(this.frets[this.frets.length - 1], this.strings[i]);
 				painterBuffer.closePath();
@@ -373,7 +375,6 @@ public class FretBoard extends Composite {
 	}
 	
 	private void paintScale(TGPainter painter) {
-		//TGTrack track = TuxGuitar.instance().getTablatureEditor().getTablature().getCaret().getTrack();
 		TGTrack track = getTrack();
 		
 		for (int i = 0; i < this.strings.length; i++) {
@@ -403,7 +404,6 @@ public class FretBoard extends Composite {
 	
 	private void paintNotes(TGPainter painter) {
 		if(this.beat != null){
-			//TGTrack track = TuxGuitar.instance().getTablatureEditor().getTablature().getCaret().getTrack();
 			TGTrack track = getTrack();
 			
 			for(int v = 0; v < this.beat.countVoices(); v ++){
@@ -594,6 +594,13 @@ public class FretBoard extends Composite {
 		TuxGuitar.instance().updateCache(true);
 	}
 	
+	protected void updateDirection( int direction ){
+		this.config.saveDirection( this.getDirection(direction) );
+		this.initFrets(10);
+		this.setChanges(true);
+		this.fretBoardComposite.redraw();
+	}
+	
 	public boolean hasChanges(){
 		return this.changes;
 	}
@@ -647,7 +654,7 @@ public class FretBoard extends Composite {
 		this.settings.setImage(TuxGuitar.instance().getIconManager().getSettings());
 		this.loadDurationImage(true);
 		this.layout(true,true);
-		this.layout(getClientArea().width,this.handSelector.getSelectionIndex() + 1);
+		this.layout(getClientArea().width);
 	}
 	
 	public void loadScale(){
@@ -670,16 +677,17 @@ public class FretBoard extends Composite {
 		super.layout();
 	}
 	
-	public void layout(int width,int hand){
+	public void layout(int width){
 		this.disposeFretBoardImage();
 		this.calculateFretSpacing(width);
-		this.initFrets(10,hand);
+		this.initFrets(10);
 		this.initStrings(getStringCount());
 		this.setChanges(false);
 	}
 	
 	protected void configure(){
 		this.config.configure(getShell());
+		this.handSelector.select( this.getDirection(this.config.getDirection()) );
 		this.setChanges(true);
 		this.redraw();
 	}
