@@ -15,13 +15,13 @@ import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.graphics.RGB;
 import org.herac.tuxguitar.gui.TuxGuitar;
 import org.herac.tuxguitar.gui.editors.TGPainter;
-import org.herac.tuxguitar.gui.editors.tab.layout.TrackSpacing;
 import org.herac.tuxguitar.gui.editors.tab.layout.ViewLayout;
 import org.herac.tuxguitar.gui.editors.tab.painters.TGClefPainter;
 import org.herac.tuxguitar.gui.editors.tab.painters.TGKeySignaturePainter;
 import org.herac.tuxguitar.gui.editors.tab.painters.TGTempoPainter;
 import org.herac.tuxguitar.gui.editors.tab.painters.TGTripletFeelPainter;
 import org.herac.tuxguitar.gui.helper.SyncThread;
+import org.herac.tuxguitar.player.base.MidiPlayerMode;
 import org.herac.tuxguitar.song.managers.TGSongManager;
 import org.herac.tuxguitar.song.models.TGBeat;
 import org.herac.tuxguitar.song.models.TGChord;
@@ -29,8 +29,7 @@ import org.herac.tuxguitar.song.models.TGColor;
 import org.herac.tuxguitar.song.models.TGDuration;
 import org.herac.tuxguitar.song.models.TGMeasure;
 import org.herac.tuxguitar.song.models.TGMeasureHeader;
-import org.herac.tuxguitar.song.models.TGNoteEffect;
-import org.herac.tuxguitar.song.models.TGTupleto;
+import org.herac.tuxguitar.song.models.TGDivisionType;
 
 /**
  * @author julian
@@ -70,9 +69,19 @@ public class TGMeasureImpl extends TGMeasure{
 	
 	public static final int SCORE_KEY_OFFSETS[] = new int[]{30,18,22,24};
 	
-	public static final int SCORE_KEY_SHARP_POSITIONS[] = new int[]{ 1 , 4, 0, 3, 6, 2 , 5 };
+	public static final int SCORE_KEY_SHARP_POSITIONS[][] = new int[][]{ 
+		new int[] { 1 , 4, 0, 3, 6, 2 , 5 } ,
+		new int[] { 3 , 6, 2, 5, 8, 4 , 7 } ,
+		new int[] { 7 , 3, 6, 2, 5, 1 , 4 } ,
+		new int[] { 2 , 5, 1, 4, 7, 3 , 6 } ,
+	};
 	
-	public static final int SCORE_KEY_FLAT_POSITIONS[] = new int[]{ 5, 2, 6, 3, 0, 4, 1 };
+	public static final int SCORE_KEY_FLAT_POSITIONS[][] = new int[][]{ 
+		new int[] { 5, 2, 6, 3, 7, 4, 8 } ,
+		new int[] { 7, 4, 8, 5, 9, 6, 10 } ,
+		new int[] { 4, 1, 5, 2, 6, 3, 7 } ,
+		new int[] { 6, 3, 7, 4, 8, 5, 9 } ,
+	};
 	
 	/**
 	 * Espacio por defecto de la clave
@@ -123,7 +132,7 @@ public class TGMeasureImpl extends TGMeasure{
 	
 	private int spacing;
 	
-	private TrackSpacing ts;
+	private TGTrackSpacing ts;
 	
 	private int maxY;
 	
@@ -135,7 +144,6 @@ public class TGMeasureImpl extends TGMeasure{
 	
 	private int widthBeats = 0;
 	
-	//private List beatGroups; //TODO: borrar
 	private List[] voiceGroups;
 	
 	private TGMeasureBuffer buffer;
@@ -147,22 +155,16 @@ public class TGMeasureImpl extends TGMeasure{
 	private int lyricBeatIndex;
 	private int width;
 	
+	private int beatEffectSpacing;
 	private boolean text;
 	private boolean chord;
-	private boolean accentuated;
-	private boolean harmonic;
-	private boolean tapping;
-	private boolean palmMute;
-	private boolean vibrato;
-	private boolean tupleto;
-	private boolean fadeIn;
+	private boolean division;
 	
 	private boolean[][] registeredAccidentals;
 	
 	public TGMeasureImpl(TGMeasureHeader header) {
 		super(header);
 		this.registeredAccidentals = new boolean[11][7];
-		//this.beatGroups = new ArrayList();
 		this.voiceGroups = new List[TGBeat.MAX_VOICES];
 		for(int v = 0 ; v < TGBeat.MAX_VOICES; v ++){
 			this.voiceGroups[v] = new ArrayList();
@@ -231,15 +233,10 @@ public class TGMeasureImpl extends TGMeasure{
 		TGDuration minDuration = null;
 		TGBeatImpl previousBeat = null;
 		TGVoiceImpl[] previousVoices = new TGVoiceImpl[TGBeat.MAX_VOICES];
-		//TGBeatGroup group = null;
 		TGBeatGroup[] groups = new TGBeatGroup[TGBeat.MAX_VOICES];
 		
 		int style = layout.getStyle();
-		int minimunChordLength = 0;
-		//int[] minimumNote = new int[TGBeat.MAX_VOICES];
-		//int[] maximumNote = new int[TGBeat.MAX_VOICES];
-		//boolean beatChanged = false;
-		//boolean voiceChanged[] = new boolean[TGBeat.MAX_VOICES];
+		int minimumChordLength = 0;
 		
 		boolean[] notEmptyVoicesChecked = new boolean[TGBeat.MAX_VOICES];
 		boolean chordEnabled = ((style & (ViewLayout.DISPLAY_CHORD_DIAGRAM | ViewLayout.DISPLAY_CHORD_NAME)) != 0);
@@ -257,7 +254,7 @@ public class TGMeasureImpl extends TGMeasure{
 			if(chordEnabled && beat.getChord() != null){
 				if(previousChord != null){
 					int length = (int) (beat.getStart() - previousChord.getBeat().getStart());
-					minimunChordLength = (minimunChordLength > 0)?Math.min(minimunChordLength, Math.abs(length)):length;
+					minimumChordLength = (minimumChordLength > 0)?Math.min(minimumChordLength, Math.abs(length)):length;
 				}
 				previousChord = beat.getChord();
 			}
@@ -276,17 +273,15 @@ public class TGMeasureImpl extends TGMeasure{
 						this.notEmptyVoices ++;
 					}
 					
-					//voiceChanged[v] = true;
 					Iterator it = voice.getNotes().iterator();
 					while(it.hasNext()){
 						TGNoteImpl note = (TGNoteImpl)it.next();
-						
 						voice.check(note);
 					}
 					
 					if(!voice.isRestVoice()){
-						beat.check(voice.getMinNote());
-						beat.check(voice.getMaxNote());
+						beat.check( layout, voice.getMinNote() );
+						beat.check( layout, voice.getMaxNote() );
 						if( ( groups[v] == null ) || !canJoin(layout.getSongManager(),voice,previousVoices[v]) ){
 							groups[v] = new TGBeatGroup(v);
 							this.voiceGroups[v].add(groups[v]);
@@ -312,60 +307,7 @@ public class TGMeasureImpl extends TGMeasure{
 			if (emptyBeat){
 				System.out.println( "Empty Beat !!!!!! " + beat.getStart() + "  " + i);
 			}
-			/*
-			for( int v = 0; v < TGBeat.MAX_VOICES; v ++){
-				TGVoiceImpl voice = (TGVoiceImpl)beat.getVoice(v);
-				if(!voice.isEmpty()){					
-					//
-				}
-			}
-			*/
-			/*
-			for( int v = 0; v < TGBeat.MAX_VOICES; v ++){
-				TGVoiceImpl voice = (TGVoiceImpl)beat.getVoice(v);
-				if(!voice.isEmpty()){
-					voice.reset();
-					if (minDuration == null || voice.getDuration().getTime() <= minDuration.getTime()) {
-						minDuration = voice.getDuration();
-					}
-					
-					voiceChanged[v] = true;
-					Iterator it = voice.getNotes().iterator();
-					while(it.hasNext()){
-						TGNoteImpl note = (TGNoteImpl)it.next();
-						
-						voice.check(note);
-						
-						if( ( groups[v] == null ) || (voiceChanged[v] && !canJoin(layout.getSongManager(),voice,previousVoices[v]) ) ){
-							groups[v] = new TGBeatGroup();
-							this.voiceGroups[v].add(groups[v]);
-						}
-						groups[v].check(note,getClef(), groups[ (v + 1) % groups.length ]);
-						note.setBeatGroup(groups[v]);
-						voiceChanged[v] = false;
-					}
-					
-					if(!voice.isRestVoice()){
-						beat.check(voice.getMinNote());
-						beat.check(voice.getMaxNote());
-					}else{
-						for( int v2 = 0; v2 < TGBeat.MAX_VOICES; v2 ++){
-							if(v2 != voice.getIndex()){
-								TGVoiceImpl voice2 = beat.getVoiceImpl(v2);
-								if( !voice2.isEmpty() && voice2.getDuration().isEqual(voice.getDuration())){
-									if(!voice2.isRestVoice() || !voice2.isHiddenSilence()){
-										voice.setHiddenSilence(true);
-										break;
-									}
-								}
-							}
-						}
-					}
-					makeVoice(layout, voice, previousVoices[v], groups[v]);
-					previousVoices[v] = voice;
-				}
-			}
-			*/
+			
 			makeBeat(layout,beat,previousBeat,chordEnabled);
 			previousBeat = beat;
 		}
@@ -380,10 +322,10 @@ public class TGMeasureImpl extends TGMeasure{
 		
 		if(!this.compactMode){
 			this.quarterSpacing = (minDuration != null)?layout.getSpacingForQuarter(minDuration): Math.round(DEFAULT_QUARTER_SPACING * layout.getScale());
-			if(chordEnabled && minimunChordLength > 0){
+			if(chordEnabled && minimumChordLength > 0){
 				int chordWidth = (layout.getChordFretIndexSpacing() + layout.getChordStringSpacing() + (getTrack().stringCount() * layout.getChordStringSpacing()));
-				int minimunSpacing = (int)((TGDuration.QUARTER_TIME * chordWidth) / minimunChordLength);
-				this.quarterSpacing = Math.max(minimunSpacing,this.quarterSpacing);
+				int minimumSpacing = (int)((TGDuration.QUARTER_TIME * chordWidth) / minimumChordLength);
+				this.quarterSpacing = Math.max(minimumSpacing,this.quarterSpacing);
 			}
 			this.getHeaderImpl().notifyQuarterSpacing(this.quarterSpacing);
 		}
@@ -489,6 +431,7 @@ public class TGMeasureImpl extends TGMeasure{
 		int tmpX = spacing;
 		for (int i = 0; i < countBeats(); i++) {
 			TGBeatImpl beat = (TGBeatImpl) getBeat(i);
+			beat.resetEffectsSpacing(layout);
 			
 			if(this.compactMode){
 				beat.setPosX(tmpX);
@@ -519,16 +462,13 @@ public class TGMeasureImpl extends TGMeasure{
 					Iterator notes = voice.getNotes().iterator();
 					while(notes.hasNext()){
 						TGNoteImpl note = (TGNoteImpl)notes.next();
-						
-						checkEffects(layout,note.getEffect());
-						
+						beat.updateEffectsSpacing(layout, note.getEffect());
 						note.update(layout);
 					}
-					
 					voice.update(layout);
 					
-					if(!this.tupleto && !voice.getDuration().getTupleto().isEqual(TGTupleto.NORMAL)){
-						this.tupleto = true;
+					if(!this.division && !voice.getDuration().getDivision().isEqual(TGDivisionType.NORMAL)){
+						this.division = true;
 					}
 					if( (layout.getStyle() & ViewLayout.DISPLAY_SCORE) == 0 || (voice.isRestVoice() && !voice.isHiddenSilence()) ){
 						if( voice.getMaxY() > this.maxY ){
@@ -541,6 +481,11 @@ public class TGMeasureImpl extends TGMeasure{
 				}
 			}
 			
+			int bsSize = beat.getEffectsSpacing(layout);
+			if( bsSize > this.beatEffectSpacing ){
+				this.beatEffectSpacing = bsSize;
+			}
+			
 			if(!this.chord && beat.isChordBeat()){
 				this.chord = true;
 			}
@@ -603,72 +548,34 @@ public class TGMeasureImpl extends TGMeasure{
 		}
 	}
 	
-	private void checkEffects(ViewLayout layout,TGNoteEffect effect){
-		if(effect.isAccentuatedNote() || effect.isHeavyAccentuatedNote()){
-			this.accentuated = true;
-		}
-		if(effect.isHarmonic() && (layout.getStyle() & ViewLayout.DISPLAY_SCORE) == 0 ){
-			this.harmonic = true;
-		}
-		if(effect.isTapping() || effect.isSlapping() || effect.isPopping()){
-			this.tapping = true;
-		}
-		if(effect.isPalmMute()){
-			this.palmMute = true;
-		}
-		if(effect.isFadeIn()){
-			this.fadeIn = true;
-		}
-		if(effect.isVibrato() || effect.isTrill()){
-			this.vibrato = true;
-		}
-	}
-	
 	private void resetSpacing(){
 		this.text = false;
 		this.chord = false;
-		this.tupleto = false;
-		this.accentuated = false;
-		this.harmonic = false;
-		this.tapping = false;
-		this.palmMute = false;
-		this.fadeIn = false;
-		this.vibrato = false;
+		this.division = false;
+		this.beatEffectSpacing = 0;
 	}
 	
-	public void registerSpacing(ViewLayout layout,TrackSpacing ts){
+	public void registerSpacing(ViewLayout layout,TGTrackSpacing ts){
+		if(layout.hasLoopMarker( this )){
+			ts.setSize(TGTrackSpacing.POSITION_LOOP_MARKER,layout.getLoopMarkerSpacing());
+		}
 		if(this.hasMarker()){
-			ts.setSize(TrackSpacing.POSITION_MARKER,layout.getMarkerSpacing());
+			ts.setSize(TGTrackSpacing.POSITION_MARKER,layout.getMarkerSpacing());
 		}
 		if(this.chord){
-			ts.setSize(TrackSpacing.POSITION_CHORD,layout.getDefaultChordSpacing());
+			ts.setSize(TGTrackSpacing.POSITION_CHORD,layout.getDefaultChordSpacing());
 		}
 		if(this.text){
-			ts.setSize(TrackSpacing.POSITION_TEXT,layout.getTextSpacing());
+			ts.setSize(TGTrackSpacing.POSITION_TEXT,layout.getTextSpacing());
 		}
 		if(this.getHeader().getRepeatAlternative() > 0){
-			ts.setSize(TrackSpacing.POSITION_REPEAT_ENDING,layout.getRepeatEndingSpacing());
+			ts.setSize(TGTrackSpacing.POSITION_REPEAT_ENDING,layout.getRepeatEndingSpacing());
 		}
-		if(this.tupleto){
-			ts.setSize(TrackSpacing.POSITION_TUPLETO,layout.getTupletoSpacing());
+		if(this.division){
+			ts.setSize(TGTrackSpacing.POSITION_DIVISION_TYPE,layout.getDivisionTypeSpacing());
 		}
-		if(this.accentuated){
-			ts.setSize(TrackSpacing.POSITION_ACCENTUATED_EFFECT,layout.getEffectSpacing());
-		}
-		if(this.harmonic){
-			ts.setSize(TrackSpacing.POSITION_HARMONIC_EFFEC,layout.getEffectSpacing());
-		}
-		if(this.tapping){
-			ts.setSize(TrackSpacing.POSITION_TAPPING_EFFEC,layout.getEffectSpacing());
-		}
-		if(this.palmMute){
-			ts.setSize(TrackSpacing.POSITION_PALM_MUTE_EFFEC,layout.getEffectSpacing());
-		}
-		if(this.fadeIn){
-			ts.setSize(TrackSpacing.POSITION_FADE_IN,layout.getEffectSpacing());
-		}
-		if(this.vibrato){
-			ts.setSize(TrackSpacing.POSITION_VIBRATO_EFFEC,layout.getEffectSpacing());
+		if( this.beatEffectSpacing > 0 ){
+			ts.setSize(TGTrackSpacing.POSITION_EFFECTS, this.beatEffectSpacing );
 		}
 	}
 	
@@ -682,25 +589,28 @@ public class TGMeasureImpl extends TGMeasure{
 		boolean bufferEnabled = layout.isBufferEnabled();
 		
 		if(shouldRepaintBuffer() || !bufferEnabled ){
-			TGPainter painterBuffer = painter;
+			TGPainter bufferPainter = painter;
 			int x = (bufferEnabled ? 0 : getPosX());
 			int y = (bufferEnabled ? 0 : getPosY());
 			if(bufferEnabled){
-				getBuffer().makeBuffer(getWidth(layout) + getSpacing(), getTs().getSize(),layout.getResources().getBackgroundColor());
-				painterBuffer = getBuffer().getPainter();
+				getBuffer().createBuffer(getWidth(layout) + getSpacing(), getTs().getSize(),layout.getResources().getBackgroundColor());
+				bufferPainter = getBuffer().getPainter();
+			}
+			layout.paintLines(getTrackImpl(),getTs(),bufferPainter,x,y, getWidth(layout) + getSpacing());
+			paintTimeSignature(layout,bufferPainter,x,y);
+			paintClef(layout,bufferPainter,x,y);
+			paintKeySignature(layout,bufferPainter,x,y);
+			paintComponents(layout,bufferPainter,x,y);
+			if(bufferEnabled){
+				getBuffer().disposePainter();
 			}
-			layout.paintLines(getTrackImpl(),getTs(),painterBuffer,x,y, getWidth(layout) + getSpacing());
-			paintTimeSignature(layout,painterBuffer,x,y);
-			paintClef(layout,painterBuffer,x,y);
-			paintKeySignature(layout,painterBuffer,x,y);
-			paintComponents(layout,painterBuffer,x,y);
-			
 			setBufferCreated(true);
 		}
 		if(bufferEnabled){
 			painter.setBackground(layout.getResources().getBackgroundColor());
-			getBuffer().paintImage(painter,getPosX(),getPosY(),getTs().getPosition(TrackSpacing.POSITION_BUFFER_SEPARATOR));
+			getBuffer().paintBuffer(painter,getPosX(),getPosY(),getTs().getPosition(TGTrackSpacing.POSITION_BUFFER_SEPARATOR));
 		}
+		this.paintLoopMarker(layout, painter);
 		this.paintMarker(layout, painter);
 		this.paintTexts(layout,painter);
 		this.paintTempo(layout,painter);
@@ -719,7 +629,7 @@ public class TGMeasureImpl extends TGMeasure{
 			float scale = layout.getScale();
 			float x1 = (getPosX() + getHeaderImpl().getLeftSpacing(layout) + getFirstNoteSpacing(layout));
 			float x2 = (getPosX() + getWidth(layout) + getSpacing());
-			float y1 = (getPosY() + getTs().getPosition(TrackSpacing.POSITION_REPEAT_ENDING));
+			float y1 = (getPosY() + getTs().getPosition(TGTrackSpacing.POSITION_REPEAT_ENDING));
 			float y2 = (y1 + (layout.getRepeatEndingSpacing() * 0.75f ));
 			String string = new String();
 			for(int i = 0; i < 8; i ++){
@@ -729,6 +639,7 @@ public class TGMeasureImpl extends TGMeasure{
 			}
 			layout.setRepeatEndingStyle(painter);
 			painter.initPath();
+			painter.setAntialias(false);
 			painter.moveTo(x1, y2);
 			painter.lineTo(x1, y1);
 			painter.lineTo(x2, y1);
@@ -761,17 +672,17 @@ public class TGMeasureImpl extends TGMeasure{
 		boolean addInfo = false;
 		//-----SCORE ------------------------------------//
 		if((style & ViewLayout.DISPLAY_SCORE) != 0 ){
-			y1 = getPosY() + getTs().getPosition(TrackSpacing.POSITION_SCORE_MIDDLE_LINES);
+			y1 = getPosY() + getTs().getPosition(TGTrackSpacing.POSITION_SCORE_MIDDLE_LINES);
 			y2 = y1 + (layout.getScoreLineSpacing() * 4);
 			addInfo = true;
 			if( (style & ViewLayout.DISPLAY_TABLATURE) != 0 && (layout.isFirstMeasure(this) || isFirstOfLine())){
-				offsetY = ( getPosY() + getTs().getPosition(TrackSpacing.POSITION_TABLATURE)) - y2;
+				offsetY = ( getPosY() + getTs().getPosition(TGTrackSpacing.POSITION_TABLATURE)) - y2;
 			}
 			paintDivisions(layout, painter, x1, y1, x2, y2, offsetY, addInfo );
 		}
 		//-----TABLATURE ------------------------------------//
 		if( (style & ViewLayout.DISPLAY_TABLATURE) != 0 ){
-			y1 = getPosY() + getTs().getPosition(TrackSpacing.POSITION_TABLATURE);
+			y1 = getPosY() + getTs().getPosition(TGTrackSpacing.POSITION_TABLATURE);
 			y2 = y1 + ((getTrack().getStrings().size() - 1 ) * layout.getStringSpacing());
 			addInfo = ( (style & ViewLayout.DISPLAY_SCORE) == 0 );
 			offsetY = 0;
@@ -796,11 +707,13 @@ public class TGMeasureImpl extends TGMeasure{
 		//principio
 		if(this.isRepeatOpen() || layout.isFirstMeasure(this)){
 			painter.initPath(TGPainter.PATH_DRAW | TGPainter.PATH_FILL);
+			painter.setAntialias(false);
 			painter.setLineWidth(lineWidthSmall);
 			painter.addRectangle( x1, y1, lineWidthBig, (y2 + offsetY) - y1);
 			painter.closePath();
 			
 			painter.initPath();
+			painter.setAntialias(false);
 			painter.setLineWidth(lineWidthSmall);
 			painter.moveTo(x1 + lineWidthBig + scale + lineWidthSmall, y1);
 			painter.lineTo(x1 + lineWidthBig + scale + lineWidthSmall, (y2 + offsetY));
@@ -821,6 +734,7 @@ public class TGMeasureImpl extends TGMeasure{
 			}
 		}else{
 			painter.initPath();
+			painter.setAntialias(false);
 			painter.setLineWidth(lineWidthSmall);
 			painter.moveTo(x1, y1);
 			painter.lineTo(x1, (y2 + offsetY));
@@ -830,12 +744,14 @@ public class TGMeasureImpl extends TGMeasure{
 		//fin
 		if(this.getRepeatClose() > 0 || layout.isLastMeasure(this)){
 			painter.initPath();
+			painter.setAntialias(false);
 			painter.setLineWidth(lineWidthSmall);
 			painter.moveTo( (x2 + getSpacing()) - (lineWidthBig + scale + lineWidthSmall) , y1);
 			painter.lineTo( (x2 + getSpacing()) - (lineWidthBig + scale + lineWidthSmall) , y2);
 			painter.closePath();
 			
 			painter.initPath(TGPainter.PATH_DRAW | TGPainter.PATH_FILL);
+			painter.setAntialias(false);
 			painter.setLineWidth(lineWidthSmall);
 			painter.addRectangle( (x2 + getSpacing()) - lineWidthBig, y1, lineWidthBig, y2 - y1);
 			painter.closePath();
@@ -861,6 +777,7 @@ public class TGMeasureImpl extends TGMeasure{
 			}
 		}else{
 			painter.initPath();
+			painter.setAntialias(false);
 			painter.setLineWidth(lineWidthSmall);
 			painter.moveTo(x2 + getSpacing(), y1);
 			painter.lineTo(x2 + getSpacing(), y2);
@@ -876,7 +793,7 @@ public class TGMeasureImpl extends TGMeasure{
 		//-----SCORE ------------------------------------//
 		if((layout.getStyle() & ViewLayout.DISPLAY_SCORE) != 0 && this.paintClef){
 			int x = fromX + Math.round( 14 * layout.getScale() ) ;
-			int y = fromY + getTs().getPosition(TrackSpacing.POSITION_SCORE_MIDDLE_LINES);
+			int y = fromY + getTs().getPosition(TGTrackSpacing.POSITION_SCORE_MIDDLE_LINES);
 			layout.setClefStyle(painter);
 			painter.initPath(TGPainter.PATH_FILL);
 			if(this.getClef() == TGMeasure.CLEF_TREBLE){
@@ -902,50 +819,18 @@ public class TGMeasureImpl extends TGMeasure{
 		if((layout.getStyle() & ViewLayout.DISPLAY_SCORE) != 0 && this.paintKeySignature){
 			float scale = layout.getScoreLineSpacing();
 			int x = fromX + getClefSpacing(layout) + 10;
-			int y = fromY + getTs().getPosition(TrackSpacing.POSITION_SCORE_MIDDLE_LINES);
+			int y = fromY + getTs().getPosition(TGTrackSpacing.POSITION_SCORE_MIDDLE_LINES);
+			int clefIndex = (this.getClef() - 1);
 			int currentKey = this.getKeySignature();
 			int previousKey = (this.prevMeasure != null ? this.prevMeasure.getKeySignature() : 0);
-			int offsetClef = 0;
-			if(this.getClef() == TGMeasure.CLEF_TREBLE){
-				offsetClef = 0;
-			}
-			else if(this.getClef() == TGMeasure.CLEF_BASS){
-				offsetClef = 2;
-			}
-			else if(this.getClef() == TGMeasure.CLEF_TENOR){
-				offsetClef = -1;
-			}
-			else if(this.getClef() == TGMeasure.CLEF_ALTO){
-				offsetClef = 1;
-			}
 			
 			layout.setKeySignatureStyle(painter);
 			
-			//sharps
-			if(currentKey >= 1 && currentKey <= 7){
-				for(int i = 0; i < currentKey; i ++ ){
-					float offset =  ( (scale / 2) * ( ( (SCORE_KEY_SHARP_POSITIONS[i] + offsetClef) + 7) % 7)  )  - (scale / 2);
-					painter.initPath(TGPainter.PATH_FILL);
-					TGKeySignaturePainter.paintSharp(painter,x, (y +  offset  ), scale);
-					painter.closePath();
-					x += (scale - (scale / 4));
-				}
-			}
-			//flats
-			else if(currentKey >= 8 && currentKey <= 14){
-				for(int i = 7; i < currentKey; i ++ ){
-					float offset =  ( (scale / 2) * ( ( (SCORE_KEY_FLAT_POSITIONS[i - 7] + offsetClef) + 7) % 7)  )  - (scale / 2);
-					painter.initPath(TGPainter.PATH_FILL);
-					TGKeySignaturePainter.paintFlat(painter,x, (y +  offset  ), scale);
-					painter.closePath();
-					x += (scale - (scale / 4));
-				}
-			}
 			//natural
 			if(previousKey >= 1 && previousKey <= 7){
 				int naturalFrom =  (currentKey >= 1 && currentKey <= 7) ? currentKey : 0;
 				for(int i = naturalFrom; i < previousKey; i ++ ){
-					float offset =  ( (scale / 2) * ( ( (SCORE_KEY_SHARP_POSITIONS[i] + offsetClef) + 7) % 7)  )  - (scale / 2);
+					float offset =  ( ( (scale / 2) * SCORE_KEY_SHARP_POSITIONS[clefIndex][i] )  - (scale / 2) );
 					painter.initPath(TGPainter.PATH_FILL);
 					TGKeySignaturePainter.paintNatural(painter,x, (y +  offset  ), scale);
 					painter.closePath();
@@ -955,13 +840,34 @@ public class TGMeasureImpl extends TGMeasure{
 			else if(previousKey >= 8 && previousKey <= 14){
 				int naturalFrom =  (currentKey >= 8 && currentKey <= 14) ? currentKey : 7;
 				for(int i = naturalFrom; i < previousKey; i ++ ){
-					float offset =  ( (scale / 2) * ( ( (SCORE_KEY_FLAT_POSITIONS[i - 7] + offsetClef) + 7) % 7)  )  - (scale / 2);
+					float offset =  ( ( (scale / 2) * SCORE_KEY_FLAT_POSITIONS[clefIndex][i - 7] )  - (scale / 2) );
 					painter.initPath(TGPainter.PATH_FILL);
 					TGKeySignaturePainter.paintNatural(painter,x, (y +  offset  ), scale);
 					painter.closePath();
 					x += (scale - (scale / 4));
 				}
 			}
+			
+			//sharps
+			if(currentKey >= 1 && currentKey <= 7){
+				for(int i = 0; i < currentKey; i ++ ){
+					float offset =  ( ( (scale / 2) * SCORE_KEY_SHARP_POSITIONS[clefIndex][i] )  - (scale / 2) );
+					painter.initPath(TGPainter.PATH_FILL);
+					TGKeySignaturePainter.paintSharp(painter,x, (y +  offset  ), scale);
+					painter.closePath();
+					x += (scale - (scale / 4));
+				}
+			}
+			//flats
+			else if(currentKey >= 8 && currentKey <= 14){
+				for(int i = 7; i < currentKey; i ++ ){
+					float offset =  ( ( (scale / 2) * SCORE_KEY_FLAT_POSITIONS[clefIndex][i - 7] )  - (scale / 2) );
+					painter.initPath(TGPainter.PATH_FILL);
+					TGKeySignaturePainter.paintFlat(painter,x, (y +  offset  ), scale);
+					painter.closePath();
+					x += (scale - (scale / 4));
+				}
+			}
 		}
 	}
 	
@@ -975,13 +881,13 @@ public class TGMeasureImpl extends TGMeasure{
 			String numerator = Integer.toString(getTimeSignature().getNumerator());
 			String denominator = Integer.toString(getTimeSignature().getDenominator().getValue());
 			if( (style & ViewLayout.DISPLAY_SCORE) != 0 ){
-				int y = getTs().getPosition(TrackSpacing.POSITION_SCORE_MIDDLE_LINES);
+				int y = getTs().getPosition(TGTrackSpacing.POSITION_SCORE_MIDDLE_LINES);
 				int y1 = (int)(y - (3f * scale));
 				int y2 = (int)(((y + (layout.getScoreLineSpacing() * 4)) - painter.getStringExtent(denominator).y) + (3f * scale));
 				painter.drawString(numerator,fromX + x,fromY + y1,true);
 				painter.drawString(denominator,fromX + x,fromY + y2,true);
 			}else if( (style & ViewLayout.DISPLAY_TABLATURE) != 0 ){
-				int y = getTs().getPosition(TrackSpacing.POSITION_TABLATURE);
+				int y = getTs().getPosition(TGTrackSpacing.POSITION_TABLATURE);
 				int move = (int)((8f - getTrack().stringCount()) * scale);
 				int y1 = (y - move);
 				int y2 = ((y  + getTrackImpl().getTabHeight()) - painter.getStringExtent(denominator).y) + move;
@@ -999,9 +905,9 @@ public class TGMeasureImpl extends TGMeasure{
 			int lineSpacing = (Math.max(layout.getScoreLineSpacing() , layout.getStringSpacing()));
 			int style = layout.getStyle();
 			if( (style & ViewLayout.DISPLAY_SCORE) != 0 ){
-				y += ( getTs().getPosition(TrackSpacing.POSITION_SCORE_MIDDLE_LINES) - lineSpacing ) ;
+				y += ( getTs().getPosition(TGTrackSpacing.POSITION_SCORE_MIDDLE_LINES) - lineSpacing ) ;
 			}else if( (style & ViewLayout.DISPLAY_TABLATURE) != 0 ){
-				y += ( getTs().getPosition(TrackSpacing.POSITION_TABLATURE) - lineSpacing ) ;
+				y += ( getTs().getPosition(TGTrackSpacing.POSITION_TABLATURE) - lineSpacing ) ;
 			}
 			
 			layout.setTempoStyle(painter, false);
@@ -1029,9 +935,9 @@ public class TGMeasureImpl extends TGMeasure{
 			int lineSpacing = (Math.max(layout.getScoreLineSpacing() , layout.getStringSpacing()));
 			int style = layout.getStyle();
 			if( (style & ViewLayout.DISPLAY_SCORE) != 0 ){
-				y += ( getTs().getPosition(TrackSpacing.POSITION_SCORE_MIDDLE_LINES) - lineSpacing );
+				y += ( getTs().getPosition(TGTrackSpacing.POSITION_SCORE_MIDDLE_LINES) - lineSpacing );
 			}else if( (style & ViewLayout.DISPLAY_TABLATURE) != 0 ){
-				y += ( getTs().getPosition(TrackSpacing.POSITION_TABLATURE) - lineSpacing );
+				y += ( getTs().getPosition(TGTrackSpacing.POSITION_TABLATURE) - lineSpacing );
 			}
 			
 			layout.setTripletFeelStyle(painter, true);
@@ -1093,13 +999,37 @@ public class TGMeasureImpl extends TGMeasure{
 		}
 	}
 	
+	private void paintLoopMarker(ViewLayout layout,TGPainter painter){
+		if( layout.hasLoopMarker( this ) ){
+			int size = Math.round( layout.getLoopMarkerSpacing() - (1f * layout.getScale()));
+			MidiPlayerMode pm = TuxGuitar.instance().getPlayer().getMode();
+			if( pm.getLoopSHeader() == getHeader().getNumber() ){
+				int x = (getPosX() + Math.round(size / 2f) );
+				int y = (getPosY() + getTs().getPosition(TGTrackSpacing.POSITION_LOOP_MARKER));
+				layout.setLoopSMarkerStyle(painter);
+				paintLoopMarker(painter, x, y, size);
+			}
+			if( pm.getLoopEHeader() == getHeader().getNumber() ){
+				float x = (getPosX() + getWidth(layout) + getSpacing() - size );
+				float y = (getPosY() + getTs().getPosition(TGTrackSpacing.POSITION_LOOP_MARKER));
+				layout.setLoopEMarkerStyle(painter);
+				paintLoopMarker(painter, x, y, size);
+			}
+		}
+	}
+	
+	private void paintLoopMarker(TGPainter painter, float x, float y, float size){
+		painter.initPath( TGPainter.PATH_FILL );
+		painter.addRectangle(x, y, size, size);
+		painter.closePath();
+	}
+	
 	private void paintMarker(ViewLayout layout,TGPainter painter){
 		if( this.hasMarker() ){
 			int x = (getPosX() + getHeaderImpl().getLeftSpacing(layout) + getFirstNoteSpacing(layout));
-			int y = (getPosY() + getTs().getPosition(TrackSpacing.POSITION_MARKER));
+			int y = (getPosY() + getTs().getPosition(TGTrackSpacing.POSITION_MARKER));
 			
-			layout.setMarkerStyle(painter);
-			painter.setForeground( getMarkerColor() );
+			layout.setMarkerStyle(painter,getMarkerColor());
 			painter.drawString(getMarker().getTitle(), x, y);
 		}
 	}
@@ -1123,14 +1053,14 @@ public class TGMeasureImpl extends TGMeasure{
 			int y2 = getPosY();
 			int style = layout.getStyle();
 			if( (style & (ViewLayout.DISPLAY_SCORE | ViewLayout.DISPLAY_TABLATURE)) == (ViewLayout.DISPLAY_SCORE | ViewLayout.DISPLAY_TABLATURE) ){
-				y1 += (getTs().getPosition(TrackSpacing.POSITION_SCORE_MIDDLE_LINES) - layout.getScoreLineSpacing());
-				y2 += (getTs().getPosition(TrackSpacing.POSITION_TABLATURE) + getTrackImpl().getTabHeight() + layout.getStringSpacing());
+				y1 += (getTs().getPosition(TGTrackSpacing.POSITION_SCORE_MIDDLE_LINES) - layout.getScoreLineSpacing());
+				y2 += (getTs().getPosition(TGTrackSpacing.POSITION_TABLATURE) + getTrackImpl().getTabHeight() + layout.getStringSpacing());
 			}else if( (style & ViewLayout.DISPLAY_SCORE) != 0 ){
-				y1 += (getTs().getPosition(TrackSpacing.POSITION_SCORE_MIDDLE_LINES) - layout.getScoreLineSpacing());
-				y2 += (getTs().getPosition(TrackSpacing.POSITION_SCORE_MIDDLE_LINES) + (layout.getScoreLineSpacing() * 5));
+				y1 += (getTs().getPosition(TGTrackSpacing.POSITION_SCORE_MIDDLE_LINES) - layout.getScoreLineSpacing());
+				y2 += (getTs().getPosition(TGTrackSpacing.POSITION_SCORE_MIDDLE_LINES) + (layout.getScoreLineSpacing() * 5));
 			} else if( (style & ViewLayout.DISPLAY_TABLATURE) != 0 ){
-				y1 += (getTs().getPosition(TrackSpacing.POSITION_TABLATURE) - layout.getStringSpacing());
-				y2 += (getTs().getPosition(TrackSpacing.POSITION_TABLATURE) + getTrackImpl().getTabHeight() + layout.getStringSpacing());
+				y1 += (getTs().getPosition(TGTrackSpacing.POSITION_TABLATURE) - layout.getStringSpacing());
+				y2 += (getTs().getPosition(TGTrackSpacing.POSITION_TABLATURE) + getTrackImpl().getTabHeight() + layout.getStringSpacing());
 			}
 			layout.setMeasurePlayingStyle(painter);
 			// Don't uncomment "lineStyle" until be sure SWT bug has fixed.
@@ -1138,6 +1068,7 @@ public class TGMeasureImpl extends TGMeasure{
 			//painter.setLineStyle(SWT.LINE_DASH);
 			painter.setLineWidth(1);
 			painter.initPath();
+			painter.setAntialias(false);
 			painter.addRectangle(getPosX() + (5f * scale),y1,width - (10f * scale),(y2 - y1));
 			painter.closePath();
 			//painter.setLineStyle(SWT.LINE_SOLID);
@@ -1286,16 +1217,18 @@ public class TGMeasureImpl extends TGMeasure{
 		return (TGTrackImpl)super.getTrack();
 	}
 	
-	public TrackSpacing getTs() {
+	public TGTrackSpacing getTs() {
 		return this.ts;
 	}
 	
-	public void setTs(TrackSpacing ts) {
+	public void setTs(TGTrackSpacing ts) {
 		if(getTs() == null){
 			setBufferCreated(false);
-		}else if(getTs().getPosition(TrackSpacing.POSITION_SCORE_MIDDLE_LINES) != ts.getPosition(TrackSpacing.POSITION_SCORE_MIDDLE_LINES)){
+		}else if(getTs().getPosition(TGTrackSpacing.POSITION_SCORE_MIDDLE_LINES) != ts.getPosition(TGTrackSpacing.POSITION_SCORE_MIDDLE_LINES)){
 			setBufferCreated(false);
-		}else if(getTs().getPosition(TrackSpacing.POSITION_TABLATURE) != ts.getPosition(TrackSpacing.POSITION_TABLATURE)){
+		}else if(getTs().getPosition(TGTrackSpacing.POSITION_TABLATURE) != ts.getPosition(TGTrackSpacing.POSITION_TABLATURE)){
+			setBufferCreated(false);
+		}else if(getTs().getPosition(TGTrackSpacing.POSITION_EFFECTS) != ts.getPosition(TGTrackSpacing.POSITION_EFFECTS)){
 			setBufferCreated(false);
 		}
 		this.ts = ts;
