@@ -4,13 +4,12 @@ import java.util.Iterator;
 
 import org.herac.tuxguitar.gui.TuxGuitar;
 import org.herac.tuxguitar.gui.editors.TGPainter;
-import org.herac.tuxguitar.gui.editors.tab.layout.TrackSpacing;
 import org.herac.tuxguitar.gui.editors.tab.layout.ViewLayout;
 import org.herac.tuxguitar.gui.editors.tab.painters.TGNotePainter;
 import org.herac.tuxguitar.gui.editors.tab.painters.TGSilencePainter;
 import org.herac.tuxguitar.song.factory.TGFactory;
 import org.herac.tuxguitar.song.models.TGDuration;
-import org.herac.tuxguitar.song.models.TGTupleto;
+import org.herac.tuxguitar.song.models.TGDivisionType;
 import org.herac.tuxguitar.song.models.TGVoice;
 
 public class TGVoiceImpl extends TGVoice{
@@ -60,11 +59,7 @@ public class TGVoiceImpl extends TGVoice{
 	public int getPosX() {
 		return this.getBeatImpl().getPosX();
 	}
-	/*
-	public void setPosX(int posX) {
-		this.posX = posX;
-	}
-	*/
+	
 	public int getWidth() {
 		return this.width;
 	}
@@ -155,6 +150,9 @@ public class TGVoiceImpl extends TGVoice{
 		this.usedStrings = new boolean[getBeat().getMeasure().getTrack().stringCount()];
 		this.maxString = 1;
 		this.minString = getBeat().getMeasure().getTrack().stringCount();
+		this.group = null;
+		this.previous = null;
+		this.next = null;
 	}
 	
 	public void check(TGNoteImpl note){
@@ -266,11 +264,11 @@ public class TGVoiceImpl extends TGVoice{
 			
 			int duration = getDuration().getValue();
 			if(duration == TGDuration.WHOLE){
-				this.silenceHeight = lineSpacing;
+				this.silenceHeight = (scale * 3.6513581f);
 				this.silenceY = ( lineCount <= 5 ? lineSpacing : lineSpacing * 2 );
 			}
 			else if(duration == TGDuration.HALF){
-				this.silenceHeight = lineSpacing;
+				this.silenceHeight = (scale * 3.6513581f);
 				this.silenceY = ( lineCount <= 5 ? lineSpacing * 2 : lineSpacing * 3 ) - this.silenceHeight;
 			}
 			else if(duration == TGDuration.QUARTER){
@@ -366,59 +364,45 @@ public class TGVoiceImpl extends TGVoice{
 	public void paintSilence(ViewLayout layout,TGPainter painter, int fromX, int fromY) {
 		int style = layout.getStyle();
 		int x = 0;
-		//int firstLineY = 0;
 		int lineSpacing = 0;
-		//int lineCount = 0;
-		float y = 0;//this.silenceY;//(this.silenceMoved ? this.silenceY : 0);
+		float y = 0;
 		float scale = 0;
 		
 		if((style & ViewLayout.DISPLAY_SCORE) != 0 ){
 			x = fromX + getPosX() + getBeatImpl().getSpacing();
-			y = fromY + getPaintPosition(TrackSpacing.POSITION_SCORE_MIDDLE_LINES) + this.silenceY;
+			y = fromY + getPaintPosition(TGTrackSpacing.POSITION_SCORE_MIDDLE_LINES) + this.silenceY;
 			lineSpacing = layout.getScoreLineSpacing();
-			//lineCount = 5;
 			scale = (lineSpacing / 9.0f);
 		}else{
 			x = fromX + getPosX() + getBeatImpl().getSpacing() - 1;
-			y = fromY + getPaintPosition(TrackSpacing.POSITION_TABLATURE) + this.silenceY;
+			y = fromY + getPaintPosition(TGTrackSpacing.POSITION_TABLATURE) + this.silenceY;
 			lineSpacing = layout.getStringSpacing();
-			//lineCount = getBeat().getMeasure().getTrack().stringCount();
 			scale = (lineSpacing / 10.0f);
 		}
 		
 		setStyle(layout, painter,(layout.isPlayModeEnabled() && isPlaying(layout)));
 		painter.initPath(TGPainter.PATH_FILL);
 		
-		//(this.centerPosition ? : firstLineY );
-		
 		int duration = getDuration().getValue();
 		if(duration == TGDuration.WHOLE){
-			//y += (this.silenceMoved ? firstLineY : firstLineY + ( lineCount <= 5 ? lineSpacing : lineSpacing * 2 ));
 			TGSilencePainter.paintWhole(painter, x, y , scale);
 		}
 		else if(duration == TGDuration.HALF){
-			//y += (this.silenceMoved ? firstLineY : firstLineY + ( lineCount <= 5 ? lineSpacing * 2 : lineSpacing * 3 ) - (scale * 3));
 			TGSilencePainter.paintHalf(painter, x, y , scale);
 		}
 		else if(duration == TGDuration.QUARTER){
-			//y += (this.silenceMoved ? firstLineY : firstLineY + ((lineSpacing * (lineCount - 1)) / 2) - (scale * 8));
 			TGSilencePainter.paintQuarter(painter, x, y, scale);
 		}
 		else if(duration == TGDuration.EIGHTH){
-			//y += (this.silenceMoved ? firstLineY : firstLineY + ((lineSpacing * (lineCount - 1)) / 2) - (scale * 6));
 			TGSilencePainter.paintEighth(painter, x, y, scale);
 		}
 		else if(duration == TGDuration.SIXTEENTH){
-			//y += (this.silenceMoved ? firstLineY : firstLineY + ((lineSpacing * (lineCount - 1)) / 2) - (scale * 8));
 			TGSilencePainter.paintSixteenth(painter, x, y, scale);
 		}
 		else if(duration == TGDuration.THIRTY_SECOND){
-			//y += (this.silenceMoved ? firstLineY : firstLineY + ((lineSpacing * (lineCount - 1)) / 2) - (scale * 12));
-			
 			TGSilencePainter.paintThirtySecond(painter, x, y, scale);
 		}
 		else if(duration == TGDuration.SIXTY_FOURTH){
-			//y += (this.silenceMoved ? firstLineY : firstLineY + ((lineSpacing * (lineCount - 1)) / 2) - (scale * 14));
 			TGSilencePainter.paintSixtyFourth(painter, x, y, scale);
 		}
 		
@@ -435,12 +419,12 @@ public class TGVoiceImpl extends TGVoice{
 			}
 			painter.closePath();
 		}
-		if(!getDuration().getTupleto().isEqual(TGTupleto.NORMAL)){
-			layout.setTupletoStyle(painter);
+		if(!getDuration().getDivision().isEqual(TGDivisionType.NORMAL)){
+			layout.setDivisionTypeStyle(painter);
 			if((style & ViewLayout.DISPLAY_SCORE) != 0 ){
-				painter.drawString(Integer.toString(getDuration().getTupleto().getEnters()), x,(fromY + getPaintPosition(TrackSpacing.POSITION_TUPLETO)));
+				painter.drawString(Integer.toString(getDuration().getDivision().getEnters()), x,(fromY + getPaintPosition(TGTrackSpacing.POSITION_DIVISION_TYPE)));
 			}else{
-				painter.drawString(Integer.toString(getDuration().getTupleto().getEnters()),x,(fromY + getPaintPosition(TrackSpacing.POSITION_TUPLETO)));
+				painter.drawString(Integer.toString(getDuration().getDivision().getEnters()),x,(fromY + getPaintPosition(TGTrackSpacing.POSITION_DIVISION_TYPE)));
 			}
 		}
 	}
@@ -459,10 +443,10 @@ public class TGVoiceImpl extends TGVoice{
 			int spacing = getBeatImpl().getSpacing();
 			
 			if((style & ViewLayout.DISPLAY_SCORE) != 0){
-				paintScoreBeat(layout, painter, fromX, fromY+getPaintPosition(TrackSpacing.POSITION_SCORE_MIDDLE_LINES), spacing);
+				paintScoreBeat(layout, painter, fromX, fromY+getPaintPosition(TGTrackSpacing.POSITION_SCORE_MIDDLE_LINES), spacing);
 			}
 			if((style & ViewLayout.DISPLAY_TABLATURE) != 0 && (style & ViewLayout.DISPLAY_SCORE) == 0){
-				paintTablatureBeat(layout, painter, fromX, fromY + getPaintPosition(TrackSpacing.POSITION_TABLATURE), spacing);
+				paintTablatureBeat(layout, painter, fromX, fromY + getPaintPosition(TGTrackSpacing.POSITION_TABLATURE), spacing);
 			}
 		}
 	}
@@ -487,22 +471,8 @@ public class TGVoiceImpl extends TGVoice{
 			if (getDuration().getValue() >= TGDuration.QUARTER) {
 				layout.setTabNoteFooterStyle(painter);
 				painter.initPath();
+				painter.setAntialias(false);
 				painter.setLineWidth( (int)verticalLineWidth );
-				/*
-				boolean painting = false;
-				boolean[] usedStrings = getUsedStrings();
-				for (int i = 0; i < usedStrings.length; i++) {
-					if (!usedStrings[i] && painting) {
-						int stringPosition = (fromY + (stringSpacing * (i + 1)) - stringSpacing);
-						int posY1 = stringPosition - (stringSpacing / 2);
-						int posY2 = stringPosition + (stringSpacing / 2);
-						posY2 = ((posY2 - posY1 < stringSpacing)?posY2 + 1:posY2);
-						painter.moveTo(x, posY1);
-						painter.lineTo(x, posY2);
-					}
-					painting = ( painting || usedStrings[i] );
-				}
-				*/
 				painter.moveTo(x, y1);
 				painter.lineTo(x, y2);
 				painter.closePath();
@@ -537,6 +507,7 @@ public class TGVoiceImpl extends TGVoice{
 			} else if (getDuration().getValue() == TGDuration.HALF) {
 				layout.setTabNoteFooterStyle(painter);
 				painter.initPath();
+				painter.setAntialias(false);
 				painter.setLineWidth( (int)verticalLineWidth );
 				painter.moveTo(x, (y1 + ((y2 - y1) / 2)));
 				painter.lineTo(x, y2);
@@ -546,17 +517,15 @@ public class TGVoiceImpl extends TGVoice{
 			//-------------puntillo--------------------------------------
 			if (getDuration().isDotted() || getDuration().isDoubleDotted()) {
 				int joinedType = getJoinedType();
-				
-				//float scale = (stringSpacing / 10.0f);
 				float posX = ((getDuration().getValue() > TGDuration.WHOLE)?((joinedType == TGVoiceImpl.JOINED_TYPE_NONE_RIGHT || joinedType == TGVoiceImpl.JOINED_TYPE_RIGHT)?(x+ (4.0f * scale)):(x- (5.0f * scale))):x);
 				float posY = (y2 - ((getDuration().getValue() >= TGDuration.EIGHTH)? ((stringSpacing / 2) * (getDuration().getIndex() - 2)):(1.0f * scale)));
 				paintDot(layout, painter, posX, posY,scale);
 			}
 			
 			//-------------tresillo--------------------------------------
-			if (!getDuration().getTupleto().isEqual(TGTupleto.NORMAL)) {
-				layout.setTupletoStyle(painter);
-				painter.drawString(Integer.toString(getDuration().getTupleto().getEnters()), (int)(x - 3),((fromY - getPaintPosition(TrackSpacing.POSITION_TABLATURE)) + getPaintPosition(TrackSpacing.POSITION_TUPLETO)));
+			if (!getDuration().getDivision().isEqual(TGDivisionType.NORMAL)) {
+				layout.setDivisionTypeStyle(painter);
+				painter.drawString(Integer.toString(getDuration().getDivision().getEnters()), (int)(x - 3),((fromY - getPaintPosition(TGTrackSpacing.POSITION_TABLATURE)) + getPaintPosition(TGTrackSpacing.POSITION_DIVISION_TYPE)));
 			}
 		}
 	}
@@ -564,10 +533,10 @@ public class TGVoiceImpl extends TGVoice{
 	public void paintScoreBeat(ViewLayout layout,TGPainter painter, int fromX, int fromY, int spacing){
 		int vX = ( fromX + getPosX() + spacing );
 		
-		//TUPLETO
-		if (!getDuration().getTupleto().isEqual(TGTupleto.NORMAL)) {
-			layout.setTupletoStyle(painter);
-			painter.drawString(Integer.toString(getDuration().getTupleto().getEnters()),vX ,((fromY - getPaintPosition(TrackSpacing.POSITION_SCORE_MIDDLE_LINES)) + getPaintPosition(TrackSpacing.POSITION_TUPLETO)));
+		//division type
+		if (!getDuration().getDivision().isEqual(TGDivisionType.NORMAL)) {
+			layout.setDivisionTypeStyle(painter);
+			painter.drawString(Integer.toString(getDuration().getDivision().getEnters()),vX ,((fromY - getPaintPosition(TGTrackSpacing.POSITION_SCORE_MIDDLE_LINES)) + getPaintPosition(TGTrackSpacing.POSITION_DIVISION_TYPE)));
 		}
 		//dibujo el pie
 		if(getDuration().getValue() >= TGDuration.HALF){
@@ -586,6 +555,7 @@ public class TGVoiceImpl extends TGVoice{
 			int vY2 = fromY + this.group.getY2(layout,getPosX() + spacing,key,clef);
 			
 			painter.initPath();
+			painter.setAntialias(false);
 			painter.moveTo(vX + xMove, vY1 + yMove);
 			painter.lineTo(vX + xMove, vY2);
 			painter.closePath();
@@ -620,14 +590,11 @@ public class TGVoiceImpl extends TGVoice{
 						}
 						int hY1 = fromY + this.group.getY2(layout,hX1,key,clef);
 						int hY2 = fromY + this.group.getY2(layout,hX2,key,clef);
-						//painter.setLineWidth(3);
 						painter.setLineWidth(Math.max(1,Math.round(3f * scale)));
 						painter.initPath();
 						for(int i = 0; i <= index; i ++){
 							painter.moveTo(fromX + xMove + hX1, hY1 - ( (i * (5f * scale)) * dir));
 							painter.lineTo(fromX + xMove + hX2, hY2 - ( (i * (5f * scale)) * dir));
-							//painter.moveTo(fromX + xMove + hX1, hY1 - ( (i * (scale/1.6f)) * dir));
-							//painter.lineTo(fromX + xMove + hX2, hY2 - ( (i * (scale/1.6f)) * dir));
 						}
 						painter.closePath();
 						painter.setLineWidth(1);
