@@ -10,6 +10,7 @@ import java.util.ArrayList;
 import java.util.List;
 
 import org.eclipse.swt.SWT;
+import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.graphics.Font;
 import org.eclipse.swt.graphics.FontData;
 import org.eclipse.swt.graphics.Rectangle;
@@ -19,6 +20,7 @@ import org.herac.tuxguitar.gui.editors.tab.TGChordImpl;
 import org.herac.tuxguitar.gui.editors.tab.TGLyricImpl;
 import org.herac.tuxguitar.gui.editors.tab.TGMeasureImpl;
 import org.herac.tuxguitar.gui.editors.tab.TGTrackImpl;
+import org.herac.tuxguitar.gui.editors.tab.TGTrackSpacing;
 import org.herac.tuxguitar.gui.editors.tab.Tablature;
 import org.herac.tuxguitar.gui.printer.PrintDocument;
 import org.herac.tuxguitar.gui.printer.PrintStyles;
@@ -76,7 +78,7 @@ public class PrinterViewLayout extends ViewLayout{
 		this.setRepeatEndingSpacing( getScaledValue(scale ,  20 ) );
 		this.setTextSpacing( getScaledValue( scale, 15 ) );
 		this.setMarkerSpacing( getScaledValue( scale, 15 ) );
-		this.setTupletoSpacing( getScaledValue( scale,  10 ) );
+		this.setDivisionTypeSpacing( getScaledValue( scale,  10 ) );
 		this.setEffectSpacing( getScaledValue(scale ,  8 ) );
 		this.setScale( checkScale() );
 		this.setFontScale( scale );
@@ -126,24 +128,22 @@ public class PrinterViewLayout extends ViewLayout{
 		TGTrackImpl track = (TGTrackImpl)getSongManager().getTrack(this.styles.getTrackNumber());
 		((TGLyricImpl)track.getLyrics()).start(getSkippedBeats(track));
 		
-		TrackSpacing ts = new TrackSpacing(this) ;
+		TGTrackSpacing ts = new TGTrackSpacing(this) ;
 		TempLine line = getTempLines(track,( this.styles.getFromMeasure() - 1 ),ts);
 		while(!line.measures.isEmpty()){
 			
-			ts.setSize(TrackSpacing.POSITION_SCORE_MIDDLE_LINES, ((style & DISPLAY_SCORE) != 0?( (getScoreLineSpacing() * 5) ):0));
+			ts.setSize(TGTrackSpacing.POSITION_SCORE_MIDDLE_LINES, ((style & DISPLAY_SCORE) != 0?( (getScoreLineSpacing() * 5) ):0));
 			if((style & DISPLAY_SCORE) != 0){
-				ts.setSize(TrackSpacing.POSITION_SCORE_UP_LINES, Math.abs(line.minY));
+				ts.setSize(TGTrackSpacing.POSITION_SCORE_UP_LINES, Math.abs(line.minY));
 				if(line.maxY + getMinScoreTabSpacing() > getScoreSpacing()){
-					ts.setSize(TrackSpacing.POSITION_SCORE_DOWN_LINES, (line.maxY - (getScoreLineSpacing() * 4)) );
+					ts.setSize(TGTrackSpacing.POSITION_SCORE_DOWN_LINES, (line.maxY - (getScoreLineSpacing() * 4)) );
 				}
 			}
 			if((style & DISPLAY_TABLATURE) != 0){
-				ts.setSize(TrackSpacing.POSITION_TABLATURE_TOP_SEPARATOR, ((style & DISPLAY_SCORE) != 0 ? getMinScoreTabSpacing() : Math.max(Math.abs(line.minY), getStringSpacing()) ));
-				ts.setSize(TrackSpacing.POSITION_TABLATURE, ((style & DISPLAY_SCORE) != 0 ?  track.getTabHeight() + getStringSpacing() + 1 : Math.max( line.maxY, track.getTabHeight() + getStringSpacing() + 1) ));
-				//ts.setSize(TrackSpacing.POSITION_TABLATURE_TOP_SEPARATOR,((style & DISPLAY_SCORE) != 0 ?getMinScoreTabSpacing(): ((getStringSpacing() / 2) * 5) +1 ));
-				//ts.setSize(TrackSpacing.POSITION_TABLATURE, ((style & DISPLAY_SCORE) != 0 ?track.getTabHeight() + getStringSpacing() +1:track.getTabHeight() + ((getStringSpacing() / 2) * 5) +1 ) );
+				ts.setSize(TGTrackSpacing.POSITION_TABLATURE_TOP_SEPARATOR, ((style & DISPLAY_SCORE) != 0 ? getMinScoreTabSpacing() : Math.max(Math.abs(line.minY), getStringSpacing()) ));
+				ts.setSize(TGTrackSpacing.POSITION_TABLATURE, ((style & DISPLAY_SCORE) != 0 ?  track.getTabHeight() + getStringSpacing() + 1 : Math.max( line.maxY, track.getTabHeight() + getStringSpacing() + 1) ));
 			}
-			ts.setSize(TrackSpacing.POSITION_LYRIC,10);
+			ts.setSize(TGTrackSpacing.POSITION_LYRIC,10);
 			checkDefaultSpacing(ts);
 			
 			lineHeight = ts.getSize();
@@ -161,7 +161,7 @@ public class PrinterViewLayout extends ViewLayout{
 			posY += lineHeight + getTrackSpacing();
 			height += lineHeight + getTrackSpacing();
 			
-			ts = new TrackSpacing(this) ;
+			ts = new TGTrackSpacing(this) ;
 			line = getTempLines(track,( line.lastIndex + 1 ),ts);
 		}
 		this.setHeight(height);
@@ -202,7 +202,7 @@ public class PrinterViewLayout extends ViewLayout{
 		}
 	}
 	
-	public void paintLine(TGTrackImpl track,TempLine line,TGPainter painter,int fromX, int fromY,TrackSpacing ts) {
+	public void paintLine(TGTrackImpl track,TempLine line,TGPainter painter,int fromX, int fromY,TGTrackSpacing ts) {
 		if(this.document.isPaintable(this.page) ){
 			int posX = fromX;
 			int posY = fromY;
@@ -268,7 +268,7 @@ public class PrinterViewLayout extends ViewLayout{
 		return ((getMaxHeight() - textHeight));
 	}
 	
-	private TempLine getTempLines(TGTrack track,int fromIndex,TrackSpacing ts) {
+	private TempLine getTempLines(TGTrack track,int fromIndex,TGTrackSpacing ts) {
 		TempLine line = new TempLine();
 		int measureCount = track.countMeasures();
 		for (int measureIdx = fromIndex; measureIdx < measureCount; measureIdx++) {
@@ -312,13 +312,16 @@ public class PrinterViewLayout extends ViewLayout{
 	
 	public void setLineStyle(TGPainter painter){
 		painter.setLineWidth(1);
-		painter.setForeground(getResources().getColorBlack());
+		//painter.setForeground(getResources().getColorBlack());
+		painter.setForeground( getDarkColor( getResources().getLineColor() ) );
 	}
 	
 	public void setMeasureNumberStyle(TGPainter painter){
 		painter.setFont(getResources().getPrinterDefaultFont());
+		//painter.setBackground(getResources().getColorWhite());
+		//painter.setForeground(getResources().getColorBlack());
 		painter.setBackground(getResources().getColorWhite());
-		painter.setForeground(getResources().getColorBlack());
+		painter.setForeground(getDarkColor(getResources().getColorRed()));
 	}
 	
 	public void setDivisionsStyle(TGPainter painter, boolean fill){
@@ -327,59 +330,59 @@ public class PrinterViewLayout extends ViewLayout{
 		painter.setForeground(getResources().getColorBlack());
 	}
 	
-	public void setTempoStyle(TGPainter painter){
+	public void setTempoStyle(TGPainter painter, boolean fontStyle){
 		painter.setFont(getResources().getPrinterDefaultFont());
-		painter.setBackground(getResources().getColorWhite());
 		painter.setForeground(getResources().getColorBlack());
+		painter.setBackground( ( fontStyle ? getResources().getColorWhite() : getResources().getColorBlack() ));
 	}
 	
-	public void setTripletFeelStyle(TGPainter painter){
+	public void setTripletFeelStyle(TGPainter painter, boolean fontStyle){
 		painter.setFont(getResources().getPrinterDefaultFont());
-		painter.setBackground(getResources().getColorWhite());
 		painter.setForeground(getResources().getColorBlack());
+		painter.setBackground( ( fontStyle ? getResources().getColorWhite() : getResources().getColorBlack() ));
 	}
 	
 	public void setTabNoteStyle(TGPainter painter,boolean playMode){
 		painter.setBackground( getResources().getColorWhite() );
-		painter.setForeground(getResources().getColorBlack());
+		painter.setForeground( getDarkColor(getResources().getTabNoteColor()) );
 		painter.setFont(getResources().getPrinterNoteFont());
 	}
 	
 	public void setTabNoteFooterStyle(TGPainter painter){
-		painter.setForeground( getResources().getColorBlack());
-		painter.setBackground( getResources().getColorBlack());
+		painter.setForeground( getDarkColor(getResources().getTabNoteColor()));
+		painter.setBackground( getDarkColor(getResources().getTabNoteColor()));
 	}
 	
 	public void setTabEffectStyle(TGPainter painter){
-		painter.setForeground( getResources().getColorBlack());
-		painter.setBackground( getResources().getColorBlack());
+		painter.setForeground( getDarkColor(getResources().getTabNoteColor()));
+		painter.setBackground( getDarkColor(getResources().getTabNoteColor()));
 	}
 	
 	public void setScoreNoteStyle(TGPainter painter,boolean playing){
-		painter.setBackground( getResources().getColorBlack() );
-		painter.setForeground(getResources().getColorBlack());
+		painter.setBackground( getDarkColor(getResources().getScoreNoteColor()) );
+		painter.setForeground( getDarkColor(getResources().getScoreNoteColor()) );
 	}
 	
 	public void setScoreNoteFooterStyle(TGPainter painter){
-		painter.setForeground( getResources().getColorBlack());
-		painter.setBackground( getResources().getColorBlack());
+		painter.setForeground( getDarkColor(getResources().getScoreNoteColor()) );
+		painter.setBackground( getDarkColor(getResources().getScoreNoteColor()) );
 	}
 	
 	public void setScoreEffectStyle(TGPainter painter){
-		painter.setForeground( getResources().getColorBlack());
-		painter.setBackground( getResources().getColorBlack());
+		painter.setForeground( getDarkColor(getResources().getScoreNoteColor()) );
+		painter.setBackground( getDarkColor(getResources().getScoreNoteColor()) );
 	}
 	
 	public void setTimeSignatureStyle(TGPainter painter){
 		painter.setFont(getResources().getPrinterTimeSignatureFont());
 		painter.setBackground( getResources().getColorWhite() );
-		painter.setForeground(getResources().getColorBlack());
+		painter.setForeground( getResources().getColorBlack() );
 	}
 	
-	public void setGraceStyle(TGPainter painter){
+	public void setTabGraceStyle(TGPainter painter){
 		painter.setFont(getResources().getPrinterGraceFont());
 		painter.setBackground( getResources().getColorWhite() );
-		painter.setForeground(getResources().getColorBlack());
+		painter.setForeground( getDarkColor(getResources().getTabNoteColor()) );
 	}
 	
 	public void setLyricStyle(TGPainter painter,boolean playMode){
@@ -388,28 +391,34 @@ public class PrinterViewLayout extends ViewLayout{
 		painter.setForeground(getResources().getColorBlack());
 	}
 	
+	public void setMarkerStyle(TGPainter painter, Color color){
+		painter.setFont(getResources().getMarkerFont());
+		painter.setBackground(getResources().getColorWhite());
+		painter.setForeground(getDarkColor(color));
+	}
+	
 	public void setTextStyle(TGPainter painter){
 		painter.setFont(getResources().getPrinterTextFont());
 		painter.setBackground( getResources().getColorWhite() );
-		painter.setForeground(getResources().getColorBlack());
+		painter.setForeground( getResources().getColorBlack() );
 	}
 	
 	public void setOfflineEffectStyle(TGPainter painter){
 		painter.setFont(getResources().getPrinterDefaultFont());
 		painter.setBackground( getResources().getColorWhite() );
-		painter.setForeground(getResources().getColorBlack());
+		painter.setForeground( getResources().getColorBlack() );
 	}
 	
-	public void setTupletoStyle(TGPainter painter){
+	public void setDivisionTypeStyle(TGPainter painter){
 		painter.setFont(getResources().getPrinterDefaultFont());
 		painter.setBackground( getResources().getColorWhite() );
-		painter.setForeground(getResources().getColorBlack());
+		painter.setForeground( getResources().getColorBlack() );
 	}
 	
 	public void setRepeatEndingStyle(TGPainter painter){
 		painter.setFont(getResources().getPrinterDefaultFont());
 		painter.setBackground( getResources().getColorWhite() );
-		painter.setForeground(getResources().getColorBlack());
+		painter.setForeground( getResources().getColorBlack() );
 	}
 	
 	public void setChordStyle(TGChordImpl chord){
@@ -417,9 +426,9 @@ public class PrinterViewLayout extends ViewLayout{
 		chord.setFont(getResources().getPrinterChordFont());
 		chord.setForegroundColor(getResources().getColorBlack());
 		chord.setBackgroundColor(getResources().getColorWhite());
-		chord.setColor(getResources().getColorBlack());
-		chord.setNoteColor(getResources().getColorBlack());
-		chord.setTonicColor(getResources().getColorBlack());
+		chord.setColor(getDarkColor(getResources().getLineColor()));
+		chord.setNoteColor(getDarkColor(getResources().getTabNoteColor()));
+		chord.setTonicColor(getDarkColor(getResources().getTabNoteColor()));
 		chord.setFretSpacing(getChordFretSpacing());
 		chord.setStringSpacing(getChordStringSpacing());
 		chord.setNoteSize(getChordNoteSize());
@@ -427,6 +436,10 @@ public class PrinterViewLayout extends ViewLayout{
 		chord.setFirstFretFont(getResources().getChordFretFont());
 	}
 	
+	public Color getDarkColor( Color color ) {
+		return ( this.styles.isBlackAndWhite() ? getResources().getColorBlack() : color );
+	}
+	
 	public int getMaxWidth(){
 		return (this.document.getBounds().width - this.document.getBounds().x - 10);
 	}
@@ -443,6 +456,10 @@ public class PrinterViewLayout extends ViewLayout{
 		return (measure.getNumber() == this.styles.getToMeasure());
 	}
 	
+	public boolean hasLoopMarker(TGMeasure measure){
+		return false;
+	}
+	
 	private int getScaledValue(float scale, int value){
 		return getScaledValue(scale, value,1);
 	}
