@@ -3,14 +3,14 @@ package org.herac.tuxguitar.gui.system.plugins.base;
 import org.herac.tuxguitar.gui.TuxGuitar;
 import org.herac.tuxguitar.gui.system.plugins.TGPluginException;
 import org.herac.tuxguitar.io.base.TGFileFormatManager;
-import org.herac.tuxguitar.io.base.TGSongExporter;
+import org.herac.tuxguitar.io.base.TGRawExporter;
 
 public abstract class TGExporterPlugin extends TGPluginAdapter{
 	
 	private boolean loaded;
-	private TGSongExporter exporter;
+	private TGRawExporter exporter;
 	
-	protected abstract TGSongExporter getExporter() throws TGPluginException;
+	protected abstract TGRawExporter getExporter() throws TGPluginException;
 	
 	public void init() throws TGPluginException {
 		this.exporter = getExporter();
