@@ -2,6 +2,7 @@ package org.herac.tuxguitar.gui.tools.browser.filesystem;
 
 import java.io.File;
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.List;
 
 import org.herac.tuxguitar.gui.tools.browser.base.TGBrowser;
@@ -48,6 +49,9 @@ public class TGBrowserImpl extends TGBrowser{
 				elements.add(new TGBrowserElementImpl(this.element,files[i]));
 			}
 		}
+		if( !elements.isEmpty() ){
+			Collections.sort(elements,new TGBrowserElementComparator());
+		}
 		return elements;
 	}
 	
