@@ -7,6 +7,7 @@ import java.util.List;
 import org.herac.tuxguitar.song.managers.TGSongManager;
 import org.herac.tuxguitar.song.models.TGChannel;
 import org.herac.tuxguitar.song.models.TGDuration;
+import org.herac.tuxguitar.song.models.TGMeasureHeader;
 import org.herac.tuxguitar.song.models.TGNote;
 import org.herac.tuxguitar.song.models.TGString;
 import org.herac.tuxguitar.song.models.TGTrack;
@@ -38,6 +39,8 @@ public class MidiPlayer{
 	
 	private List sequencerProviders;
 	
+	private List listeners;
+	
 	private int volume;
 	
 	private boolean running;
@@ -45,13 +48,19 @@ public class MidiPlayer{
 	private boolean paused;
 	
 	private boolean changeTickPosition;
-		
+	
 	private boolean metronomeEnabled;
 	
 	private int metronomeTrack;
 	
 	private int infoTrack;
 	
+	private int loopSHeader;
+	
+	private int loopEHeader;
+	
+	private long loopSPosition;
+	
 	private boolean anySolo;
 	
 	protected long tickLength;
@@ -76,6 +85,7 @@ public class MidiPlayer{
 		this.songManager = songManager;
 		this.outputPortProviders = new ArrayList();
 		this.sequencerProviders = new ArrayList();
+		this.listeners = new ArrayList();
 		this.getSequencer();
 		this.getMode();
 		this.reset();
@@ -154,12 +164,14 @@ public class MidiPlayer{
 	 */
 	public synchronized void play() throws MidiPlayerException{
 		try {
+			final boolean notifyStarted = (!this.isRunning());
 			this.setStarting(true);
 			this.stop();
 			this.lock.lock();
-			this.checkOutput();
+			this.checkDevices();
+			this.updateLoop( true );
 			this.systemReset();
-			this.addSecuence();
+			this.addSequence();
 			this.updatePrograms();
 			this.updateControllers();
 			this.updateDefaultControllers();
@@ -172,7 +184,11 @@ public class MidiPlayer{
 					try {
 						MidiPlayer.this.lock.lock();
 						
-						setStarting(false);
+						MidiPlayer.this.setStarting(false);
+						
+						if( notifyStarted ){
+							MidiPlayer.this.notifyStarted();
+						}
 						
 						MidiPlayer.this.tickLength = getSequencer().getTickLength();
 						MidiPlayer.this.tickPosition = getSequencer().getTickPosition();
@@ -197,6 +213,10 @@ public class MidiPlayer{
 								stop(isPaused());
 							}
 						}
+						
+						if( !isRunning() ){
+							MidiPlayer.this.notifyStopped();
+						}
 					}catch (Throwable throwable) {
 						setStarting(false);
 						reset();
@@ -221,6 +241,7 @@ public class MidiPlayer{
 				this.setStarting(true);
 				this.reset();
 				this.getMode().notifyLoop();
+				this.notifyLoop();
 				this.play();
 				return;
 			}
@@ -230,9 +251,41 @@ public class MidiPlayer{
 		}
 	}
 	
-	public void checkOutput() throws Throwable {
-		if( getOutputPort() != null ){
-			getOutputPort().check();
+	public void updateLoop( boolean force ){
+		if( force || !this.isRunning() ){
+			this.loopSHeader = -1;
+			this.loopEHeader = -1;
+			this.loopSPosition = TGDuration.QUARTER_TIME;
+			if( getMode().isLoop() ){
+				int hCount = this.songManager.getSong().countMeasureHeaders();
+				this.loopSHeader = ( getMode().getLoopSHeader() <= hCount ? getMode().getLoopSHeader() : -1 ) ;
+				this.loopEHeader = ( getMode().getLoopEHeader() <= hCount ? getMode().getLoopEHeader() : -1 ) ;
+				if( this.loopSHeader > 0 && this.loopSHeader <= hCount ){
+					TGMeasureHeader header = this.songManager.getMeasureHeader( this.loopSHeader );
+					if( header != null ){
+						this.loopSPosition = header.getStart();
+					}
+				}
+			}
+		}
+	}
+	
+	public int getLoopSHeader() {
+		return this.loopSHeader;
+	}
+	
+	public int getLoopEHeader() {
+		return this.loopEHeader;
+	}
+	
+	public long getLoopSPosition() {
+		return this.loopSPosition;
+	}
+	
+	public void checkDevices() throws Throwable {
+		this.getSequencer().check();
+		if( this.getOutputPort() != null ){
+			this.getOutputPort().check();
 		}
 	}
 	
@@ -315,6 +368,9 @@ public class MidiPlayer{
 	protected void changeTickPosition(){
 		try{
 			if(isRunning()){
+				if( this.tickPosition < this.getLoopSPosition() ){
+					this.tickPosition = this.getLoopSPosition();
+				}
 				this.getSequencer().setTickPosition(this.tickPosition);
 			}
 			setChangeTickPosition(false);
@@ -335,13 +391,15 @@ public class MidiPlayer{
 	 * Agrega la Secuencia
 	 * @throws MidiUnavailableException 
 	 */
-	public void addSecuence() {
+	public void addSequence() {
 		try{
 			MidiSequenceParser parser = new MidiSequenceParser(this.songManager,MidiSequenceParser.DEFAULT_PLAY_FLAGS,getMode().getCurrentPercent(),0);		
 			MidiSequenceHandler sequence = getSequencer().createSequence(this.songManager.getSong().countTracks() + 2);
+			parser.setSHeader( getLoopSHeader() );
+			parser.setEHeader( getLoopEHeader() );
 			parser.parse(sequence);
-			this.infoTrack = sequence.getInfoTrack();
-			this.metronomeTrack = sequence.getMetronomeTrack();
+			this.infoTrack = parser.getInfoTrack();
+			this.metronomeTrack = parser.getMetronomeTrack();
 		} catch (MidiPlayerException e) {
 			e.printStackTrace();
 		}
@@ -378,15 +436,15 @@ public class MidiPlayer{
 	
 	public void updateControllers() {
 		this.anySolo = false;
-		boolean percusionUpdated = false;
+		boolean percussionUpdated = false;
 		Iterator it = this.songManager.getSong().getTracks();
 		while(it.hasNext()){
 			TGTrack track = (TGTrack)it.next();
 			this.updateController(track);
 			this.anySolo = ((!this.anySolo)?track.isSolo():this.anySolo);
-			percusionUpdated = (percusionUpdated || track.isPercussionTrack());
+			percussionUpdated = (percussionUpdated || track.isPercussionTrack());
 		}
-		if(!percusionUpdated && isMetronomeEnabled()){
+		if(!percussionUpdated && isMetronomeEnabled()){
 			int volume = (int)((this.getVolume() / 10.00) * TGChannel.DEFAULT_VOLUME);
 			int balance = TGChannel.DEFAULT_BALANCE;
 			int chorus = TGChannel.DEFAULT_CHORUS;
@@ -757,5 +815,41 @@ public class MidiPlayer{
 				}
 			}
 		}
-	}	
+	}
+	
+	public void addListener( MidiPlayerListener listener ){
+		if( !this.listeners.contains( listener ) ){
+			this.listeners.add( listener );
+		}
+	}
+	
+	public void removeListener( MidiPlayerListener listener ){
+		if( this.listeners.contains( listener ) ){
+			this.listeners.remove( listener );
+		}
+	}
+	
+	public void notifyStarted(){
+		Iterator it = this.listeners.iterator();
+		while( it.hasNext() ){
+			MidiPlayerListener listener = (MidiPlayerListener) it.next();
+			listener.notifyStarted();
+		}
+	}
+	
+	public void notifyStopped(){
+		Iterator it = this.listeners.iterator();
+		while( it.hasNext() ){
+			MidiPlayerListener listener = (MidiPlayerListener) it.next();
+			listener.notifyStopped();
+		}
+	}
+	
+	public void notifyLoop(){
+		Iterator it = this.listeners.iterator();
+		while( it.hasNext() ){
+			MidiPlayerListener listener = (MidiPlayerListener) it.next();
+			listener.notifyLoop();
+		}
+	}
 }
