@@ -84,18 +84,24 @@ public class MidiSequenceParser {
 	 */
 	private int metronomeTrack;
 	
-	private int fisrtTickMove;
+	private int firstTickMove;
 	
 	private int tempoPercent;
 	
 	private int transpose;
 	
+	private int sHeader;
+	
+	private int eHeader;
+	
 	public MidiSequenceParser(TGSongManager manager,int flags,int tempoPercent,int transpose) {
 		this.manager = manager;
 		this.flags = flags;
 		this.transpose = transpose;
 		this.tempoPercent = tempoPercent;
-		this.fisrtTickMove = (int)(((flags & ADD_FIRST_TICK_MOVE) != 0)?(-TGDuration.QUARTER_TIME):0);
+		this.firstTickMove = (int)(((flags & ADD_FIRST_TICK_MOVE) != 0)?(-TGDuration.QUARTER_TIME):0);
+		this.sHeader = -1;
+		this.eHeader = -1;
 	}
 	
 	public MidiSequenceParser(TGSongManager manager,int flags) {
@@ -106,8 +112,8 @@ public class MidiSequenceParser {
 	 * Crea la cancion
 	 */
 	public void parse(MidiSequenceHandler sequence) {
-		this.infoTrack = sequence.getInfoTrack();
-		this.metronomeTrack = sequence.getMetronomeTrack();
+		this.infoTrack = 0;
+		this.metronomeTrack = (sequence.getTracks() - 1);
 		addDefaultMessages(sequence);
 		for (int i = 0; i < this.manager.getSong().countTracks(); i++) {
 			TGTrack songTrack = this.manager.getSong().getTrack(i);
@@ -116,24 +122,35 @@ public class MidiSequenceParser {
 		sequence.notifyFinish();
 	}
 	
-	private int infoIndex(){
+	public int getInfoTrack(){
 		return this.infoTrack;
 	}
 	
-	private int metronomeIndex(){
+	public int getMetronomeTrack(){
 		return this.metronomeTrack;
 	}
 	
 	private long getTick(long tick){
-		return (tick + this.fisrtTickMove);
+		return (tick + this.firstTickMove);
 	}
 	
+	public void setSHeader(int header) {
+		this.sHeader = header;
+	}
+	
+	public void setEHeader(int header) {
+		this.eHeader = header;
+	}
+	
+	private int fix( int value ){
+		return ( value >= 0 ? value <= 127 ? value : 127 : 0 );
+	}
 	/**
 	 * Crea las pistas de la cancion
 	 */
 	private void createTrack(MidiSequenceHandler sequence,TGTrack track) {
 		TGMeasure previous = null;
-		MidiRepeatController controller = new MidiRepeatController(track.getSong());
+		MidiRepeatController controller = new MidiRepeatController(track.getSong(),this.sHeader,this.eHeader);
 		
 		addBend(sequence,track.getNumber(),TGDuration.QUARTER_TIME,DEFAULT_BEND,track.getChannel().getChannel());
 		makeChannel(sequence, track.getChannel(), track.getNumber());
@@ -150,8 +167,9 @@ public class MidiSequenceParser {
 				}
 				//agrego los pulsos
 				makeBeats(sequence, track, measure,index, move);
+				
+				previous = measure;
 			}
-			previous = measure;
 		}
 	}
 	
@@ -258,7 +276,7 @@ public class MidiSequenceParser {
 					//---Slide---
 					else if(note.getEffect().isSlide() && effectChannel >= 0 && !percussionTrack){
 						channel = effectChannel;
-						TGNote nextNote = getNextNote(note,track,measureIdx,bIndex);
+						TGNote nextNote = getNextNote(note,track,measureIdx,bIndex,true);
 						makeSlide(sequence,trackId,note,nextNote,startMove,channel);
 					}
 					//---Vibrato---
@@ -304,8 +322,8 @@ public class MidiSequenceParser {
 	 * Crea una nota en la posicion start
 	 */
 	private void makeNote(MidiSequenceHandler sequence,int track, int key, long start, long duration, int velocity, int channel) {
-		sequence.addNoteOn(getTick(start),track,channel,key,velocity);
-		sequence.addNoteOff(getTick(start + duration),track,channel,key,velocity);
+		sequence.addNoteOn(getTick(start),track,channel,fix(key),fix(velocity));
+		sequence.addNoteOff(getTick(start + duration),track,channel,fix(key),fix(velocity));
 	}
 	
 	private void makeChannel(MidiSequenceHandler sequence,TGChannel channel,int track) {
@@ -319,14 +337,14 @@ public class MidiSequenceParser {
 	
 	private void makeChannel(MidiSequenceHandler sequence,TGChannel channel,int track,boolean primary) {
 		int number = (primary?channel.getChannel():channel.getEffectChannel());
-		sequence.addControlChange(getTick(TGDuration.QUARTER_TIME),track,number,MidiControllers.VOLUME,channel.getVolume());
-		sequence.addControlChange(getTick(TGDuration.QUARTER_TIME),track,number,MidiControllers.BALANCE,channel.getBalance());
-		sequence.addControlChange(getTick(TGDuration.QUARTER_TIME),track,number,MidiControllers.CHORUS,channel.getChorus());
-		sequence.addControlChange(getTick(TGDuration.QUARTER_TIME),track,number,MidiControllers.REVERB,channel.getReverb());
-		sequence.addControlChange(getTick(TGDuration.QUARTER_TIME),track,number,MidiControllers.PHASER,channel.getPhaser());
-		sequence.addControlChange(getTick(TGDuration.QUARTER_TIME),track,number,MidiControllers.TREMOLO,channel.getTremolo());
+		sequence.addControlChange(getTick(TGDuration.QUARTER_TIME),track,number,MidiControllers.VOLUME,fix(channel.getVolume()));
+		sequence.addControlChange(getTick(TGDuration.QUARTER_TIME),track,number,MidiControllers.BALANCE,fix(channel.getBalance()));
+		sequence.addControlChange(getTick(TGDuration.QUARTER_TIME),track,number,MidiControllers.CHORUS,fix(channel.getChorus()));
+		sequence.addControlChange(getTick(TGDuration.QUARTER_TIME),track,number,MidiControllers.REVERB,fix(channel.getReverb()));
+		sequence.addControlChange(getTick(TGDuration.QUARTER_TIME),track,number,MidiControllers.PHASER,fix(channel.getPhaser()));
+		sequence.addControlChange(getTick(TGDuration.QUARTER_TIME),track,number,MidiControllers.TREMOLO,fix(channel.getTremolo()));
 		sequence.addControlChange(getTick(TGDuration.QUARTER_TIME),track,number,MidiControllers.EXPRESSION, 127);
-		sequence.addProgramChange(getTick(TGDuration.QUARTER_TIME),track,number,channel.getInstrument());
+		sequence.addProgramChange(getTick(TGDuration.QUARTER_TIME),track,number,fix(channel.getInstrument()));
 	}
 	/**
 	 * Agrega un Time Signature si es distinto al anterior
@@ -345,7 +363,7 @@ public class MidiSequenceParser {
 			}
 		}
 		if (addTimeSignature) {
-			sequence.addTimeSignature(getTick(currMeasure.getStart() + startMove), infoIndex(), currMeasure.getTimeSignature());
+			sequence.addTimeSignature(getTick(currMeasure.getStart() + startMove), getInfoTrack(), currMeasure.getTimeSignature());
 		}
 	}
 	
@@ -363,7 +381,7 @@ public class MidiSequenceParser {
 		}
 		if (addTempo) {
 			int usq = (int)(currMeasure.getTempo().getInUSQ() * 100.00 / this.tempoPercent );
-			sequence.addTempoInUSQ(getTick(currMeasure.getStart() + startMove), infoIndex(), usq);
+			sequence.addTempoInUSQ(getTick(currMeasure.getStart() + startMove), getInfoTrack(), usq);
 		}
 	}
 	
@@ -374,7 +392,7 @@ public class MidiSequenceParser {
 		long lastEnd = (note.getVoice().getBeat().getStart() + note.getVoice().getDuration().getTime());
 		long realDuration = duration;
 		int nextBIndex = (bIndex + 1);
-		int measureCount = track.countMeasures();
+		int measureCount = ( this.eHeader == -1 ? track.countMeasures() : Math.min( this.eHeader, track.countMeasures() ) );
 		for (int m = mIndex; m < measureCount; m++) {
 			TGMeasure measure = track.getMeasure( m );
 			int beatCount = measure.countBeats();
@@ -430,7 +448,7 @@ public class MidiSequenceParser {
 		
 		//Check for Hammer effect
 		if(!songTrack.isPercussionTrack()){
-			TGNote prevNote = getPreviousNote(note,songTrack,mIndex,bIndex);
+			TGNote prevNote = getPreviousNote(note,songTrack,mIndex,bIndex,false);
 			if(prevNote != null && prevNote.getEffect().isHammer()){
 				velocity = Math.max(TGVelocities.MIN_VELOCITY,(velocity - 25));
 			}
@@ -454,7 +472,7 @@ public class MidiSequenceParser {
 			long start = (startMove + header.getStart());
 			long length = header.getTimeSignature().getDenominator().getTime();
 			for(int i = 1; i <= header.getTimeSignature().getNumerator();i ++){
-				makeNote(sequence,metronomeIndex(),DEFAULT_METRONOME_KEY,start,length,TGVelocities.DEFAULT,9);
+				makeNote(sequence,getMetronomeTrack(),DEFAULT_METRONOME_KEY,start,length,TGVelocities.DEFAULT,9);
 				start += length;
 			}
 		}
@@ -463,16 +481,16 @@ public class MidiSequenceParser {
 	public void addDefaultMessages(MidiSequenceHandler sequence) {
 		if( (this.flags & ADD_DEFAULT_CONTROLS) != 0) {
 			for(int i = 0; i < 16; i ++){
-				sequence.addControlChange(getTick(TGDuration.QUARTER_TIME),infoIndex(),i,MidiControllers.RPN_MSB,0);
-				sequence.addControlChange(getTick(TGDuration.QUARTER_TIME),infoIndex(),i,MidiControllers.RPN_LSB,0);
-				sequence.addControlChange(getTick(TGDuration.QUARTER_TIME),infoIndex(),i,MidiControllers.DATA_ENTRY_MSB,12);
-				sequence.addControlChange(getTick(TGDuration.QUARTER_TIME),infoIndex(),i,MidiControllers.DATA_ENTRY_LSB, 0);
+				sequence.addControlChange(getTick(TGDuration.QUARTER_TIME),getInfoTrack(),i,MidiControllers.RPN_MSB,0);
+				sequence.addControlChange(getTick(TGDuration.QUARTER_TIME),getInfoTrack(),i,MidiControllers.RPN_LSB,0);
+				sequence.addControlChange(getTick(TGDuration.QUARTER_TIME),getInfoTrack(),i,MidiControllers.DATA_ENTRY_MSB,12);
+				sequence.addControlChange(getTick(TGDuration.QUARTER_TIME),getInfoTrack(),i,MidiControllers.DATA_ENTRY_LSB, 0);
 			}
 		}
 	}
 	
 	private void addBend(MidiSequenceHandler sequence,int track, long tick,int bend, int channel) {
-		sequence.addPitchBend(getTick(tick),track,channel,bend);
+		sequence.addPitchBend(getTick(tick),track,channel,fix(bend));
 	}
 	
 	public void makeVibrato(MidiSequenceHandler sequence,int track,long start, long duration,int channel){
@@ -585,7 +603,7 @@ public class MidiSequenceParser {
 		long tick = start;
 		long tickIncrement = (duration / ((127 - expression) / expressionIncrement));
 		while( tick < (start + duration) && expression < 127 ) {
-			sequence.addControlChange(getTick(tick),track,channel,MidiControllers.EXPRESSION, expression);
+			sequence.addControlChange(getTick(tick),track,channel,MidiControllers.EXPRESSION, fix(expression));
 			tick += tickIncrement;
 			expression += expressionIncrement;
 		}
@@ -646,8 +664,8 @@ public class MidiSequenceParser {
 					TGVoice v = getNextBeat(voice,bIndex);
 					if(v == null || ( v.getBeat().getStart() > (bStart + voice.getDuration().getTime()) || v.getDuration().isEqual(newDuration(TGDuration.EIGHTH)))  ){
 						TGDuration duration = newDuration(TGDuration.EIGHTH);
-						duration.getTupleto().setEnters(3);
-						duration.getTupleto().setTimes(2);
+						duration.getDivision().setEnters(3);
+						duration.getDivision().setTimes(2);
 						bDuration = (duration.getTime() * 2);
 					}
 				}
@@ -656,8 +674,8 @@ public class MidiSequenceParser {
 					TGVoice v = getPreviousBeat(voice,bIndex);
 					if(v == null || ( v.getBeat().getStart() < (bStart - voice.getDuration().getTime())  || v.getDuration().isEqual(newDuration(TGDuration.EIGHTH)) )){
 						TGDuration duration = newDuration(TGDuration.EIGHTH);
-						duration.getTupleto().setEnters(3);
-						duration.getTupleto().setTimes(2);
+						duration.getDivision().setEnters(3);
+						duration.getDivision().setTimes(2);
 						bStart = ( (bStart - voice.getDuration().getTime()) + (duration.getTime() * 2));
 						bDuration = duration.getTime();
 					}
@@ -670,8 +688,8 @@ public class MidiSequenceParser {
 					TGVoice v = getNextBeat(voice,bIndex);
 					if(v == null || ( v.getBeat().getStart() > (bStart + voice.getDuration().getTime()) || v.getDuration().isEqual(newDuration(TGDuration.SIXTEENTH)))  ){
 						TGDuration duration = newDuration(TGDuration.SIXTEENTH);
-						duration.getTupleto().setEnters(3);
-						duration.getTupleto().setTimes(2);
+						duration.getDivision().setEnters(3);
+						duration.getDivision().setTimes(2);
 						bDuration = (duration.getTime() * 2);
 					}
 				}
@@ -680,8 +698,8 @@ public class MidiSequenceParser {
 					TGVoice v = getPreviousBeat(voice,bIndex);
 					if(v == null || ( v.getBeat().getStart() < (bStart - voice.getDuration().getTime())  || v.getDuration().isEqual(newDuration(TGDuration.SIXTEENTH)) )){
 						TGDuration duration = newDuration(TGDuration.SIXTEENTH);
-						duration.getTupleto().setEnters(3);
-						duration.getTupleto().setTimes(2);
+						duration.getDivision().setEnters(3);
+						duration.getDivision().setTimes(2);
 						bStart = ( (bStart - voice.getDuration().getTime()) + (duration.getTime() * 2));
 						bDuration = duration.getTime();
 					}
@@ -723,42 +741,53 @@ public class MidiSequenceParser {
 		return next;
 	}
 	
-	private TGNote getNextNote(TGNote note,TGTrack track, int mIndex, int bIndex){ 
+	private TGNote getNextNote(TGNote note,TGTrack track, int mIndex, int bIndex, boolean breakAtRest){ 
 		int nextBIndex = (bIndex + 1);
-		int measureCount = track.countMeasures();
+		int measureCount = ( this.eHeader == -1 ? track.countMeasures() : Math.min( this.eHeader, track.countMeasures() ) );
 		for (int m = mIndex; m < measureCount; m++) {
 			TGMeasure measure = track.getMeasure( m );
 			int beatCount = measure.countBeats();
 			for (int b = nextBIndex; b < beatCount; b++) {
 				TGBeat beat = measure.getBeat( b );
 				TGVoice voice = beat.getVoice( note.getVoice().getIndex() );
-				int noteCount = voice.countNotes();
-				for (int n = 0; n < noteCount; n++) {
-					TGNote currNote = voice.getNote( n );
-					if(currNote.getString() == note.getString()){
-						return currNote;
+				if( !voice.isEmpty() ){
+					int noteCount = voice.countNotes();
+					for (int n = 0; n < noteCount; n++) {
+						TGNote currNote = voice.getNote( n );
+						if(currNote.getString() == note.getString()){
+							return currNote;
+						}
+					}
+					if( breakAtRest ){
+						return null;
 					}
 				}
-				return null;
 			}
 			nextBIndex = 0;
 		}
 		return null;
 	}
 	
-	private TGNote getPreviousNote(TGNote note,TGTrack track, int mIndex, int bIndex){
+	private TGNote getPreviousNote(TGNote note,TGTrack track, int mIndex, int bIndex, boolean breakAtRest){
 		int nextBIndex = bIndex;
 		for (int m = mIndex; m >= 0; m--) {
 			TGMeasure measure = track.getMeasure( m );
-			nextBIndex = (nextBIndex < 0 ? measure.countBeats() : nextBIndex);
-			for (int b = (nextBIndex - 1); b >= 0; b--) {
-				TGBeat beat = measure.getBeat( b );
-				TGVoice voice = beat.getVoice( note.getVoice().getIndex() );
-				int noteCount = voice.countNotes();
-				for (int n = 0; n < noteCount; n ++) {
-					TGNote current = voice.getNote( n );
-					if(current.getString() == note.getString()){
-						return current;
+			if( this.sHeader == -1 || this.sHeader <= measure.getNumber() ){
+				nextBIndex = (nextBIndex < 0 ? measure.countBeats() : nextBIndex);
+				for (int b = (nextBIndex - 1); b >= 0; b--) {
+					TGBeat beat = measure.getBeat( b );
+					TGVoice voice = beat.getVoice( note.getVoice().getIndex() );
+					if( !voice.isEmpty() ){
+						int noteCount = voice.countNotes();
+						for (int n = 0; n < noteCount; n ++) {
+							TGNote current = voice.getNote( n );
+							if(current.getString() == note.getString()){
+								return current;
+							}
+						}
+						if( breakAtRest ){
+							return null;
+						}
 					}
 				}
 			}
