@@ -1,6 +1,8 @@
 package org.herac.tuxguitar.song.managers;
 
 import java.util.ArrayList;
+import java.util.Collections;
+import java.util.Comparator;
 import java.util.Iterator;
 import java.util.List;
 
@@ -13,6 +15,7 @@ import org.herac.tuxguitar.song.models.TGNote;
 import org.herac.tuxguitar.song.models.TGString;
 import org.herac.tuxguitar.song.models.TGStroke;
 import org.herac.tuxguitar.song.models.TGText;
+import org.herac.tuxguitar.song.models.TGTrack;
 import org.herac.tuxguitar.song.models.TGVoice;
 import org.herac.tuxguitar.song.models.effects.TGEffectBend;
 import org.herac.tuxguitar.song.models.effects.TGEffectGrace;
@@ -43,7 +46,7 @@ public class TGMeasureManager {
 			}
 			measure.moveBeat(i, minBeat);
 		}
-	}	
+	}
 	
 	/**
 	 * Agrega un beat al compas
@@ -86,7 +89,7 @@ public class TGMeasureManager {
 			if(next != null){
 				length = next.getStart() - start;
 			}
-			moveBeats(beat.getMeasure(),start + length,-length, minimumDuration);
+			moveBeatsInMeasure(beat.getMeasure(),start + length,-length, minimumDuration);
 		}
 	}
 	
@@ -113,7 +116,7 @@ public class TGMeasureManager {
 			this.removeBeat( beat );
 		}
 	}
-	
+		
 	public void removeBeatsBeforeEnd(TGMeasure measure,long fromStart){
 		List beats = getBeatsBeforeEnd( measure.getBeats() , fromStart);
 		Iterator it = beats.iterator();
@@ -123,6 +126,15 @@ public class TGMeasureManager {
 		}
 	}
 	
+	public void removeBeatsBeetween(TGMeasure measure,long p1, long p2){
+		List beats = getBeatsBeetween( measure.getBeats() , p1, p2 );
+		Iterator it = beats.iterator();
+		while(it.hasNext()){
+			TGBeat beat = (TGBeat) it.next();
+			removeBeat(beat);
+		}
+	}
+	
 	public void addNote(TGMeasure measure,long start, TGNote note, TGDuration duration, int voice){
 		TGBeat beat = getBeat(measure, start);
 		if(beat != null){
@@ -166,8 +178,28 @@ public class TGMeasureManager {
 		}
 	}
 	
+	public void removeNote(TGNote note, boolean checkRestBeat){
+		//note.getVoice().removeNote(note);
+		TGVoice voice = note.getVoice();
+		if( voice != null ){
+			// Remove the note
+			voice.removeNote(note);
+			
+			TGBeat beat = voice.getBeat();
+			if(checkRestBeat && beat.isRestBeat()){
+				//Anulo un posible stroke
+				beat.getStroke().setDirection( TGStroke.STROKE_NONE );
+				
+				//Borro un posible acorde
+				if( beat.getMeasure() != null ){
+					removeChord(beat.getMeasure(), beat.getStart());
+				}
+			}
+		}
+	}
+	
 	public void removeNote(TGNote note){
-		note.getVoice().removeNote(note);
+		this.removeNote(note, true);
 	}
 	
 	public void removeNote(TGMeasure measure,long start, int voiceIndex,int string){
@@ -185,88 +217,13 @@ public class TGMeasureManager {
 			for( int i = 0; i < voice.countNotes(); i ++){
 				TGNote note = voice.getNote(i);
 				if(note.getString() == string){
-					removeNote(note);
-					
-					if(checkRestBeat && beat.isRestBeat()){
-						//Anulo un posible stroke
-						beat.getStroke().setDirection( TGStroke.STROKE_NONE );
-						
-						//Borro un posible acorde
-						removeChord(measure, beat.getStart());
-					}
+					removeNote(note , checkRestBeat);
 					return;
 				}
 			}
 		}
 	}
 	
-	/*
-	@Deprecated
-	public void addNote(TGMeasure measure,long start, TGNote note, TGDuration duration){
-		TGBeat beat = getBeat(measure, start);
-		if(beat != null){
-			addNote(beat, note, duration);
-		}
-	}
-	
-	@Deprecated
-	public void addNote(TGBeat beat, TGNote note, TGDuration duration){
-		addNote(beat, note, duration, beat.getStart());
-	}
-	
-	@Deprecated
-	public void addNote(TGBeat beat, TGNote note, TGDuration duration, long start){
-		//Verifico si entra en el compas
-		if(validateDuration(beat.getMeasure(),beat, duration,true,true)){
-			//Borro lo que haya en la misma posicion
-			removeNote(beat.getMeasure(),beat.getStart(),note.getString());
-			
-			duration.copy(beat.getDuration());
-			
-			//trato de agregar un silencio similar al lado
-			tryChangeSilenceAfter(beat.getMeasure(),beat);
-			
-			// Despues de cambiar la duracion, verifico si hay un beat mejor para agregar la nota.
-			TGBeat realBeat = beat;
-			if(realBeat.getStart() != start){
-				TGBeat beatIn = getBeatIn(realBeat.getMeasure(), start);
-				if( beatIn != null ) {
-					realBeat = beatIn;
-				}
-			}
-			realBeat.addNote(note);
-		}
-	}
-	
-	public void removeNote(TGNote note){
-		note.getBeat().removeNote(note);
-	}
-	*/
-	/**
-	 * Elimina los Componentes que empiecen en Start y esten en la misma cuerda
-	 * Si hay un Silencio lo borra sin importar la cuerda
-	 */
-	/*
-	@Deprecated
-	public void removeNote(TGMeasure measure,long start,int string){
-		TGBeat beat = getBeat(measure, start);
-		if(beat != null){
-			for( int i = 0; i < beat.countNotes(); i ++){
-				TGNote note = beat.getNote(i);
-				if(note.getString() == string){
-					removeNote(note);
-					
-					//si era el unico componente agrego un silencio
-					if(beat.isRestBeat()){
-						//Borro un posible acorde
-						removeChord(measure, beat.getStart());
-					}
-					return;
-				}
-			}
-		}
-	}
-	*/
 	public void removeNotesAfterString(TGMeasure measure,int string){
 		List notesToRemove = new ArrayList();
 		
@@ -311,6 +268,27 @@ public class TGMeasureManager {
 		return notes;
 	}
 	
+	/**
+	 * Retorna Todas las Notas en el pulso
+	 */
+	public List getNotes(TGBeat beat){
+		List notes = new ArrayList();
+		
+		if(beat != null){
+			for(int v = 0 ; v < beat.countVoices(); v ++){
+				TGVoice voice = beat.getVoice( v );
+				if( !voice.isEmpty() && !voice.isRestVoice() ){
+					Iterator it = voice.getNotes().iterator();
+					while(it.hasNext()){
+						TGNote note = (TGNote)it.next();
+						notes.add(note);
+					}
+				}
+			}
+		}
+		return notes;
+	}
+	
 	/**
 	 * Retorna la Nota en la posicion y cuerda
 	 */
@@ -402,6 +380,20 @@ public class TGMeasureManager {
 		return minimumDuration;
 	}
 	
+	public TGBeat getBeat(TGTrack track,long start) {
+		Iterator measures = track.getMeasures();
+		while( measures.hasNext() ){
+			TGMeasure measure = (TGMeasure)measures.next();
+			Iterator beats = measure.getBeats().iterator();
+			while(beats.hasNext()){
+				TGBeat beat = (TGBeat)beats.next();
+				if (beat.getStart() == start) {
+					return beat;
+				}
+			}
+		}
+		return null;
+	}
 	/**
 	 * Retorna las Nota en la posicion y cuerda
 	 */
@@ -545,34 +537,122 @@ public class TGMeasureManager {
 		return list;
 	}
 	
+	public List getBeatsBeetween(List beats,long p1, long p2) {
+		List list = new ArrayList();
+		Iterator it = beats.iterator();
+		while(it.hasNext()){
+			TGBeat current = (TGBeat)it.next();
+			if (current.getStart() >= p1 && current.getStart() < p2 ) {
+				list.add(current);
+			}
+		}
+		return list;
+	}
+	
+	public void locateBeat( TGBeat beat, TGTrack track , boolean newMeasureAlsoForRestBeats) {
+		if( beat.getMeasure() != null ){
+			beat.getMeasure().removeBeat(beat);
+			beat.setMeasure(null);
+		}
+		TGMeasure newMeasure = getSongManager().getTrackManager().getMeasureAt(track, beat.getStart() );
+		if( newMeasure == null ){
+			boolean createNewMeasure = newMeasureAlsoForRestBeats;
+			if( !createNewMeasure ){
+				createNewMeasure = ( !beat.isRestBeat() || beat.isTextBeat() );
+			}
+			if( createNewMeasure ){
+				
+				while( newMeasure == null && beat.getStart() >= TGDuration.QUARTER_TIME){
+					getSongManager().addNewMeasureBeforeEnd();
+					newMeasure = getSongManager().getTrackManager().getMeasureAt(track, beat.getStart() );
+				}
+			}
+		}
+		if( newMeasure != null ){
+			long mStart = newMeasure.getStart();
+			long mLength = newMeasure.getLength();
+			long bStart = beat.getStart();
+			for( int v = 0 ; v < beat.countVoices() ; v ++ ){
+				TGVoice voice = beat.getVoice( v );
+				long vDuration = voice.getDuration().getTime();
+				if(!voice.isEmpty() && (bStart + vDuration) > (mStart + mLength) ){
+					long vTiedDuration = ( (bStart + vDuration) - (mStart + mLength) );
+					vDuration -= vTiedDuration;
+					if( vDuration > 0 ){
+						TGDuration duration = TGDuration.fromTime(getSongManager().getFactory(), vDuration);
+						if( duration != null ){
+							duration.copy( voice.getDuration() );
+						}
+					}
+					if( vTiedDuration > 0 ) {
+						TGDuration newVoiceDuration = TGDuration.fromTime(getSongManager().getFactory(), vTiedDuration);
+						if( newVoiceDuration != null ){
+							long newBeatStart = (bStart + vDuration);
+							TGBeat newBeat = getBeat(track, newBeatStart);
+							if( newBeat == null ){
+								newBeat = getSongManager().getFactory().newBeat();
+								newBeat.setStart( (bStart + vDuration) );
+							}
+							TGVoice newVoice = newBeat.getVoice( v );
+							for( int n = 0 ; n < voice.countNotes() ; n ++ ){
+								TGNote note = voice.getNote( n );
+								TGNote newNote = getSongManager().getFactory().newNote();
+								newNote.setTiedNote( true );
+								newNote.setValue( note.getValue() );
+								newNote.setString( note.getString() );
+								newNote.setVelocity( note.getVelocity() );
+								newVoice.addNote( newNote );
+							}
+							newVoice.setEmpty( false );
+							newVoiceDuration.copy( newVoice.getDuration() );
+							
+							locateBeat(newBeat, track, newMeasureAlsoForRestBeats);
+						}
+					}
+				}
+			}
+			
+			newMeasure.addBeat(beat);
+		}
+	}
+	
 	public void moveOutOfBoundsBeatsToNewMeasure(TGMeasure measure){
+		this.moveOutOfBoundsBeatsToNewMeasure(measure, true );
+	}
+	
+	public void moveOutOfBoundsBeatsToNewMeasure(TGMeasure measure, boolean newMeasureAlsoForRestBeats ){
 		List beats = new ArrayList();
+		long mStart = measure.getStart();
+		long mLength = measure.getLength();
 		for( int i = 0; i < measure.countBeats() ; i ++ ){
 			TGBeat beat = measure.getBeat( i );
-			if( beat.getStart() < measure.getStart() || beat.getStart() >= measure.getStart() + measure.getLength() ){
+			if( beat.getStart() < mStart || beat.getStart() >= mStart + mLength ){
 				beats.add( beat );
 			}
+			else{
+				long bStart = beat.getStart();
+				for( int v = 0 ; v < beat.countVoices() ; v ++ ){
+					TGVoice voice = beat.getVoice( v );
+					long vDuration = voice.getDuration().getTime();
+					if(!voice.isEmpty() && (bStart + vDuration) > (mStart + mLength) ){
+						beats.add( beat );
+					}
+				}
+			}
 		}
 		while( !beats.isEmpty() ){
 			TGBeat beat = (TGBeat)beats.get( 0 );
-			beat.getMeasure().removeBeat(beat);
-			beat.setMeasure(null);
-			
-			TGMeasure newMeasure = getSongManager().getTrackManager().getMeasureAt(measure.getTrack(), beat.getStart() );
-			while( newMeasure == null ){
-				getSongManager().addNewMeasureBeforeEnd();
-				newMeasure = getSongManager().getTrackManager().getMeasureAt(measure.getTrack(), beat.getStart() );
+			if( beat.getMeasure() != null ){
+				beat.getMeasure().removeBeat(beat);
+				beat.setMeasure(null);
 			}
-			newMeasure.addBeat(beat);
+			this.locateBeat(beat, measure.getTrack(), newMeasureAlsoForRestBeats);
+			
 			beats.remove(0);
 		}
 	}
 	
-	public void moveAllBeats(TGMeasure measure,long theMove){
-		moveBeats(measure.getBeats(),theMove);
-	}
-	
-	public boolean moveBeats(TGMeasure measure,long start,long theMove, TGDuration fillDuration){
+	public boolean moveBeatsInMeasure(TGMeasure measure,long start,long theMove, TGDuration fillDuration){
 		if( theMove == 0 ){
 			return false;
 		}
@@ -662,6 +742,14 @@ public class TGMeasureManager {
 		return success;
 	}
 	
+	public void moveAllBeats(TGMeasure measure,long theMove){
+		moveBeats(measure.getBeats(),theMove);
+	}
+	
+	public void moveBeats(TGMeasure measure, long start, long theMove){
+		moveBeats(getBeatsBeforeEnd(measure.getBeats(), start),theMove);
+	}
+	
 	/**
 	 * Mueve los componentes
 	 */
@@ -687,10 +775,10 @@ public class TGMeasureManager {
 	public void cleanBeat(TGBeat beat){
 		beat.getStroke().setDirection( TGStroke.STROKE_NONE );
 		if( beat.getText() != null ){
-			beat.removeChord();
+			beat.removeText();
 		}
 		if( beat.getChord() != null){
-			beat.removeText();
+			beat.removeChord();
 		}
 		
 		this.cleanBeatNotes(beat);
@@ -1157,8 +1245,8 @@ public class TGMeasureManager {
 		if(!startBeat){
 			TGDuration minDuration = getSongManager().getFactory().newDuration();
 			minDuration.setValue(TGDuration.SIXTY_FOURTH);
-			minDuration.getTupleto().setEnters(3);
-			minDuration.getTupleto().setTimes(2);
+			minDuration.getDivision().setEnters(3);
+			minDuration.getDivision().setTimes(2);
 			for(int i = 0;i < minDuration.getTime();i++){
 				start ++;
 				startBeat = (start % beatLength == 0);
@@ -1423,8 +1511,8 @@ public class TGMeasureManager {
 		minimum.setValue(TGDuration.SIXTY_FOURTH);
 		minimum.setDotted(false);
 		minimum.setDoubleDotted(false);
-		minimum.getTupleto().setEnters(3);
-		minimum.getTupleto().setTimes(2);
+		minimum.getDivision().setEnters(3);
+		minimum.getDivision().setTimes(2);
 		
 		long missingTime = time;
 		while( missingTime > minimum.getTime() ){
@@ -1617,6 +1705,31 @@ public class TGMeasureManager {
 		}
 	}
 	
+	public void removeVoicesOutOfTime(TGMeasure measure){
+		List voicesToRemove = new ArrayList();
+		
+		long mStart = measure.getStart();
+		long mEnd = mStart + measure.getLength();
+		
+		Iterator beats = measure.getBeats().iterator();
+		while(beats.hasNext()){
+			TGBeat beat = (TGBeat)beats.next();
+			for( int v = 0; v < beat.countVoices() ; v ++){
+				TGVoice voice = beat.getVoice( v );
+				if(!voice.isEmpty()){
+					if( beat.getStart() < mStart || (beat.getStart() + voice.getDuration().getTime()) > mEnd){
+						voicesToRemove.add( voice );
+					}
+				}
+			}
+		}
+		Iterator it = voicesToRemove.iterator();
+		while(it.hasNext()){
+			TGVoice voice = (TGVoice)it.next();
+			this.removeVoice( voice );
+		}
+	}
+	
 	public void removeMeasureVoices(TGMeasure measure,int index){
 		boolean hasNotes = false;
 		
@@ -2039,4 +2152,249 @@ public class TGMeasureManager {
 		}
 		return true;
 	}
+	
+	public void transposeNotes( TGMeasure measure, int transposition , boolean tryKeepString, boolean applyToChords, int applyToString){
+		if( transposition != 0 ){
+			if( measure != null ){
+				TGTrack track = measure.getTrack();
+				if( track != null ){
+					List strings = getSortedStringsByValue(track, ( transposition > 0 ? 1 : -1 ) ) ;
+					for( int i = 0 ; i < measure.countBeats() ; i ++ ){
+						TGBeat beat = measure.getBeat( i );
+						transposeNotes( beat, strings, transposition , tryKeepString, applyToChords, applyToString );
+					}
+				}
+			}
+		}
+	}
+	
+	public void transposeNotes( TGMeasure measure, int[] transpositionStrings , boolean tryKeepString , boolean applyToChords){
+		if( transpositionStrings != null && transpositionStrings.length > 0 ){
+			if( measure != null ){
+				TGTrack track = measure.getTrack();
+				if( track != null ){
+					TGNote[] notes = new TGNote[ transpositionStrings.length ];
+					
+					for( int b = 0 ; b < measure.countBeats() ; b ++ ){
+						TGBeat beat = measure.getBeat( b );
+						
+						for( int n = 0 ; n < notes.length ; n ++ ){
+							notes[ n ] = getNote( beat, (n + 1) );
+						}
+						
+						for( int i = 0 ; i < notes.length ; i ++ ){
+							if( notes[ i ] != null ){
+								int transposition = transpositionStrings[ i ];
+								if( transposition != 0 ){
+									int applyToString = notes[i].getString();
+									List strings = getSortedStringsByValue(track, ( transposition > 0 ? 1 : -1 ) ) ;
+									transposeNotes( beat, strings, transposition , tryKeepString, applyToChords, applyToString );
+								}
+							}
+						}
+					}
+				}
+			}
+		}
+	}
+	
+	public void transposeNotes( TGBeat beat, List strings, int transposition , boolean tryKeepString, boolean applyToChord, int applyToString){
+		if( transposition != 0 ){
+			List notes = getNotes(beat);
+			
+			int stringCount = strings.size();
+			for( int i = 0 ; i < stringCount ; i ++ ){
+				TGString string = (TGString)strings.get( (stringCount - i) - 1 );
+				if( applyToString == -1 || string.getNumber() == applyToString ){
+					TGNote note = null;
+					for( int n = 0 ; n < notes.size() ; n ++ ){
+						TGNote current = (TGNote)notes.get( n );
+						if( current.getString() == string.getNumber() ){
+							note = current;
+						}
+					}
+					if( note != null ){
+						transposeNote(note, notes, strings, transposition, tryKeepString, false );
+					}
+					
+					if( applyToChord && beat.isChordBeat() ){
+						TGChord chord = beat.getChord();
+						int chordString = ( string.getNumber() - 1 );
+						if( chord.getFretValue( chordString ) >= 0 ){
+							transposeChordNote(chord, chordString, strings, transposition, tryKeepString, false);
+						}
+						chord.setFirstFret( -1 );
+					}
+				}
+			}
+		}
+	}
+	
+	private boolean transposeNote( TGNote note, List notes, List strings , int transposition , boolean tryKeepString, boolean forceChangeString ){
+		boolean canTransposeFret = false;
+		
+		int maximumFret = 29;
+		
+		int transposedFret = ( note.getValue() + transposition );
+		
+		// Check if transposition could be done without change the string
+		if( transposedFret >= 0 && transposedFret <= maximumFret ){
+			// Do it now if keep string is the priority
+			if( !forceChangeString && tryKeepString ){
+				note.setValue( transposedFret );
+				return true;
+			}
+			canTransposeFret = true;
+		}
+		
+		// Check the current string index for this note
+		int stringIndex = -1;
+		for( int i = 0 ; i < strings.size() ; i ++ ){
+			TGString string = ( TGString ) strings.get( i );
+			if( string.getNumber() == note.getString() ){
+				stringIndex = i;
+				break;
+			}
+		}
+		
+		// Try to change the string of the note
+		TGString string = ( TGString ) strings.get( stringIndex );
+		int transposedValue = ( string.getValue() + note.getValue() + transposition );
+		int nextStringIndex = ( stringIndex + 1 );
+		while( nextStringIndex >= 0 && nextStringIndex < strings.size() ){
+			TGString nextString = ( TGString ) strings.get( nextStringIndex );
+			TGNote nextOwner = null;
+			for( int i = 0 ; i < notes.size() ; i ++ ){
+				TGNote nextNote = (TGNote) notes.get( i );
+				if( nextNote.getString() == nextString.getNumber() ){
+					nextOwner = nextNote;
+				}
+			}
+			
+			int transposedStringFret = ( transposedValue - nextString.getValue() );
+			if( transposedStringFret >= 0 && transposedStringFret <= maximumFret ){
+				if( nextOwner != null ){
+					if( ! transposeNote(nextOwner, notes, strings, 0 , tryKeepString , !canTransposeFret ) ){
+						// Note was removed.
+						nextOwner = null ;
+					}
+				}
+				if( nextOwner == null || nextOwner.getString() != nextString.getNumber() ){
+					note.setValue( transposedStringFret );
+					note.setString( nextString.getNumber() );
+					
+					return true;
+				}
+			}
+			nextStringIndex ++;
+		}
+		
+		// Keep using same string if it's possible
+		if( !forceChangeString && canTransposeFret ){
+			note.setValue( transposedFret );
+			return true;
+		}
+		
+		// If note can't be transposed, it must be removed.
+		notes.remove( note );
+		removeNote(note);
+		
+		return false;
+	}
+	
+	private boolean transposeChordNote( TGChord chord, int chordString, List strings , int transposition , boolean tryKeepString, boolean forceChangeString ){
+		boolean canTransposeFret = false;
+		
+		int maximumFret = 24;
+		
+		int noteValue = chord.getFretValue( chordString );
+		int noteString = (chordString + 1 );
+		
+		int transposedFret = ( noteValue + transposition );
+		
+		// Check if transposition could be done without change the string
+		if( transposedFret >= 0 && transposedFret <= maximumFret ){
+			// Do it now if keep string is the priority
+			if( !forceChangeString && tryKeepString ){
+				chord.addFretValue(chordString, transposedFret);
+				return true;
+			}
+			canTransposeFret = true;
+		}
+		
+		// Check the current string index for this note
+		int stringIndex = -1;
+		for( int i = 0 ; i < strings.size() ; i ++ ){
+			TGString string = ( TGString ) strings.get( i );
+			if( string.getNumber() == noteString ){
+				stringIndex = i;
+				break;
+			}
+		}
+		
+		// Try to change the string of the note
+		TGString string = ( TGString ) strings.get( stringIndex );
+		int transposedValue = ( string.getValue() + noteValue + transposition );
+		int nextStringIndex = ( stringIndex + 1 );
+		while( nextStringIndex >= 0 && nextStringIndex < strings.size() ){
+			TGString nextString = ( TGString ) strings.get( nextStringIndex );
+			int nextChordString = -1;
+			for( int i = 0 ; i < chord.countStrings() ; i ++ ){
+				if( (i + 1) == nextString.getNumber() ){
+					if( chord.getFretValue( i ) >= 0 ){
+						nextChordString = i;
+					}
+				}
+			}
+			
+			int transposedStringFret = ( transposedValue - nextString.getValue() );
+			if( transposedStringFret >= 0 && transposedStringFret <= maximumFret ){
+				if( nextChordString >= 0 ){
+					transposeChordNote(chord, nextChordString , strings, 0 , tryKeepString , !canTransposeFret );
+				}
+				if( nextChordString < 0 || chord.getFretValue( nextChordString ) < 0 ){
+					chord.addFretValue( chordString , -1 );
+					chord.addFretValue( ( nextString.getNumber() - 1 ) , transposedStringFret );
+					
+					return true;
+				}
+			}
+			nextStringIndex ++;
+		}
+		
+		// Keep using same string if it's possible
+		if( !forceChangeString && canTransposeFret ){
+			chord.addFretValue( chordString , transposedFret );
+			return true;
+		}
+		
+		// If note can't be transposed, it must be removed.
+		chord.addFretValue( chordString , -1 );
+		
+		return false;
+	}
+	
+	public List getSortedStringsByValue( TGTrack track , final int direction ){
+		List strings = new ArrayList();
+		for( int number = 1 ; number <= track.stringCount() ; number ++ ){
+			strings.add( track.getString( number ) );
+		}
+		
+		Collections.sort( strings , new Comparator() {
+			public int compare(Object o1, Object o2) {
+				if( o1 != null && o2 != null && o1 instanceof TGString && o2 instanceof TGString ){
+					TGString s1 = (TGString)o1;
+					TGString s2 = (TGString)o2;
+					int status = ( s1.getValue() - s2.getValue() );
+					if( status == 0 ){
+						return 0;
+					}
+					return ( (status * direction) > 0 ? 1 : -1 );
+				}
+				return 0;
+			}
+		});
+		
+		return strings;
+	}
 }
