@@ -77,23 +77,28 @@ public class TGSongManager {
 	}
 	
 	public void clearSong(){
-		if(getSong() != null){
-			getSong().clear();
+		if(this.getSong() != null){
+			this.getSong().clear();
 		}
 	}
 	
 	public void setSong(TGSong song){
 		if(song != null){
-			clearSong();
+			this.clearSong();
 			this.song = song;
 		}
 	}
 	
-	public void setProperties(String name,String artist,String album,String author){
+	public void setProperties(String name,String artist,String album,String author,String date,String copyright,String writer,String transcriber,String comments){
 		getSong().setName(name);
 		getSong().setArtist(artist);
 		getSong().setAlbum(album);
 		getSong().setAuthor(author);
+		getSong().setDate(date);
+		getSong().setCopyright(copyright);
+		getSong().setWriter(writer);
+		getSong().setTranscriber(transcriber);
+		getSong().setComments(comments);
 	}
 	
 	public void addTrack(TGTrack trackToAdd){
@@ -174,9 +179,9 @@ public class TGSongManager {
 		return (getSong().countTracks() + 1);
 	}
 	
-	public TGChannel getFreeChannel(short instrument,boolean isPercusion){
-		if(isPercusion){
-			return TGChannel.newPercusionChannel(getFactory());
+	public TGChannel getFreeChannel(short instrument,boolean isPercussion){
+		if(isPercussion){
+			return TGChannel.newPercussionChannel(getFactory());
 		}
 		short normalChannel = -1;
 		short effectChannel = -1;
@@ -1009,7 +1014,7 @@ public class TGSongManager {
 		return strings;
 	}
 	
-	public static List createPercusionStrings(TGFactory factory,int stringCount){
+	public static List createPercussionStrings(TGFactory factory,int stringCount){
 		List strings = new ArrayList();
 		for(int i = 1;i <= stringCount; i++){
 			strings.add(newString(factory,i, 0));
