@@ -193,6 +193,21 @@ public class TGTrackManager {
 		}
 	}
 	
+	public void moveTrackBeats(TGTrack track, long measureStart, long moveStart, long theMove ){
+		List measures = getMeasuresBeforeEnd(track,measureStart);
+		for( int i = 0 ; i < measures.size() ; i ++ ){
+			TGMeasure measure = (TGMeasure)measures.get(i);
+			if( moveStart + theMove < moveStart ){
+				getSongManager().getMeasureManager().removeBeatsBeetween(measure, moveStart, (moveStart + Math.abs(theMove)));
+			}
+			getSongManager().getMeasureManager().moveBeats(measure, moveStart, theMove);
+		}
+		for( int i = 0 ; i < measures.size() ; i ++ ){
+			TGMeasure measure = (TGMeasure)measures.get(i);
+			getSongManager().getMeasureManager().moveOutOfBoundsBeatsToNewMeasure(measure,false);
+		}
+	}
+	
 	public void changeKeySignature(TGTrack track,long start,int keySignature,boolean toEnd){
 		changeKeySignature(track,getMeasureAt(track,start),keySignature,toEnd);
 	}
@@ -235,6 +250,16 @@ public class TGTrackManager {
 		}
 	}
 	
+	public void changeSolo(TGTrack track,boolean solo){
+		track.setSolo(solo);
+		track.setMute(track.isSolo() ? false : track.isMute());
+	}
+	
+	public void changeMute(TGTrack track,boolean mute){
+		track.setMute(mute);
+		track.setSolo(track.isMute() ? false : track.isSolo());
+	}
+	
 	public void changeInfo(TGTrack track,String name,TGColor color,int offset){
 		track.setName(name);
 		track.setOffset(offset);
@@ -258,11 +283,11 @@ public class TGTrackManager {
 		}
 	}
 	
-	public void changeInstrument(TGTrack track,int instrument,boolean percusion){
+	public void changeInstrument(TGTrack track,int instrument,boolean percussion){
 		track.getChannel().setInstrument((short)instrument);
-		if(percusion){
-			TGChannel.setPercusionChannel(track.getChannel());
-			track.setStrings(TGSongManager.createPercusionStrings(getSongManager().getFactory(),track.getStrings().size()));
+		if(percussion){
+			TGChannel.setPercussionChannel(track.getChannel());
+			track.setStrings(TGSongManager.createPercussionStrings(getSongManager().getFactory(),track.getStrings().size()));
 		}else{
 			if(track.getChannel().isPercussionChannel()){
 				TGChannel tempChannel = this.songManager.getFreeChannel((short)instrument,false);
@@ -289,6 +314,22 @@ public class TGTrackManager {
 		}
 	}
 	
+	public void transposeNotes(TGTrack track, int transposition , boolean tryKeepString, boolean applyToChords, int applyToString){
+		Iterator it = track.getMeasures();
+		while(it.hasNext()){
+			TGMeasure measure = (TGMeasure)it.next();
+			this.songManager.getMeasureManager().transposeNotes(measure, transposition, tryKeepString, applyToChords, applyToString );
+		}
+	}
+	
+	public void transposeNotes(TGTrack track, int[] transpositionStrings , boolean tryKeepString , boolean applyToChords ){
+		Iterator it = track.getMeasures();
+		while(it.hasNext()){
+			TGMeasure measure = (TGMeasure)it.next();
+			this.songManager.getMeasureManager().transposeNotes(measure, transpositionStrings, tryKeepString , applyToChords);
+		}
+	}
+	
 	/**
 	 * Retorna true si es el primer compas
 	 */
